CREATE OR REPLACE PACKAGE BODY EKONO."WMS_P_JORNADAS"
IS
   --------------------------------------------------------------------------
   -- Jornada cerrada
   --------------------------------------------------------------------------

   FUNCTION jornada_cerrada (p_jornada NUMBER, p_rubro NUMBER DEFAULT NULL )
      RETURN VARCHAR2
   IS
      -- Definimos variables locales
      v_cerrado    VARCHAR2 (1);
      v_detalles   NUMBER (5);
   BEGIN
      -- Verificando si la jornada se encuentra cerrada
      SELECT   DECODE (corte_cerrado, 'F', 'S', 'N')
        INTO   v_cerrado
        FROM   WMS_JORNADAS
       WHERE   jornada = p_jornada;

      -- Verificando si la jornada tiene detalles y esta cerrada
      IF v_cerrado <> 'N'
      THEN
         -- Validando HISTORICO_JORNADAS
         SELECT   COUNT (1)
           INTO   v_detalles
           FROM   WMS_HISTORICO_JORNADAS
          WHERE   jornada = p_jornada;

         IF v_detalles = 0
         THEN
            v_cerrado := 'N';
         END IF;

         -- Validando HISTORICO_DETALLE_JORNADAS
         SELECT   COUNT (1)
           INTO   v_detalles
           FROM   WMS_HISTORICO_DETALLE_JORNADAS
          WHERE   jornada = p_jornada AND rubro = NVL (p_rubro, rubro);

         IF v_detalles = 0
         THEN
            v_cerrado := 'N';
         END IF;
      END IF;

      RETURN v_cerrado;
   END jornada_cerrada;

   --------------------------------------------------------------------------
   -- Abonos
   --------------------------------------------------------------------------
   FUNCTION abonos (p_documento NUMBER)
      RETURN NUMBER
   IS
      v_resultado   NUMBER;
   BEGIN
      SELECT   NVL (SUM (b.valor), 0)
        INTO   v_resultado
        FROM   DOC_ABONO_DOCUMENTOS b
       WHERE   b.recibo = p_documento AND b.tipo_documento IN ('F', 'B', 'P');

      RETURN v_resultado;
   END abonos;

   --------------------------------------------------------------------------
   -- detalles
   --------------------------------------------------------------------------
   PROCEDURE detalles (p_jornada NUMBER, p_rubro NUMBER, p_monto NUMBER)
   IS
   BEGIN
      BEGIN
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, p_rubro, NVL (p_monto, 0));
      EXCEPTION
         WHEN DUP_VAL_ON_INDEX
         THEN
            UPDATE   WMS_HISTORICO_JORNADAS
               SET   monto = p_monto
             WHERE   jornada = p_jornada AND rubro = p_rubro;
      END;
   END detalles;

   --------------------------------------------------------------------------
   -- Propina
   --------------------------------------------------------------------------
   FUNCTION wms_f_propina (p_fecha_inicial    DATE,
                           p_fecha_final      DATE,
                           p_usuario          VARCHAR2)
      RETURN NUMBER
   IS
      -- Definimos variables locales
      v_propina   WMS_DOCUMENTOS.propina%TYPE;
   BEGIN
      SELECT   NVL (SUM (NVL (x.propina, 0)), 0)
        INTO   v_propina
        FROM   WMS_DOCUMENTOS x
       WHERE       x.imprimir_propina = 'S'
               AND x.tipo_documento = 'F'
               AND NVL (x.situacion, 1) <> 11
               AND x.usuario1 = p_usuario
               AND x.jornada IN
                        (SELECT   jornada
                           FROM   WMS_JORNADAS
                          WHERE   fecha_apertura BETWEEN TRUNC (
                                                            p_fecha_inicial
                                                         )
                                                     AND  TRUNC (
                                                             p_fecha_final
                                                          )
                                                          + 0.99999);

      RETURN v_propina;
   END wms_f_propina;

   --------------------------------------------------------------------------
   -- Total de la caja chica
   --------------------------------------------------------------------------
   FUNCTION WMS_F_TOTAL_CAJA_CHICA (P_JORNADA NUMBER, P_MONEDA NUMBER)
      RETURN NUMBER
   IS
      -- Definimos variables locales
      v_total   WMS_GASTOS_JORNADA.valor%TYPE;
   BEGIN
      SELECT   NVL (SUM (VALOR), 0)
        INTO   v_total
        FROM   WMS_GASTOS_JORNADA
       WHERE   JORNADA = P_JORNADA AND MONEDA = P_MONEDA;

      RETURN v_total;
   END WMS_F_TOTAL_CAJA_CHICA;

   --------------------------------------------------------------------------
   -- Actualizar estadisticas
   --------------------------------------------------------------------------
   PROCEDURE actualizar_estadisticas (p_jornada          NUMBER,
                                      p_fecha_inicial    DATE,
                                      p_fecha_final      DATE)
   IS
      -- Definimos variables locales
      v_resultado   NUMBER (14, 4);
   BEGIN
      -- FACTURACION
      SELECT   NVL (
                  DECODE (Cg_F_Parameter_Value ('MOJO'),
                          'MB', SUM (a.total),
                          SUM (NVL (a.total, 0) / NVL (a.tasa_cambio_ma, 1))),
                  0
               )
                  total
        INTO   v_resultado
        FROM   WMS_DOCUMENTOS a
       WHERE   a.tipo_documento = 'F' AND NVL (a.situacion, 1) <> 11
               AND a.fecha_emision BETWEEN TRUNC (p_fecha_inicial)
                                       AND  TRUNC (p_fecha_final) + 0.99999;

      detalles (p_jornada, 194, v_resultado);
      detalles (p_jornada, 195, v_resultado);
      detalles (p_jornada, 196, v_resultado);

      -- ANULACIONES
      SELECT                                                /* + FIRST_ROWS */
            DECODE (Cg_F_Parameter_Value ('MOJO'),
                    'MB', NVL (SUM (b.total), 0),
                    NVL (SUM (b.propina / NVL (tasa_cambio_ma, 1)), 0))
                  total
        INTO   v_resultado
        FROM   WMS_DOCUMENTOS b
       WHERE   b.tipo_documento = 'F' AND b.situacion = 11
               AND b.fecha_emision BETWEEN TRUNC (p_fecha_inicial)
                                       AND  TRUNC (p_fecha_final) + 0.99999;

      detalles (p_jornada, 197, v_resultado);

      -- DESCUENTOS
      SELECT                                                 /*+ FIRST_ROWS */
            DECODE (
                  Cg_F_Parameter_Value ('MOJO'),
                  'MB',
                  NVL (SUM (NVL (a.descuento, 0) * NVL (a.cantidad, 0)), 0),
                  NVL (
                     SUM( (NVL (a.descuento, 0) * NVL (a.cantidad, 0))
                         / NVL (b.tasa_cambio_ma, 1)),
                     0
                  )
               )
                  descuento
        INTO   v_resultado
        FROM   WMS_SKUS_X_DOCUMENTO a, WMS_DOCUMENTOS b
       WHERE       a.documento = b.documento
               AND b.tipo_documento = 'F'
               AND NVL (b.situacion, 1) <> 11
               AND b.fecha_emision BETWEEN TRUNC (p_fecha_inicial)
                                       AND  TRUNC (p_fecha_final) + 0.99999;

      detalles (p_jornada, 200, v_resultado);

      -- PEDIDOS BONIFICADOS
      SELECT                                                 /*+ FIRST_ROWS */
            NVL (
                  DECODE (
                     Cg_F_Parameter_Value ('MOJO'),
                     'MB',
                     SUM (cantidad * (b.precio_unitario + b.impuesto))
                     * (1 + (Cg_F_Parameter_Value ('PIVA') / 100)),
                     SUM(  (cantidad * (b.precio_unitario + b.impuesto))
                         * (1 + (Cg_F_Parameter_Value ('PIVA') / 100))
                         / NVL (a.tasa_cambio_ma, 1))
                  ),
                  0
               )
                  Total
        INTO   v_resultado
        FROM   WMS_DOCUMENTOS a, WMS_SKUS_X_DOCUMENTO b, wms_v_usuarios c
       WHERE       a.tipo_documento = 'P'
               AND a.bonificacion IS NOT NULL
               AND a.documento = b.documento
               AND b.usuario_anulo IS NULL
               AND b.usuario = c.usuario
               AND NVL (a.situacion, 1) <> 11
               AND a.fecha_emision BETWEEN TRUNC (p_fecha_inicial)
                                       AND  TRUNC (p_fecha_final) + 0.99999;

      detalles (p_jornada, 203, v_resultado);

      -- PEDIDOS ABIERTOS
      SELECT                                                 /*+ FIRST_ROWS */
            SUM(NVL (b.cantidad, 1)
                * ( (  NVL (b.precio_unitario, 0)
                     + NVL (b.impuesto, 0)
                     - NVL (b.descuento, 0))))
                  total
        INTO   v_resultado
        FROM   WMS_DOCUMENTOS a, WMS_SKUS_X_DOCUMENTO b
       WHERE   a.tipo_documento = 'P' AND a.usuario2 IS NULL
               AND a.fecha_emision BETWEEN TRUNC (p_fecha_inicial)
                                       AND  TRUNC (p_fecha_final) + 0.99999
               AND a.situacion IN (1, 3)
               AND a.tipo_documento = 'P'
               AND a.fecha_vencimiento IS NULL
               AND NVL (a.subtipo_documento, 'R') <> 'F'
               AND a.documento = b.documento;

      detalles (p_jornada, 205, v_resultado);

      -- PEDIDOS ANULADOS
      SELECT   DECODE (
                  Cg_F_Parameter_Value ('MOJO'),
                  'MB',
                  SUM(NVL (b.cantidad, 1)
                      * (  NVL (b.precio_unitario, 0)
                         - NVL (b.descuento, 0)
                         + NVL (b.impuesto, 0))),
                  SUM(NVL (b.cantidad, 1)
                      * (  NVL (b.precio_unitario, 0)
                         - NVL (b.descuento, 0)
                         + NVL (b.impuesto, 0)))
                  / MAX (NVL (a.tasa_cambio_ma, 1))
               )
                  total
        INTO   v_resultado
        FROM   WMS_DOCUMENTOS a, WMS_SKUS_X_DOCUMENTO b
       WHERE       a.tipo_documento = 'P'
               AND NVL (a.situacion, 1) = 11
               AND a.documento = b.documento
               AND a.anulada_el BETWEEN TRUNC (p_fecha_inicial)
                                    AND  TRUNC (p_fecha_final) + 0.99999;

      detalles (p_jornada, 206, v_resultado);

      -- PERSONAS ATENDIDAS
      SELECT                                                 /*+ FIRST_ROWS */
            SUM (a.personas) total
        INTO   v_resultado
        FROM   WMS_DOCUMENTOS a
       WHERE   a.tipo_documento = 'F' AND NVL (a.situacion, 1) <> 11
               AND a.fecha_emision BETWEEN TRUNC (p_fecha_inicial)
                                       AND  TRUNC (p_fecha_final) + 0.99999;

      detalles (p_jornada, 207, v_resultado);

      -- PRODUCTOS ANULADOS
      SELECT   NVL (SUM (b.cantidad), 0)
        INTO   v_resultado
        FROM   WMS_DOCUMENTOS a, WMS_SKUS_X_DOCUMENTO b
       WHERE       a.documento = b.documento
               AND a.tipo_documento = 'P'
               AND b.usuario_anulo IS NOT NULL
               AND a.fecha_emision BETWEEN TRUNC (p_fecha_inicial)
                                       AND  TRUNC (p_fecha_final) + 0.99999;

      detalles (p_jornada, 208, v_resultado);
      -- Grabamos los cambios
      COMMIT;
   END actualizar_estadisticas;

   --------------------------------------------------------------------------
   -- Abono documentos
   --------------------------------------------------------------------------
   FUNCTION abono_documentos (p_documento NUMBER)
      RETURN NUMBER
   IS
      -- Definimos variables locales
      v_resultado   NUMBER (14, 4);
   BEGIN
      SELECT   NVL (SUM (b.valor), 0)
        INTO   v_resultado
        FROM   DOC_ABONO_DOCUMENTOS b
       WHERE   b.recibo = p_documento AND b.tipo_documento IN ('F', 'B', 'P');

      RETURN v_resultado;
   END abono_documentos;

   --------------------------------------------------------------------------
   -- pagos
   --------------------------------------------------------------------------
   FUNCTION pagos (p_moneda       VARCHAR2,
                   p_jornada      NUMBER,
                   p_tipo_pago    NUMBER,
                   p_rubro        NUMBER,
                   p_detalles     VARCHAR2 DEFAULT 'S' ,
                   p_emisor       NUMBER DEFAULT NULL )
      RETURN NUMBER
   IS
      v_resultado    NUMBER;
      v_total        NUMBER;
      v_usuario      WMS_DETALLE_JORNADAS.monto%TYPE;
      v_supervisor   WMS_DETALLE_JORNADAS.monto_supervisor%TYPE;
      v_rubro        NUMBER (5);
   BEGIN
      IF p_emisor IS NULL
      THEN
         SELECT                                              /*+ FIRST_ROWS */
               NVL (
                     DECODE (
                        p_moneda,
                        'MB',
                        SUM (NVL (a.valor, 0) + NVL (a.propina, 0)),
                        SUM( (NVL (a.valor, 0) + NVL (a.propina, 0))
                            / NVL (b.tasa_cambio_ma, 1))
                     ),
                     0
                  )
           INTO   v_resultado
           FROM   WMS_PAGO_DOCUMENTOS a, WMS_DOCUMENTOS b
          WHERE       a.documento = b.documento
                  AND b.Tipo_documento = 'R'
                  AND NVL (b.situacion, 1) <> 11
                  AND b.jornada = p_jornada
                  AND a.tipo_pago = p_tipo_pago;
      ELSE
         SELECT                                              /*+ FIRST_ROWS */
               NVL (
                     DECODE (
                        p_moneda,
                        'MB',
                        SUM (NVL (a.valor, 0) + NVL (a.propina, 0)),
                        SUM( (NVL (a.valor, 0) + NVL (a.propina, 0))
                            / NVL (b.tasa_cambio_ma, 1))
                     ),
                     0
                  )
           INTO   v_resultado
           FROM   WMS_PAGO_DOCUMENTOS a, WMS_DOCUMENTOS b
          WHERE       a.documento = b.documento
                  AND b.Tipo_documento = 'R'
                  AND NVL (b.situacion, 1) <> 11
                  AND b.jornada = p_jornada
                  AND a.tipo_pago = p_tipo_pago
                  AND NVL (a.emisor, -1) = NVL (p_emisor, -1);
      END IF;

      v_total := v_resultado;

      -- (-) Devolucion en efectivo/tarjeta
      IF p_rubro = 175
      THEN
         SELECT                                             /* + FIRST_ROWS */
               DECODE (Cg_F_Parameter_Value ('MOJO'),
                       'MB', NVL (SUM (total), 0),
                       NVL (SUM (total / NVL (tasa_cambio_ma, 1)), 0))
           INTO   v_resultado
           FROM   WMS_DOCUMENTOS
          WHERE       tipo_documento = 'D'
                  AND subtipo_documento = 'D'
                  AND jornada = p_jornada;

         v_total := v_total - v_resultado;
      END IF;

      -- (-) Devolucion en tarjeta
      IF p_rubro = 176
      THEN
         SELECT                                             /* + FIRST_ROWS */
               DECODE (Cg_F_Parameter_Value ('MOJO'),
                       'MB', NVL (SUM (total), 0),
                       NVL (SUM (total / NVL (tasa_cambio_ma, 1)), 0))
           INTO   v_resultado
           FROM   WMS_DOCUMENTOS
          WHERE       tipo_documento = 'D'
                  AND subtipo_documento = 'T' --- ES A PERO PARA CERMA SE MODIFICO A T
                  AND jornada = p_jornada;

         v_total := v_total - v_resultado;
      END IF;

      -- Consultando valores actuales en los montos del usuario y supervisor
      BEGIN
         SELECT   NVL (monto, 0), NVL (monto_supervisor, 0)
           INTO   v_usuario, v_supervisor
           FROM   WMS_DETALLE_JORNADAS
          WHERE   jornada = p_jornada AND tipo_pago = p_tipo_pago;
      EXCEPTION
         WHEN NO_DATA_FOUND
         THEN
            v_usuario := 0;
            v_supervisor := 0;
      END;

      -- Creamos el historico jornadas
      BEGIN
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada,
                                             rubro,
                                             monto,
                                             monto_usuario,
                                             monto_supervisor)
           VALUES   (p_jornada,
                     p_rubro,
                     v_total,
                     v_usuario,
                     v_supervisor);
      EXCEPTION
         WHEN DUP_VAL_ON_INDEX
         THEN
            UPDATE   WMS_HISTORICO_JORNADAS
               SET   monto = v_total,
                     monto_usuario = v_usuario,
                     monto_supervisor = v_supervisor
             WHERE   jornada = p_jornada AND rubro = p_rubro;
      END;

      -- Verificamos si creamos el detalle del rubro
      IF p_detalles = 'S'
      THEN
         -- Detallado
         v_rubro := 209 + (p_rubro - 175) * 4;

         -- Sistema
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, v_rubro, v_total);
      -- Usuario
      -- INSERT INTO WMS_HISTORICO_JORNADAS ( jornada, rubro, monto ) VALUES ( p_jornada, v_rubro + 1, v_usuario );
      -- Supervisor
      -- INSERT INTO WMS_HISTORICO_JORNADAS ( jornada, rubro, monto ) VALUES ( p_jornada, v_rubro + 2, v_supervisor );
      -- Diferencia
      -- INSERT INTO WMS_HISTORICO_JORNADAS ( jornada, rubro, monto ) VALUES ( p_jornada, v_rubro + 3, v_total - v_supervisor );
      END IF;

      RETURN NVL (v_total, 0);
   END pagos;

   --------------------------------------------------------------------------
   -- Impuesto de los tipos de pago
   --------------------------------------------------------------------------
   FUNCTION impuesto_pagos (p_moneda       VARCHAR2,
                            p_jornada      NUMBER,
                            p_tipo_pago    NUMBER,
                            p_rubro        NUMBER)
      RETURN NUMBER
   IS
      v_resultado   NUMBER;
      v_total       NUMBER;
      v_monto       NUMBER;
      v_piva NUMBER (7, 2)
            := NVL (TO_NUMBER (Cg_F_Parameter_Value ('PIVA')), 12) / 100 ;
      v_tipo_vale   VARCHAR2 (1);
   BEGIN
      SELECT   monto
        INTO   v_monto
        FROM   WMS_HISTORICO_JORNADAS
       WHERE   jornada = p_jornada AND rubro = p_rubro - 112;

      -- Si el rubro no es de vales ni certificados
      IF p_rubro NOT IN (291, 292)
      THEN
         -- Obtenemos los pagos que no son con vales y exoneraciones en el mismo recibo
         SELECT   SUM (NVL (a.valor, 0) + NVL (a.propina, 0))
           INTO   v_resultado
           FROM   WMS_PAGO_DOCUMENTOS a, WMS_DOCUMENTOS b
          WHERE       a.documento = b.documento
                  AND b.tipo_documento = 'R'
                  AND NVL (b.situacion, 1) <> 11
                  AND b.jornada = p_jornada
                  AND a.tipo_pago = p_tipo_pago
                  AND EXISTS
                        (SELECT   1
                           FROM   WMS_PAGO_DOCUMENTOS c
                          WHERE   c.documento = a.documento
                                  AND c.tipo_pago = 12);
      ELSE
         -- Si el rubro es de vales por devolucion
         IF p_rubro = 291
         THEN
            v_tipo_vale := 'D';
         ELSE
            v_tipo_vale := 'A';
         END IF;

         -- Obtenemos los pagos con vales y exoneraciones en el mismo recibo
         SELECT   SUM (NVL (a.valor, 0) + NVL (a.propina, 0))
           INTO   v_resultado
           FROM   WMS_PAGO_DOCUMENTOS a, WMS_DOCUMENTOS b, DOC_VALES c
          WHERE       a.documento = b.documento
                  AND a.vale = c.vale
                  AND b.tipo_documento = 'R'
                  AND NVL (b.situacion, 1) <> 11
                  AND b.jornada = p_jornada
                  AND a.tipo_pago = p_tipo_pago
                  AND c.tipo = v_tipo_vale
                  AND EXISTS
                        (SELECT   1
                           FROM   WMS_PAGO_DOCUMENTOS c
                          WHERE   c.documento = a.documento
                                  AND c.tipo_pago = 12);
      END IF;

      v_total :=
         (NVL (v_monto, 0) - NVL (v_resultado, 0)) / (1 + v_piva) * v_piva;

      BEGIN
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, p_rubro, v_total);
      EXCEPTION
         WHEN DUP_VAL_ON_INDEX
         THEN
            UPDATE   WMS_HISTORICO_JORNADAS
               SET   monto = v_total
             WHERE   jornada = p_jornada AND rubro = p_rubro;
      END;

      -- Retornamos el valor de la variable calculada
      RETURN v_total;
   END impuesto_pagos;

   --------------------------------------------------------------------------
   -- vales
   --------------------------------------------------------------------------
   FUNCTION vales (p_jornada NUMBER, p_tipo VARCHAR2, p_rubro NUMBER)
      RETURN NUMBER
   IS
      v_resultado    NUMBER;
      v_usuario      WMS_DETALLE_JORNADAS.monto%TYPE;
      v_supervisor   WMS_DETALLE_JORNADAS.monto_supervisor%TYPE;
      v_rubro        NUMBER (5);
   BEGIN
      -- Obtenemos el total pagado con vales del tipo especificado
      IF p_rubro IN (330, 331)
      THEN                                                            -- v.6.X
         v_rubro := p_rubro - 151;                 -- 330 --> 179  331 --> 180

         SELECT   -SUM (b.cantidad * (b.precio_unitario + b.impuesto)) total
           INTO   v_resultado
           FROM   WMS_DOCUMENTOS a, WMS_SKUS_X_DOCUMENTO b, DOC_VALES c
          WHERE       a.tipo_documento = 'F'
                  AND a.jornada = p_jornada
                  AND NVL (a.situacion, 1) <> 11
                  AND a.documento = b.documento
                  AND b.cantidad < 0
                  AND b.vale = c.vale
                  AND c.tipo = p_tipo;
      ELSIF p_rubro IN (179, 180)
      THEN
         v_rubro := p_rubro;

         SELECT                                              /*+ FIRST_ROWS */
               NVL (SUM (NVL (a.valor, 0) + NVL (a.propina, 0)), 0)
                     sistema
           INTO   v_resultado
           FROM   WMS_PAGO_DOCUMENTOS a, WMS_DOCUMENTOS b, DOC_VALES c
          WHERE       a.documento = b.documento
                  AND b.tipo_documento = 'R'
                  AND NVL (b.situacion, 1) <> 11
                  AND a.vale = c.vale
                  AND c.tipo = p_tipo
                  AND b.jornada = p_jornada
                  AND a.tipo_pago IN (6, 24);
      ELSIF p_rubro IN (361, 362)
      THEN                                                   -- Vales Emitidos
         SELECT                                              /*+ FIRST_ROWS */
               SUM (NVL (a.monto, 0))
           INTO   v_resultado
           FROM   DOC_VALES a
          WHERE   a.jornada = p_jornada AND a.tipo = p_tipo;
      END IF;

      -- Si el tipo de vale es por devolucion
      IF p_tipo = 'D'
      THEN
         BEGIN
            -- Obtenemos valores actuales en los montos del usuario y supervisor
            SELECT   NVL (monto, 0), NVL (monto_supervisor, 0)
              INTO   v_usuario, v_supervisor
              FROM   WMS_DETALLE_JORNADAS
             WHERE   jornada = p_jornada AND tipo_pago = 6;
         EXCEPTION
            WHEN NO_DATA_FOUND
            THEN
               v_usuario := 0;
               v_supervisor := 0;
         END;
      END IF;

      -- Actualizamos el rubro especificado ( 179 y 180 )
      INSERT INTO WMS_HISTORICO_JORNADAS (jornada,
                                          rubro,
                                          monto,
                                          monto_usuario,
                                          monto_supervisor)
        VALUES   (p_jornada,
                  p_rubro,
                  NVL (v_resultado, 0),
                  v_usuario,
                  v_supervisor);

      IF p_rubro < 360
      THEN
         -- Detallamos los rubros de vales y certificados ( sistema, usuario, supervisor y diferencia )
         -- Los rubros resultantes son del 225 - 228 para vales y 229 - 232 para certificados
         v_rubro := 209 + (v_rubro - 175) * 4;

         DELETE FROM   WMS_HISTORICO_JORNADAS
               WHERE   jornada = p_jornada
                       AND rubro BETWEEN v_rubro AND v_rubro + 3;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, v_rubro, v_resultado);

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, v_rubro + 1, v_usuario);

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, v_rubro + 2, v_supervisor);

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, v_rubro + 3, v_resultado - v_supervisor);
      END IF;

      RETURN NVL (v_resultado, 0);
   END vales;

   --------------------------------------------------------------------------
   -- Detalle jornada
   --------------------------------------------------------------------------
   PROCEDURE detalle_jornada (p_jornada          NUMBER,
                              p_rubro            NUMBER,
                              p_fecha_inicial    DATE DEFAULT SYSDATE ,
                              p_fecha_final      DATE DEFAULT SYSDATE )
   IS
      -- Definimos variables locales
      v_linea    NUMBER (5);
      v_moneda   NUMBER (3);
   BEGIN
      IF jornada_cerrada (p_jornada, p_rubro) = 'N'
      THEN
         -- Borramos registros actuales
         DELETE FROM   WMS_HISTORICO_DETALLE_JORNADAS
               WHERE   jornada = p_jornada AND rubro = p_rubro;

         -- FACTURACION TOTAL
         IF p_rubro = 160
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        total
                 FROM   (  SELECT                            /*+ FIRST_ROWS */
                                 b  .documento,
                                    b.serie || ' ' || b.no_documento
                                       no_documento,
                                    ROUND (
                                       DECODE (
                                          Cg_F_Parameter_Value ('MOJO'),
                                          'MB',
                                          NVL (
                                             SUM(NVL (a.cantidad, 0)
                                                 * NVL (a.precio_unitario, 0)
                                                 * (1
                                                    + NVL (
                                                         c.impuesto / 100,
                                                         Cg_F_Parameter_Value (
                                                            'PIVA'
                                                         )
                                                         / 100
                                                      ))),
                                             0
                                          ),
                                          NVL (
                                             SUM( (NVL (a.cantidad, 0)
                                                   * NVL (a.precio_unitario, 0)
                                                   * (1
                                                      + NVL (
                                                           c.impuesto / 100,
                                                           Cg_F_Parameter_Value('PIVA')
                                                           / 100
                                                        )))
                                                 / NVL (b.tasa_cambio_ma, 1)),
                                             0
                                          )
                                       ),
                                       2
                                    )
                                       total
                             FROM   WMS_SKUS_X_DOCUMENTO a,
                                    WMS_DOCUMENTOS b,
                                    WMS_SKUS c
                            WHERE       a.documento = b.documento
                                    AND a.sku = c.sku
                                    AND b.tipo_documento = 'F'
                                    AND b.jornada IN (p_jornada)
                         GROUP BY   b.documento, b.serie, b.no_documento
                         ORDER BY   2);
         --TRANSFERENCIAS BANCARIAS
         ELSIF p_rubro = 450
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        texto4,
                                                        texto5,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        facturas,
                        banco,
                        cuenta_bancaria,
                        autorizacion,
                        total
                 FROM   (SELECT   b.serie || ' ' || b.no_documento
                                     no_documento,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     NVL (a.valor, 0) + NVL (a.propina, 0),
                                     NVL (a.valor, 0)
                                     + NVL (a.propina, 0)
                                       / NVL (b.tasa_cambio_ma, 1)
                                  )
                                     total,
                                  Cg_F_Code_Meaning ('BANCOS', a.banco) banco,
                                  a.cuenta_bancaria,
                                  a.cheque,
                                  a.deposito,
                                  a.autorizacion,
                                  Wms_F_Facturas_Recibo (b.documento)
                                     facturas
                           FROM   WMS_PAGO_DOCUMENTOS a, WMS_DOCUMENTOS b
                          WHERE       a.documento = b.documento
                                  AND b.jornada IN (5)
                                  AND a.tipo_pago = 25
                                  AND b.tipo_documento = 'R'
                                  AND NVL (b.situacion, 1) <> 11);
         --GIFT CARD VENTA - certificados de regalo emitidos
         ELSIF p_rubro = 561
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        total
                 FROM   (  SELECT   b.documento,
                                    b.serie || ' ' || b.no_documento
                                       no_documento,
                                    DECODE (
                                       tipo_documento,
                                       'F',
                                       ROUND (
                                          NVL (
                                             SUM( (  NVL (precio_unitario, 0)
                                                   - NVL (descuento, 0)
                                                   + NVL (a.impuesto, 0))
                                                 * cantidad),
                                             0
                                          ),
                                          2
                                       ),
                                       ROUND (
                                          NVL (
                                             SUM( (  NVL (precio_unitario, 0)
                                                   - NVL (descuento, 0)
                                                   + NVL (a.impuesto, 0))
                                                 * cantidad),
                                             0
                                          ),
                                          2
                                       )
                                       * -1
                                    )
                                       total
                             FROM   wms_skus_x_documento a, wms_documentos b
                            WHERE       a.documento = b.documento
                                    AND a.usuario_anulo IS NULL
                                    AND b.tipo_documento IN ('F')
                                    AND NVL (b.situacion, 1) <> 11
                                    AND a.sku = cg_f_parameter_value ('SPIC')
                                    AND b.jornada = p_jornada
                                    AND WMS_F_FACTANUL (B.DOCUMENTO) <> 0
                         GROUP BY   b.documento,
                                    b.serie || ' ' || b.no_documento,
                                    tipo_documento);
         -- retiros de jornada COLONES
         ELSIF p_rubro = 562
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2,
                                                        texto2,
                                                        monto3)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        deposito,
                        total,
                        moneda,
                        tipo_cambio
                 FROM   (SELECT   no_deposito deposito,
                                  (DEPOSITO * NVL (tasa_cambio, 1)) total,
                                  CG_F_CODE_MEANING ('MONEDA', moneda) moneda,
                                  tasa_cambio tipo_cambio
                           FROM   wms_retiros
                          WHERE       jornada = p_jornada
                                  AND ANULADO_EL IS NULL
                                  AND MONEDA = 1);
         -- retiros de jornada DOLARES
         ELSIF p_rubro = 617
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2,
                                                        texto2,
                                                        monto3)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        deposito,
                        total,
                        moneda,
                        tipo_cambio
                 FROM   (SELECT   no_deposito deposito,
                                  (DEPOSITO) total,
                                  CG_F_CODE_MEANING ('MONEDA', moneda) moneda,
                                  tasa_cambio tipo_cambio
                           FROM   wms_retiros
                          WHERE       jornada = p_jornada
                                  AND ANULADO_EL IS NULL
                                  AND MONEDA = 2);
         -- FONABE
         ELSIF p_rubro = 592
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        comprobante,
                        total
                 FROM   (SELECT   (   B.SERIE
                                   || '-'
                                   || B.NO_DOCUMENTO
                                   || ' ('
                                   || A.IDCASHB
                                   || ')')
                                     COMPROBANTE,
                                  A.EFECTIVO_ENTREGADO TOTAL
                           FROM   WMS_CASHBACK A, WMS_DOCUMENTOS B
                          WHERE       A.DOCUMENTO = B.DOCUMENTO
                                  AND A.jornada = p_jornada
                                  AND A.ANULADO_EL IS NULL);
         --FONABE --RESUMEN
         ELSIF p_rubro = 593
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        comprobante,
                        total
                 FROM   (SELECT   (   B.SERIE
                                   || '-'
                                   || B.NO_DOCUMENTO
                                   || ' ('
                                   || A.IDCASHB
                                   || ')')
                                     COMPROBANTE,
                                  A.EFECTIVO_ENTREGADO TOTAL
                           FROM   WMS_CASHBACK A, WMS_DOCUMENTOS B
                          WHERE       A.DOCUMENTO = B.DOCUMENTO
                                  AND A.jornada = p_jornada
                                  AND A.ANULADO_EL IS NULL);
         --CAJA CHICA
         ELSIF p_rubro = 594
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        total
                 FROM   (SELECT   A.IDCAJACH COMPROBANTE, A.MONTO TOTAL
                           FROM   WMS_CAJACHICA A
                          WHERE   A.jornada = p_jornada
                                  AND A.ANULADO_EL IS NULL);
         --CAJA CHICA --RESUMEN
         ELSIF p_rubro = 595
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        total
                 FROM   (SELECT   A.IDCAJACH COMPROBANTE, A.MONTO TOTAL
                           FROM   WMS_CAJACHICA A
                          WHERE   A.jornada = p_jornada
                                  AND A.ANULADO_EL IS NULL);
         --BN SERVICIOS
         ELSIF p_rubro = 607
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        total
                 FROM   (SELECT   A.RECIBO COMPROBANTE, A.MONTO TOTAL
                           FROM   WMS_V_BNSERVICIOS A
                          WHERE   A.jornada = p_jornada);
         --PAGO TARJETAS BAC COLONES
         ELSIF p_rubro = 628
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        total
                 FROM   (SELECT   A.RECIBO COMPROBANTE, A.MONTO TOTAL
                           FROM   WMS_V_TARJBAC_COLON A
                          WHERE   A.jornada = p_jornada);
         --PAGO TARJETAS BAC DOLARES
         ELSIF p_rubro = 629
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        total
                 FROM   (SELECT   A.RECIBO COMPROBANTE,
                                  A.CMONTO_RECIBIDO TOTAL
                           FROM   WMS_V_TARJBAC_DOLAR A
                          WHERE   A.jornada = p_jornada);
         ---DEPOSITOS A CUENTA BANCARIA BAC COLONES

         ELSIF p_rubro = 630
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        total
                 FROM   (SELECT   A.RECIBO COMPROBANTE, A.DEPOSITO TOTAL
                           FROM   wms_v_depositobac_coloncc A
                          WHERE   A.jornada = p_jornada);
         --DEPOSITOS A CUENTA BANCARIA BAC DOLARES
         ELSIF p_rubro = 631
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        total
                 FROM   (SELECT   A.RECIBO COMPROBANTE, A.DEPOSITO TOTAL
                           FROM   wms_v_depositobac_dolarcc A
                          WHERE   A.jornada = p_jornada);
         ---RETIROS A CUENTA BANCARIA RAPIBAC COLONES

         ELSIF p_rubro = 632
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        total
                 FROM   (SELECT   A.RECIBO COMPROBANTE, A.RETIRO TOTAL
                           FROM   wms_v_retirosbac_coloncc A
                          WHERE   A.jornada = p_jornada);
         --VUELTOS TARJETAS BAC TODOS SON EN COLONES INDIFERENTE SI LAS TARJETAS SON EN COLONES O DOLARES
         ELSIF p_rubro = 918
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        total
                 FROM   (SELECT   A.RECIBO COMPROBANTE, A.CVUELTO TOTAL
                           FROM   WMS_V_TARJBAC_DOLAR A
                          WHERE   A.jornada = p_jornada);
         --VUELTOS DEPOSITOS BAC COLONES Y DOLARES
         ELSIF p_rubro = 919
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        total
                 FROM   (SELECT   A.RECIBO COMPROBANTE, A.CVUELTO TOTAL
                           FROM   wms_v_depositosbac A
                          WHERE   A.jornada = p_jornada);
         --RECARGAS
         ELSIF p_rubro = 608
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        total
                 FROM   (SELECT   A.RECIBO COMPROBANTE, A.MONTO TOTAL
                           FROM   WMS_V_RECARGAS2 A
                          WHERE   A.jornada = p_jornada);
         --RECARGAS NIC
         ELSIF p_rubro = 614
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        total
                 FROM   (SELECT   A.RECIBO COMPROBANTE, A.MONTO TOTAL
                           FROM   WMS_V_RECARGSNIC A
                          WHERE   A.jornada = p_jornada);
         --PAGOSCREDITO
         ELSIF p_rubro = 612
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        comprobante,
                        MONTO
                 FROM   (SELECT   A.referencia comprobante, A.MONTO
                           FROM   wms_v_pagoscredito A
                          WHERE   A.jornada = p_jornada);
         -- PUNTOS
         ELSIF p_rubro = 624
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        MONTO
                 FROM   (SELECT   A.NO_DOCUMENTO COMPROBANTE, A.MONTO
                           FROM   POS_V_PUNTOSCC A
                          WHERE   A.jornada = p_jornada AND A.MONTO > 0);
         -- FICHAS EXTRAVIADAS
         ELSIF p_rubro = 625
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        MONTO
                 FROM   (SELECT   A.NO_DOCUMENTO COMPROBANTE, A.MONTO
                           FROM   POS_V_FICHAS_EXTRAVIADASCC A
                          WHERE   A.jornada = p_jornada AND A.MONTO > 0);
         -- FICHAS EXTRAVIADAS ANULADAS
         ELSIF p_rubro = 626
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        MONTO
                 FROM   (SELECT   A.NO_DOCUMENTO COMPROBANTE, A.MONTO
                           FROM   POS_V_ANULFICHAS_EXTRAVIADASCC A
                          WHERE   A.jornada = p_jornada);
         -- VALES POR RIFA
         ELSIF p_rubro = 906
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        MONTO
                 FROM   (SELECT   VALE COMPROBANTE, MONTO
                           FROM   DOC_VALES
                          WHERE       TIPO = 'R'
                                  AND JORNADA = p_JORNADA
                                  AND BODEGA = CG_F_PARAMETER_VALUE ('BREE'));
         ---- FONDO DISPONIBLE WESTERNUNION
         ELSIF p_rubro = '917'
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        0,
                        'FONDODISPWU',
                        NVL (wu_f_fondodispwu (p_jornada), 0) MONTO
                 FROM   DUAL;
         -- MARCHAMOS --

         -- Colones
         ELSIF p_rubro = 909
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        MONTO
                 FROM   (SELECT   A.NO_DOCUMENTO COMPROBANTE, A.MONTO
                           FROM   POS_V_MARCHAMOS_EFECTIVOCC A
                          WHERE       TIPO_MONEDA = 1
                                  AND A.jornada = p_jornada
                                  AND A.MONTO > 0);
         -- Credi-e
         ELSIF p_rubro = 911
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        MONTO
                 FROM   (SELECT   A.NO_DOCUMENTO COMPROBANTE, A.MONTO
                           FROM   POS_V_MARCHAMOS_CREDIECC A
                          WHERE   A.jornada = p_jornada AND A.MONTO > 0);
         -- FIN MARCHAMOS --


         --WESTERN UNION
         ELSIF p_rubro = 913
         THEN                                                       --Pagos WU
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        total
                 FROM   (SELECT   A.RECIBO COMPROBANTE, A.MONTO TOTAL
                           FROM   wms_v_WesternUnion A
                          WHERE   A.TIPO = 'P' AND A.jornada = p_jornada);
         ELSIF p_rubro = 914
         THEN                                                  --Envios WU Col
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        total
                 FROM   (SELECT   A.RECIBO COMPROBANTE, A.MONTO TOTAL
                           FROM   wms_v_WesternUnion A
                          WHERE   A.TIPO = 'EC' AND A.jornada = p_jornada);
         ELSIF p_rubro = 915
         THEN                                                  --Envios WU Dol
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        total
                 FROM   (SELECT   A.RECIBO COMPROBANTE, A.MONTO TOTAL
                           FROM   wms_v_WesternUnion A
                          WHERE   A.TIPO = 'ED' AND A.jornada = p_jornada);
         ELSIF p_rubro = 916
         THEN                                                  --Vuelto WU Col
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        COMPROBANTE,
                        total
                 FROM   (SELECT   A.RECIBO COMPROBANTE, A.MONTO TOTAL
                           FROM   wms_v_WesternUnion A
                          WHERE   A.TIPO = 'VC' AND A.jornada = p_jornada);
         ELSIF p_rubro = 563
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        total
                 FROM   (SELECT   serie || ' ' || no_documento no_documento,
                                  sr3_f_total_documento (documento) total
                           FROM   wms_documentos a
                          WHERE       a.tipo_documento = 'F'
                                  AND NVL (apartado, 'N') = 'S'
                                  AND a.jornada = p_jornada
                                  AND NVL (a.fecha_emision, SYSDATE) <
                                        NVL (a.fecha_vencimiento,
                                             NVL (a.fecha_emision, SYSDATE))
                                  AND WMS_F_FACTANUL (a.documento) <> 0);
         --total a depositar
         ELSIF p_rubro = 564
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        total
                 FROM   ( /*SE MODIFICO PARA QUE SALGAN LAS FACTURAS Y NOTAS DE CREDITO IMGF*/
                         SELECT     e.serie || '-' || e.no_documento
                                       no_documento,
                                    SUM(DECODE (
                                           Cg_F_Parameter_Value ('MOJO'),
                                           'MB',
                                           c.valor,
                                           c.valor / NVL (a.tasa_cambio_ma, 1)
                                        ))
                                       total
                             FROM   WMS_DOCUMENTOS a,
                                    WMS_SOCIOS b,
                                    wms_pago_documentos c,
                                    doc_abono_documentos d,
                                    wms_documentos e
                            WHERE       a.tipo_documento = 'R'
                                    AND A.DOCUMENTO = C.DOCUMENTO
                                    AND C.TIPO_PAGO = '3'
                                    AND a.socio = b.socio(+)
                                    AND a.jornada IN (p_jornada)
                                    AND NVL (a.situacion, 1) <> 11
                                    AND C.MONEDA NOT IN (2, 8)  --ACC 01122020
                                    AND d.recibo = a.documento
                                    AND d.documento = e.documento
                                    AND NVL (e.fecha_vencimiento,
                                             e.fecha_emision) =
                                          NVL (e.fecha_emision, SYSDATE)
                                    AND WMS_F_FACTANUL (E.DOCUMENTO) <> 0
                         GROUP BY   e.serie, e.no_documento
                         UNION ALL
                         /*SELECT a.serie||' '||a.no_documento no_documento,
                                    DECODE (Cg_F_Parameter_Value ('MOJO'), 'MB', c.valor, c.valor/ NVL (a.tasa_cambio_ma, 1)) total
                             FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b, wms_pago_documentos c, wms_documentos f, doc_Abono_documentos d
                             WHERE  a.tipo_documento = 'R'
                             AND   A.DOCUMENTO = C.DOCUMENTO
                             AND  C.TIPO_PAGO = '3'
                             AND    a.socio = b.socio(+)
                             AND    a.jornada IN ( p_jornada )
                             AND    NVL (a.situacion, 1) <> 11
                             AND    a.documento = d.recibo
                             AND    d.documento = f.documento
                             and    trunc(nvl( f.fecha_vencimiento,f.fecha_emision)) <> trunc(f.fecha_emision)
                             and    wms_F_pago_asociaciones(a.documento) = 0 -- EXCLUIMOS LAS FACTURAS CON PAGOS A ASOCIACIONES
                             AND   WMS_F_FACTANUL(NVL(A.DOCUMENTO_PADRE, 1)) <> 0*/
                         SELECT   DISTINCT
                                  a.serie || ' ' || a.no_documento
                                     no_documento,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c,
                                  wms_documentos f,
                                  doc_Abono_documentos d
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '3'
                                  AND C.MONEDA NOT IN (2, 8)    --ACC 01122020
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.documento = d.recibo
                                  AND d.documento = f.documento
                                  AND TRUNC(NVL (f.fecha_vencimiento,
                                                 f.fecha_emision)) <>
                                        TRUNC (f.fecha_emision)
                                  AND wms_F_pago_asociaciones (a.documento) =
                                        0 -- EXCLUIMOS LAS FACTURAS CON PAGOS A ASOCIACIONES
                                  AND WMS_F_FACTANUL (
                                        NVL (A.DOCUMENTO_PADRE, 1)
                                     ) <> 0
                         UNION ALL
                         SELECT      a.serie_padre
                                  || ' '
                                  || a.no_documento_padre
                                     no_documento,
                                  (DECODE (
                                      Cg_F_Parameter_Value ('MOJO'),
                                      'MB',
                                      a.total,
                                      a.total / NVL (a.tasa_cambio_ma, 1)
                                   )
                                   * -1)
                                     total
                           FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b
                          WHERE       a.tipo_documento = 'D'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND a.SUBTIPO_DOCUMENTO = 'D'
                                  AND NVL (a.situacion, 1) <> 11
                         UNION ALL                                    --FONABE
                         SELECT   (   B.SERIE
                                   || '-'
                                   || B.NO_DOCUMENTO
                                   || ' ('
                                   || A.IDCASHB
                                   || ')')
                                     NO_DOCUMENTO,
                                  (A.EFECTIVO_ENTREGADO * -1) TOTAL
                           FROM   WMS_CASHBACK A, WMS_DOCUMENTOS B
                          WHERE       A.DOCUMENTO = B.DOCUMENTO
                                  AND A.jornada = p_jornada
                                  AND A.ANULADO_EL IS NULL
                         UNION ALL                                --CAJA CHICA
                         SELECT   TO_CHAR (A.IDCAJACH) NO_DOCUMENTO,
                                  (A.MONTO * -1) TOTAL
                           FROM   WMS_CAJACHICA A
                          WHERE   A.JORNADA = P_JORNADA
                                  AND A.ANULADO_EL IS NULL
                         UNION ALL
                         SELECT   A.RECIBO NO_DOCUMENTO, A.MONTO TOTAL
                           FROM   WMS_V_BNSERVICIOS A
                          WHERE   A.jornada = p_jornada
                         UNION ALL
                         ---DEPOSITO BAC
                         SELECT   A.RECIBO NO_DOCUMENTO, (CVUELTO * -1) TOTAL
                           FROM   wms_v_depositosbac A
                          WHERE   A.jornada = p_jornada
                         UNION ALL
                         SELECT   A.RECIBO NO_DOCUMENTO, A.MONTO TOTAL
                           FROM   wms_v_depositobac_colon A
                          WHERE   A.jornada = p_jornada
                         UNION ALL
                         SELECT   A.RECIBO NO_DOCUMENTO, (A.MONTO * -1) TOTAL
                           FROM   wms_v_retirosbac_colon A
                          WHERE   A.jornada = p_jornada
                         UNION ALL
                         SELECT   A.RECIBO NO_DOCUMENTO,
                                  A.CMONTO_RECIBIDO TOTAL
                           FROM   WMS_V_TARJBAC_COLON A
                          WHERE   A.jornada = p_jornada
                         UNION ALL
                         SELECT   A.RECIBO NO_DOCUMENTO, A.MONTO TOTAL
                           FROM   WMS_V_RECARGAS2 A
                          WHERE   A.jornada = p_jornada
                         UNION ALL
                         SELECT   TO_CHAR (A.JORNADA) NO_DOCUMENTO,
                                  A.MONTO TOTAL
                           FROM   wms_v_pagoscredito A
                          WHERE   A.jornada = p_jornada
                         UNION ALL
                         SELECT   NO_DOCUMENTO, MONTO
                           FROM   POS_V_MARCHAMOS_EFECTIVOCC
                          WHERE   JORNADA = p_JORNADA AND TIPO_MONEDA = 1
                         UNION ALL
                         SELECT   D.serie || ' ' || D.no_documento
                                     no_documento,
                                  R.PAGACON - R.VUELTO MONTO
                           FROM   WMS_HABLAMAS_REQ R,
                                  WMS_PAGUE_SERVICIOS S,
                                  WMS_DOCUMENTOS D
                          WHERE       R.JORNADA = p_jornada
                                  AND R.CODSTATE = 0
                                  AND R.Moneda = 1
                                  AND D.DOCUMENTO = S.DOCUMENTO
                                  AND S.TIPO_SERVICIO = '04'
                                  AND S.TRANS_PROVEEDOR = R.ID --PAGO EN EFECTIVO RECARGAS NICARAGUA
                         UNION ALL
                         SELECT   e.serie || ' ' || e.no_documento
                                     no_documento,
                                  (c.PAGADO - c.VALOR) * -1 vuelto
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c,
                                  doc_abono_documentos d,
                                  wms_documentos e
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.MONEDA = WMS_F_MONEDA_ALTERNA
                                  AND C.TIPO_PAGO = '3'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND d.recibo = a.documento
                                  AND d.documento = e.documento
                                  AND NVL (e.fecha_vencimiento,
                                           e.fecha_emision) =
                                        NVL (e.fecha_emision, SYSDATE)
                                  AND WMS_F_FACTANUL (NVL (E.DOCUMENTO, 1)) <>
                                        0
                         UNION ALL
                         SELECT   B.SERIE || '-' || B.NO_DOCUMENTO
                                     NO_DOCUMENTO,
                                  ( (A.PAGADO - A.VALOR) * -1) VUELTO
                           FROM      WMS_PAGO_DOCUMENTOS A
                                  INNER JOIN
                                     WMS_DOCUMENTOS B
                                  ON B.DOCUMENTO_PADRE IS NULL
                                     AND A.DOCUMENTO = B.DOCUMENTO
                          WHERE       A.TIPO_PAGO = 3
                                  AND NVL (SITUACION, 3) <> 11
                                  AND A.MONEDA = WMS_F_MONEDA_ALTERNA
                                  AND B.JORNADA = p_JORNADA
                                  AND NVL (B.FECHA_VENCIMIENTO,
                                           B.FECHA_EMISION) =
                                        NVL (B.FECHA_EMISION, SYSDATE)
                         UNION ALL
                         SELECT   D.serie || ' ' || D.no_documento
                                     no_documento,
                                  R.VUELTO * -1 MONTO
                           FROM   WMS_HABLAMAS_REQ R,
                                  WMS_PAGUE_SERVICIOS S,
                                  WMS_DOCUMENTOS D
                          WHERE       R.JORNADA = p_jornada
                                  AND R.CODSTATE = 0
                                  AND R.Moneda = 2
                                  AND D.DOCUMENTO = S.DOCUMENTO
                                  AND S.TIPO_SERVICIO = '04'
                                  AND S.TRANS_PROVEEDOR = R.ID --VUELTOS PAGOS RECARGAS NICARAGUA
                         UNION ALL
                         SELECT   B.NO_DOCUMENTO NO_DOCUMENTO,
                                  ( (A.PAGADO - A.VALOR) * -1) VUELTO
                           FROM         WMS_PAGO_DOCUMENTOS A
                                     INNER JOIN
                                        WMS_DOCUMENTOS B
                                     ON A.DOCUMENTO = B.DOCUMENTO
                                  INNER JOIN
                                     AM_RECIBO_IN C
                                  ON B.DOCUMENTO_PADRE = C.DOCUMENTO
                          WHERE       A.TIPO_PAGO = 3
                                  AND NVL (SITUACION, 3) <> 11
                                  AND A.MONEDA = WMS_F_MONEDA_ALTERNA
                                  AND B.JORNADA = p_JORNADA
                                  AND NVL (B.FECHA_VENCIMIENTO,
                                           B.FECHA_EMISION) =
                                        NVL (B.FECHA_EMISION, SYSDATE)
                         UNION ALL
                         SELECT   f.serie || ' ' || f.no_documento
                                     no_documento,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c,
                                  wms_documentos f,
                                  doc_Abono_documentos d
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '3'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_JORNADA)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.documento = d.recibo
                                  AND d.documento = f.documento
                                  AND TRUNC(NVL (f.fecha_vencimiento,
                                                 f.fecha_emision)) <>
                                        TRUNC (f.fecha_emision)
                                  AND wms_F_pago_asociaciones (a.documento) <>
                                        0 -- EXCLUIMOS LAS FACTURAS CON PAGOS A ASOCIACIONES
                         UNION ALL
                         SELECT   a.serie || ' ' || a.no_documento
                                     no_documento,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '3'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_JORNADA)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND A.DOCUMENTO NOT IN
                                           (SELECT   RECIBO
                                              FROM   DOC_ABONO_DOCUMENTOS
                                             WHERE   RECIBO = A.DOCUMENTO)
                                  AND wms_F_pago_asociaciones (a.documento) <>
                                        0 -- EXCLUIMOS LAS FACTURAS CON PAGOS A ASOCIACIONES
                         UNION ALL
                         SELECT   A.RECIBO NO_DOCUMENTO, (A.MONTO * -1) TOTAL
                           FROM   wms_v_westernunion A
                          WHERE   A.tipo = 'P' AND A.jornada = p_jornada --RESTA LOS PAGOS WU
                         UNION ALL
                         SELECT   A.RECIBO NO_DOCUMENTO, (A.MONTO) TOTAL
                           FROM   wms_v_westernunion A
                          WHERE   A.tipo = 'EC' AND A.jornada = p_jornada --ENVIOS COLONES WU
                         UNION ALL
                         SELECT   A.RECIBO NO_DOCUMENTO, (A.MONTO * -1) TOTAL
                           FROM   wms_v_westernunion A
                          WHERE   A.tipo = 'VC' AND A.jornada = p_jornada --RESTA LOS VUELTOS WU
                         UNION ALL
                         SELECT   'IFWU - ' || IDFONDO NO_DOCUMENTO,
                                  monto TOTAL
                           FROM   WU_FONDOS
                          WHERE       TIPO = 'I'
                                  AND ANULADO_EL IS NULL
                                  AND jornada = p_jornada --INGRESOS DE FONDO WESTERNUNION
                         UNION ALL
                         SELECT   'SFWU - ' || IDFONDO NO_DOCUMENTO,
                                  (monto * -1) TOTAL
                           FROM   WU_FONDOS
                          WHERE       TIPO = 'S'
                                  AND ANULADO_EL IS NULL
                                  AND jornada = p_jornada --RESTA LAS SALIDAS DEL FONDO WESTERNUNION
                         UNION ALL
                         SELECT   'FONDODISPWU',
                                  (wu_f_fondodispwu (p_jornada) * -1) TOTAL
                           FROM   DUAL
                          WHERE   wu_f_fondodispwu (p_jornada) > 0 --RESTA EL FONDO DISPONIBLE DE WESTERNUNION, YA QUE TIENE OTRO TIPO DE SALIDA DIFERENTE AL RETIRO
                         UNION ALL
                         SELECT   a.serie || ' ' || a.no_documento
                                     no_documento,
                                  DECODE (Cg_F_Parameter_Value ('MOJO'),
                                          'MB', d.cvuelto * -1,
                                          d.cvuelto * -1)
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pague_servicios c,
                                  wms_bacserv_res_a d
                          WHERE       a.tipo_documento = 'R'
                                  AND a.documento = c.documento
                                  AND a.socio = b.socio(+)
                                  AND c.trans_proveedor = d.nnumcomprobante
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND NVL (a.fecha_vencimiento,
                                           a.fecha_emision) =
                                        NVL (a.fecha_emision, SYSDATE)
                                  AND WMS_F_FACTANUL (a.documento) <> 0
                                  AND C.PROVEEDOR = '12');
         --total a depositar dolares
         ELSIF p_rubro = 618
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        total
                 FROM   (SELECT   a.no_documento, valor_moneda total
                           FROM   wms_documentos a,
                                  wms_pago_documentos b,
                                  wms_documentos d
                          WHERE       a.documento = b.documento
                                  AND a.jornada = p_jornada
                                  AND b.tipo_pago = 3
                                  AND a.documento_padre = d.documento
                                  AND NVL (a.situacion, 3) <> 11
                                  AND wms_f_factanul (d.documento) <> 0
                                  AND a.serie LIKE 'C%'
                                  AND b.moneda IN (2, 8)        --ACC 01122020
                         UNION ALL
                         SELECT   A.RECIBO NO_DOCUMENTO,
                                  A.CMONTO_RECIBIDO TOTAL
                           FROM   WMS_V_TARJBAC_DOLAR A
                          WHERE   A.jornada = p_jornada
                         UNION ALL
                         SELECT   A.RECIBO NO_DOCUMENTO,
                                  A.CMONTO_RECIBIDO TOTAL
                           FROM   wms_v_depositosbac A
                          WHERE   A.jornada = p_jornada
                         UNION ALL
                         SELECT   a.no_documento, valor_moneda total
                           FROM   wms_documentos a, wms_pago_documentos b
                          WHERE       a.documento = b.documento
                                  AND a.jornada = p_jornada
                                  AND b.tipo_pago = 3
                                  AND NVL (a.situacion, 3) <> 11
                                  AND a.serie NOT LIKE 'C%'
                                  AND b.moneda IN (2, 8)        --ACC 01122020
                         UNION ALL                              --recargas nic
                         SELECT   D.NO_DOCUMENTO, R.PAGACON TOTAL
                           FROM   WMS_HABLAMAS_REQ R,
                                  WMS_PAGUE_SERVICIOS S,
                                  WMS_DOCUMENTOS D
                          WHERE       R.JORNADA = p_jornada
                                  AND R.CODSTATE = 0
                                  AND R.Moneda = 2
                                  AND D.DOCUMENTO = S.DOCUMENTO
                                  AND S.TIPO_SERVICIO = '04'
                                  AND S.TRANS_PROVEEDOR = R.ID
                         UNION ALL
                         SELECT   A.RECIBO NO_DOCUMENTO, (A.MONTO) TOTAL
                           FROM   wms_v_westernunion A
                          WHERE   A.tipo = 'EDR' AND A.jornada = p_jornada --ENVIOS DOLARES WU
                                                                          );
         --sobrante faltante
         ELSIF p_rubro = 565
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        total
                 FROM   (SELECT   'TOTAL A DEPOSITAR' no_documento,
                                  (SUM (total) * -1) total
                           FROM   (SELECT   SUM(DECODE (
                                                   Cg_F_Parameter_Value (
                                                      'MOJO'
                                                   ),
                                                   'MB',
                                                   c.valor,
                                                   c.valor
                                                   / NVL (a.tasa_cambio_ma,
                                                          1)
                                                ))
                                               total
                                     FROM   WMS_DOCUMENTOS a,
                                            WMS_SOCIOS b,
                                            wms_pago_documentos c,
                                            doc_abono_documentos d,
                                            wms_documentos e
                                    WHERE       a.tipo_documento = 'R'
                                            AND A.DOCUMENTO = C.DOCUMENTO
                                            AND C.MONEDA NOT IN (2, 8) --ACC 01122020
                                            AND C.TIPO_PAGO IN (3, 36) ---= '3'
                                            AND a.socio = b.socio(+)
                                            AND a.jornada IN (p_jornada)
                                            AND NVL (a.situacion, 1) <> 11
                                            AND C.MONEDA NOT IN (2, 8) --ACC 01122020
                                            AND d.recibo = a.documento
                                            AND d.documento = e.documento
                                            AND NVL (e.fecha_vencimiento,
                                                     e.fecha_emision) =
                                                  NVL (e.fecha_emision,
                                                       SYSDATE)
                                            AND WMS_F_FACTANUL (E.DOCUMENTO) <>
                                                  0
                                   UNION ALL
                                   -- SE SUMA PAGOS EN EFECTIVO DE ASOCIACIONES
                                   SELECT   SUM(DECODE (
                                                   Cg_F_Parameter_Value (
                                                      'MOJO'
                                                   ),
                                                   'MB',
                                                   c.valor
                                                   / (SELECT   DECODE (
                                                                  COUNT ( * ),
                                                                  0,
                                                                  1,
                                                                  COUNT ( * )
                                                               )
                                                        FROM   DOC_ABONO_DOCUMENTOS Z
                                                       WHERE   Z.RECIBO =
                                                                  A.DOCUMENTO),
                                                   (c.valor
                                                    / (SELECT   DECODE (
                                                                   COUNT (
                                                                      *
                                                                   ),
                                                                   0,
                                                                   1,
                                                                   COUNT (
                                                                      *
                                                                   )
                                                                )
                                                         FROM   DOC_ABONO_DOCUMENTOS Z
                                                        WHERE   Z.RECIBO =
                                                                   A.DOCUMENTO))
                                                   / NVL (a.tasa_cambio_ma,
                                                          1)
                                                ))
                                               total
                                     FROM   WMS_DOCUMENTOS a,
                                            WMS_SOCIOS b,
                                            wms_pago_documentos c,
                                            wms_documentos f,
                                            doc_Abono_documentos d
                                    WHERE       a.tipo_documento = 'R'
                                            AND A.DOCUMENTO = C.DOCUMENTO
                                            AND C.TIPO_PAGO IN (3, 36) ---= '3'
                                            AND C.MONEDA NOT IN (2, 8) --ACC 01122020
                                            AND a.socio = b.socio(+)
                                            AND a.jornada IN (p_jornada)
                                            AND NVL (a.situacion, 1) <> 11
                                            AND a.documento = d.recibo
                                            AND d.documento = f.documento
                                            AND TRUNC(NVL (
                                                         f.fecha_vencimiento,
                                                         f.fecha_emision
                                                      )) <>
                                                  TRUNC (f.fecha_emision)
                                            AND wms_F_pago_asociaciones (
                                                  a.documento
                                               ) = 0 -- EXCLUIMOS LAS FACTURAS CON PAGOS A ASOCIACIONES
                                            AND WMS_F_FACTANUL (
                                                  NVL (A.DOCUMENTO_PADRE, 1)
                                               ) <> 0
                                            AND A.SOCIO <> 2
                                            AND A.SERIE LIKE 'C%'
                                   /*SELECT DECODE (Cg_F_Parameter_Value ('MOJO'), 'MB', D.valor, D.valor/ NVL (a.tasa_cambio_ma, 1)) total
                                   FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b, wms_pago_documentos c, wms_documentos f, doc_Abono_documentos d
                                   WHERE  a.tipo_documento = 'R'
                                   AND   A.DOCUMENTO = C.DOCUMENTO
                                   AND  C.TIPO_PAGO = '3'
                                   AND    a.socio = b.socio(+)
                                   AND    a.jornada IN ( p_jornada )
                                   AND    NVL (a.situacion, 1) <> 11
                                   AND    a.documento = d.recibo
                                   AND    d.documento = f.documento
                                   and    trunc(nvl( f.fecha_vencimiento,f.fecha_emision)) <> trunc(f.fecha_emision)
                                   and    wms_F_pago_asociaciones(a.documento) = 0 -- EXCLUIMOS LAS FACTURAS CON PAGOS A ASOCIACIONES*/
                                   UNION ALL
                                   SELECT   SUM(DECODE (
                                                   Cg_F_Parameter_Value (
                                                      'MOJO'
                                                   ),
                                                   'MB',
                                                   c.valor
                                                   / (SELECT   DECODE (
                                                                  COUNT ( * ),
                                                                  0,
                                                                  1,
                                                                  COUNT ( * )
                                                               )
                                                        FROM   DOC_ABONO_DOCUMENTOS Z
                                                       WHERE   Z.RECIBO =
                                                                  A.DOCUMENTO),
                                                   (c.valor
                                                    / (SELECT   DECODE (
                                                                   COUNT (
                                                                      *
                                                                   ),
                                                                   0,
                                                                   1,
                                                                   COUNT (
                                                                      *
                                                                   )
                                                                )
                                                         FROM   DOC_ABONO_DOCUMENTOS Z
                                                        WHERE   Z.RECIBO =
                                                                   A.DOCUMENTO))
                                                   / NVL (a.tasa_cambio_ma,
                                                          1)
                                                ))
                                               total
                                     FROM   WMS_DOCUMENTOS a,
                                            WMS_SOCIOS b,
                                            wms_pago_documentos c,
                                            wms_documentos f,
                                            doc_Abono_documentos d
                                    WHERE       a.tipo_documento = 'R'
                                            AND A.DOCUMENTO = C.DOCUMENTO
                                            AND C.TIPO_PAGO IN (3, 36) ---= '3'
                                            AND C.MONEDA NOT IN (2, 8) --ACC 01122020
                                            AND a.socio = b.socio(+)
                                            AND a.jornada IN (p_jornada)
                                            AND NVL (a.situacion, 1) <> 11
                                            AND a.documento = d.recibo
                                            AND d.documento = f.documento
                                            AND TRUNC(NVL (
                                                         f.fecha_vencimiento,
                                                         f.fecha_emision
                                                      )) <>
                                                  TRUNC (f.fecha_emision)
                                            AND wms_F_pago_asociaciones (
                                                  a.documento
                                               ) = 0 -- EXCLUIMOS LAS FACTURAS CON PAGOS A ASOCIACIONES
                                            AND WMS_F_FACTANUL (
                                                  NVL (A.DOCUMENTO_PADRE, 1)
                                               ) <> 0
                                            AND A.SERIE NOT LIKE 'C%'
                                   UNION ALL
                                   SELECT   SUM(DECODE (
                                                   Cg_F_Parameter_Value (
                                                      'MOJO'
                                                   ),
                                                   'MB',
                                                   c.valor,
                                                   c.valor
                                                   / NVL (a.tasa_cambio_ma,
                                                          1)
                                                ))
                                               total
                                     FROM   WMS_DOCUMENTOS a,
                                            WMS_SOCIOS b,
                                            wms_pago_documentos c
                                    WHERE       a.tipo_documento = 'R'
                                            AND A.DOCUMENTO = C.DOCUMENTO
                                            AND C.TIPO_PAGO IN (3, 36) ---= '3'
                                            AND C.MONEDA NOT IN (2, 8) --ACC 01122020
                                            AND a.socio = b.socio(+)
                                            AND a.jornada IN (p_jornada)
                                            AND NVL (a.situacion, 1) <> 11
                                            AND A.DOCUMENTO NOT IN
                                                     (SELECT   RECIBO
                                                        FROM   DOC_ABONO_DOCUMENTOS
                                                       WHERE   RECIBO =
                                                                  A.DOCUMENTO)
                                            AND wms_F_pago_asociaciones (
                                                  a.documento
                                               ) = 0 -- EXCLUIMOS LAS FACTURAS CON PAGOS A ASOCIACIONES
                                   UNION ALL
                                   SELECT   SUM( (DECODE (
                                                     Cg_F_Parameter_Value (
                                                        'MOJO'
                                                     ),
                                                     'MB',
                                                     a.total,
                                                     a.total
                                                     / NVL (a.tasa_cambio_ma,
                                                            1)
                                                  )
                                                  * -1))
                                               total
                                     FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b
                                    WHERE       a.tipo_documento = 'D'
                                            AND a.socio = b.socio(+)
                                            AND a.jornada IN (p_jornada)
                                            AND a.SUBTIPO_DOCUMENTO = 'D'
                                            AND NVL (a.situacion, 1) <> 11
                                   UNION ALL                          --FONABE
                                   SELECT   (A.EFECTIVO_ENTREGADO * -1) TOTAL
                                     FROM   WMS_CASHBACK A, WMS_DOCUMENTOS B
                                    WHERE       A.DOCUMENTO = B.DOCUMENTO
                                            AND A.jornada = p_jornada
                                            AND A.ANULADO_EL IS NULL
                                   UNION ALL                      --CAJA CHICA
                                   SELECT   (A.MONTO * -1) TOTAL
                                     FROM   WMS_CAJACHICA A
                                    WHERE   A.JORNADA = p_jornada
                                            AND A.ANULADO_EL IS NULL
                                   UNION ALL
                                   SELECT   A.MONTO TOTAL
                                     FROM   WMS_V_BNSERVICIOS A
                                    WHERE   A.jornada = p_jornada
                                   UNION ALL
                                   SELECT   DD.MONTO TOTAL
                                     FROM   WMS_V_PAGOSCREDITO DD
                                    WHERE   DD.JORNADA = p_jornada
                                   UNION ALL
                                   SELECT   A.MONTO TOTAL
                                     FROM   WMS_V_RECARGAS2 A
                                    WHERE   A.jornada = p_jornada
                                   UNION ALL
                                   SELECT   WMS_F_DIFCOL_HABLAMAS (p_jornada)
                                               TOTAL
                                     FROM   DUAL
                                   /* UNION ALL
                                   SELECT A.MONTO TOTAL
                                         FROM   WMS_V_RECARGSNIC A
                                         WHERE A.jornada = p_jornada  */
                                   UNION ALL
                                   SELECT   DECODE (
                                               Cg_F_Parameter_Value ('MOJO'),
                                               'MB',
                                               c.valor,
                                               c.valor
                                               / NVL (a.tasa_cambio_ma, 1)
                                            )
                                               total
                                     FROM   WMS_DOCUMENTOS a,
                                            WMS_SOCIOS b,
                                            wms_pago_documentos c,
                                            wms_documentos f,
                                            doc_Abono_documentos d
                                    WHERE       a.tipo_documento = 'R'
                                            AND A.DOCUMENTO = C.DOCUMENTO
                                            AND C.TIPO_PAGO IN (3, 36) ---= '3'
                                            AND a.socio = b.socio(+)
                                            AND a.jornada IN (p_jornada)
                                            AND NVL (a.situacion, 1) <> 11
                                            AND a.documento = d.recibo
                                            AND d.documento = f.documento
                                            AND TRUNC(NVL (
                                                         f.fecha_vencimiento,
                                                         f.fecha_emision
                                                      )) <>
                                                  TRUNC (f.fecha_emision)
                                            AND wms_F_pago_asociaciones (
                                                  a.documento
                                               ) <> 0 -- EXCLUIMOS LAS FACTURAS CON PAGOS A ASOCIACIONES
                                   UNION ALL
                                   SELECT   WMS_F_DIFCOL_WU (p_jornada) TOTAL
                                     FROM   DUAL    --DIFERENCIA EN COLONES WU
                                   UNION ALL
                                   SELECT   NVL (SUM (MONTO), 0)
                                     FROM   WU_FONDOS
                                    WHERE       JORNADA = p_jornada
                                            AND TIPO = 'I'
                                            AND ANULADO_EL IS NULL --INGRESOS AL FONDO
                                   UNION ALL
                                   SELECT   NVL (SUM (MONTO * -1), 0)
                                     FROM   WU_FONDOS
                                    WHERE       JORNADA = p_jornada
                                            AND TIPO = 'S'
                                            AND ANULADO_EL IS NULL --SALIDAS DEL FONDO
                                   UNION ALL
                                   SELECT   NVL (
                                               (wu_f_fondodispwu (p_jornada)
                                                * -1),
                                               0
                                            )
                                     FROM   DUAL
                                    WHERE   wu_f_fondodispwu (p_jornada) > 0 --FONDO DISPONIBLE
                                   UNION ALL
                                   SELECT   (B.MONTO * -1) TOTAL
                                     FROM   wms_v_retirosbac_colon B
                                    WHERE   B.jornada = p_jornada
                                   UNION ALL
                                   SELECT   (B.MONTO) TOTAL
                                     FROM   wms_v_depositobac_colon B
                                    WHERE   B.jornada = p_jornada)
                         UNION ALL
                         SELECT   'FONDO DISPONIBLE WESTERNUNION'
                                     no_documento,
                                  ROUND (
                                     NVL ( (wu_f_fondodispwu (p_jornada)), 0),
                                     2
                                  )
                                     total
                           FROM   DUAL
                         UNION ALL
                         SELECT   'TOTAL RETIROS' no_documento,
                                  ROUND (SUM (DEPOSITO * tasa_cambio), 2)
                                     total
                           FROM   wms_retiros
                          WHERE       jornada = p_jornada
                                  AND ANULADO_EL IS NULL
                                  AND MONEDA = 1
                         UNION ALL
                         SELECT   'TOTAL SISTEMA TARJETAS' no_documento,
                                  (ROUND (SUM (A.TOTAL_SISTEMA), 2) * -1)
                                     TOTAL
                           FROM   WMS_CIERREC_BANCOS A, WMS_JORNADAS B
                          WHERE   B.JORNADA = A.JORNADA(+)
                                  AND B.JORNADA = p_JORNADA
                         UNION ALL
                         SELECT   'TOTAL ARQUEO TARJETAS' no_documento,
                                  ROUND (SUM (A.TOTAL_USUARIO), 2) TOTAL
                           FROM   WMS_CIERREC_BANCOS A, WMS_JORNADAS B
                          WHERE   B.JORNADA = A.JORNADA(+)
                                  AND B.JORNADA = p_JORNADA
                         UNION ALL
                         SELECT   e.serie || ' ' || e.no_documento
                                     no_documento,
                                  (c.PAGADO - c.VALOR) TOTAL
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c,
                                  doc_abono_documentos d,
                                  wms_documentos e
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.MONEDA = WMS_F_MONEDA_ALTERNA
                                  AND C.TIPO_PAGO IN (3, 36)          ---= '3'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_JORNADA)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND d.recibo = a.documento
                                  AND d.documento = e.documento
                                  AND NVL (e.fecha_vencimiento,
                                           e.fecha_emision) =
                                        NVL (e.fecha_emision, SYSDATE)
                                  AND WMS_F_FACTANUL (NVL (E.DOCUMENTO, 1)) <>
                                        0
                         UNION ALL
                         SELECT   B.SERIE || '-' || B.NO_DOCUMENTO
                                     NO_DOCUMENTO,
                                  (A.PAGADO - A.VALOR) TOTAL
                           FROM      WMS_PAGO_DOCUMENTOS A
                                  INNER JOIN
                                     WMS_DOCUMENTOS B
                                  ON B.DOCUMENTO_PADRE IS NULL
                                     AND A.DOCUMENTO = B.DOCUMENTO
                          WHERE       A.TIPO_PAGO IN (3, 36)           /*= 3*/
                                  AND NVL (SITUACION, 3) <> 11
                                  AND A.MONEDA = WMS_F_MONEDA_ALTERNA
                                  AND B.JORNADA = p_JORNADA
                                  AND NVL (B.FECHA_VENCIMIENTO,
                                           B.FECHA_EMISION) =
                                        NVL (B.FECHA_EMISION, SYSDATE)
                         UNION ALL
                         SELECT   B.NO_DOCUMENTO NO_DOCUMENTO,
                                  (A.PAGADO - A.VALOR) TOTAL
                           FROM         WMS_PAGO_DOCUMENTOS A
                                     INNER JOIN
                                        WMS_DOCUMENTOS B
                                     ON A.DOCUMENTO = B.DOCUMENTO
                                  INNER JOIN
                                     AM_RECIBO_IN C
                                  ON B.DOCUMENTO_PADRE = C.DOCUMENTO
                          WHERE       A.TIPO_PAGO IN (3, 36)           /*= 3*/
                                  AND NVL (SITUACION, 3) <> 11
                                  AND A.MONEDA = WMS_F_MONEDA_ALTERNA
                                  AND B.JORNADA = p_JORNADA
                                  AND NVL (B.FECHA_VENCIMIENTO,
                                           B.FECHA_EMISION) =
                                        NVL (B.FECHA_EMISION, SYSDATE)
                         UNION ALL                     -- COLONES TARJETAS BAC
                         SELECT   B.NO_DOCUMENTO NO_DOCUMENTO,
                                  (B.MONTO * -1) TOTAL
                           FROM   WMS_V_TARJBAC_COLON B
                          WHERE   B.jornada = p_jornada
                         UNION ALL           --VUELTOS DE TARJETAS BAC DOLARES
                         SELECT   a.NO_DOCUMENTO, a.cvuelto TOTAL
                           FROM   WMS_V_TARJBAC_DOLAR a
                          WHERE   a.jornada = p_jornada
                         ----  UNION ALL -- COLONES DEPOSITOS BAC
                         --- SELECT 'DEPOSITOS RAPIBAC' no_documento, (B.MONTO) TOTAL
                         ---  FROM   wms_v_depositobac_colon B
                         ----  WHERE B.jornada = p_jornada
                         UNION ALL           --VUELTOS DE TARJETAS BAC DOLARES
                         SELECT   'VUELTOS RAPIBAC' no_documento,
                                  (a.cvuelto * -1) TOTAL
                           FROM   wms_v_depositosbac a
                          WHERE   a.jornada = p_jornada---  UNION ALL -- COLONES retiros BAC
                                                       ----  SELECT 'RETIROS RAPIBAC' no_documento, (B.MONTO * -1) TOTAL
                                                       ---   FROM   wms_v_retirosbac_colon B
                                                       ----  WHERE B.jornada = p_jornada

                        );
         --sobrante faltante Dolares
         ELSIF p_rubro = 619
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        total
                 FROM   (SELECT   'TOTAL A DEPOSITAR' no_documento,
                                  (SUM (total) * -1) total
                           FROM   (SELECT   SUM (total) total
                                     FROM   (SELECT   a.no_documento,
                                                      valor_moneda total
                                               FROM   wms_documentos a,
                                                      wms_pago_documentos b,
                                                      wms_documentos d
                                              WHERE   a.documento =
                                                         b.documento
                                                      AND a.jornada =
                                                            p_jornada
                                                      AND b.tipo_pago = 3
                                                      AND a.documento_padre =
                                                            d.documento
                                                      AND NVL (a.situacion,
                                                               3) <> 11
                                                      AND wms_f_factanul (
                                                            d.documento
                                                         ) <> 0
                                                      AND a.serie LIKE 'C%'
                                                      AND b.moneda IN (2, 8) --ACC 01122020
                                             UNION ALL
                                             SELECT   a.no_documento,
                                                      valor_moneda total
                                               FROM   wms_documentos a,
                                                      wms_pago_documentos b
                                              WHERE   a.documento =
                                                         b.documento
                                                      AND a.jornada =
                                                            p_jornada
                                                      AND b.tipo_pago = 3
                                                      AND NVL (a.situacion,
                                                               3) <> 11
                                                      AND a.serie NOT LIKE
                                                            'C%'
                                                      AND b.moneda IN (2, 8) --ACC 01122020
                                             UNION ALL          --recargas nic
                                             SELECT   D.NO_DOCUMENTO,
                                                      R.PAGACON TOTAL
                                               FROM   WMS_HABLAMAS_REQ R,
                                                      WMS_PAGUE_SERVICIOS S,
                                                      WMS_DOCUMENTOS D
                                              WHERE   R.JORNADA = p_jornada
                                                      AND R.CODSTATE = 0
                                                      AND R.Moneda = 2
                                                      AND D.DOCUMENTO =
                                                            S.DOCUMENTO
                                                      AND S.TIPO_SERVICIO =
                                                            '04'
                                                      AND S.TRANS_PROVEEDOR =
                                                            R.ID
                                             UNION ALL             --ENVIOS WU
                                             SELECT   TO_CHAR (A.DOCUMENTO)
                                                         NO_DOCUMENTO,
                                                      NVL (A.MONTO, 0) TOTAL
                                               FROM   wms_v_westernunion A
                                              WHERE   A.JORNADA = p_JORNADA
                                                      AND A.TIPO IN ('EDR')
                                             UNION ALL  --DOLARES TARJETAS BAC
                                             SELECT   B.NO_DOCUMENTO
                                                         NO_DOCUMENTO,
                                                      B.CMONTO_RECIBIDO TOTAL
                                               FROM   WMS_V_TARJBAC_DOLAR B
                                              WHERE   B.jornada = p_jornada
                                             UNION ALL
                                             SELECT   B.NO_DOCUMENTO
                                                         NO_DOCUMENTO,
                                                      B.CMONTO_RECIBIDO TOTAL
                                               FROM   wms_v_depositosbac B
                                              WHERE   B.jornada = p_jornada))
                         UNION ALL
                         SELECT   'TOTAL RETIROS' no_documento,
                                  ROUND (SUM (DEPOSITO), 2) total
                           FROM   wms_retiros
                          WHERE       jornada = p_jornada
                                  AND ANULADO_EL IS NULL
                                  AND MONEDA = 2);
         --ventas exentas  sin impuesto sin descuento
         ELSIF p_rubro = 568
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   a.documento,
                                     a.serie
                                  || ' '
                                  || a.no_documento
                                  || ' ('
                                  || d.sku_alterno
                                  || ')'
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  ROUND (c.precio_unitario * c.cantidad, 8)
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  wms_socios b,
                                  wms_skus_x_documento c,
                                  wms_skus d
                          WHERE       a.tipo_documento IN ('F')
                                  AND a.jornada IN (p_jornada)
                                  AND a.documento = c.documento
                                  AND c.usuario_anulo IS NULL
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.socio = b.socio
                                  AND a.jornada IN (p_jornada)
                                  AND c.sku = d.sku
                                  --and    c.sku <> cg_f_parameter_value('SPIC')
                                  AND c.sku NOT IN
                                           (cg_f_parameter_value ('SPIC'),
                                            cg_f_parameter_value ('SFE'),
                                            WMS_F_BUSCAR_SKU (
                                               CG_F_PARAMETER_VALUE ('SADO')
                                            ),
                                            CG_F_PARAMETER_VALUE ('STR'))
                                  --and    nvl(d.impuesto,1) <> 0 -- VENTAS EXCENTAS SON A PRODUCTOS QUE NO PAGAN IMPUESTOS
                                  --AND    A.SOCIO_ES_EXCENTO IS NULL
                                  AND ROUND (NVL (c.impuesto, 0), 2) = 0);
         -- VENTAS A GRAVADAS  sin impuesto sin descuento
         ELSIF p_rubro = 569
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   a.documento,
                                     a.serie
                                  || ' '
                                  || a.no_documento
                                  || ' ('
                                  || d.sku_alterno
                                  || ')'
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  ROUND (c.precio_unitario * c.cantidad, 8)
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  wms_socios b,
                                  wms_skus_x_documento c,
                                  wms_skus d
                          WHERE       a.tipo_documento IN ('F')
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.socio = b.socio
                                  --AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                                  AND a.documento = c.documento
                                  AND c.usuario_anulo IS NULL
                                  AND c.sku = d.sku
                                  AND ROUND (NVL (c.impuesto, 0), 2) > 0);
         --and    WMS_F_FACTANUL(a.documento) <> 0  );

         --descuento exentos
         ELSIF p_rubro = 570
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   a.documento,
                                     a.serie
                                  || ' '
                                  || a.no_documento
                                  || ' ('
                                  || d.sku_alterno
                                  || ')'
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  ROUND (c.descuento * c.cantidad, 8) total
                           FROM   WMS_DOCUMENTOS a,
                                  wms_socios b,
                                  wms_skus_x_documento c,
                                  wms_skus d
                          WHERE       a.tipo_documento IN ('F')
                                  AND a.jornada IN (p_jornada)
                                  AND a.documento = c.documento
                                  AND c.usuario_anulo IS NULL
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.socio = b.socio
                                  AND a.jornada IN (p_jornada)
                                  AND c.sku = d.sku
                                  --and    c.sku <> cg_f_parameter_value('SPIC')
                                  AND c.sku NOT IN
                                           (cg_f_parameter_value ('SPIC'),
                                            cg_f_parameter_value ('SFE'),
                                            WMS_F_BUSCAR_SKU (
                                               CG_F_PARAMETER_VALUE ('SADO')
                                            ))
                                  --and    nvl(d.impuesto,1) <> 0 -- VENTAS EXCENTAS SON A PRODUCTOS QUE NO PAGAN IMPUESTOS
                                  --AND    A.SOCIO_ES_EXCENTO IS NULL
                                  AND ROUND (NVL (c.impuesto, 0), 2) = 0);
         -- descuento gravado
         ELSIF p_rubro = 571
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   a.documento,
                                     a.serie
                                  || ' '
                                  || a.no_documento
                                  || ' ('
                                  || d.sku_alterno
                                  || ')'
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  ROUND (c.descuento * c.cantidad, 8) total
                           FROM   WMS_DOCUMENTOS a,
                                  wms_socios b,
                                  wms_skus_x_documento c,
                                  wms_skus d
                          WHERE       a.tipo_documento IN ('F')
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.socio = b.socio
                                  --AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                                  AND a.documento = c.documento
                                  AND c.usuario_anulo IS NULL
                                  AND c.sku = d.sku
                                  AND ROUND (NVL (c.impuesto, 0), 2) > 0);
         ELSIF p_rubro = 572
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   a.documento,
                                     a.serie
                                  || ' '
                                  || a.no_documento
                                  || ' ('
                                  || d.sku_alterno
                                  || ')'
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  ROUND (c.impuesto * c.cantidad, 8) total
                           FROM   WMS_DOCUMENTOS a,
                                  wms_socios b,
                                  wms_skus_x_documento c,
                                  wms_skus d
                          WHERE       a.tipo_documento IN ('F')
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.socio = b.socio
                                  --AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                                  AND a.documento = c.documento
                                  AND c.usuario_anulo IS NULL
                                  AND c.sku = d.sku
                                  AND ROUND (NVL (c.impuesto, 0), 2) > 0);
         --and    WMS_F_FACTANUL(a.documento) <> 0);

         -- solo devoluciones

         --ventas exentas  sin impuesto sin descuento
         ELSIF p_rubro = 580
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total /*MODIFICADO PARA QUE APAREZCA LA FACTURA/NOTA DE CREDITO IMGF*/
                 FROM   (SELECT   a.documento,
                                     a.serie_padre
                                  || ' '
                                  || a.no_documento_padre
                                  || ' ('
                                  || d.sku_alterno
                                  || ')'
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  ROUND (c.precio_unitario * c.cantidad * -1,
                                         8)
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  wms_socios b,
                                  wms_skus_x_documento c,
                                  wms_skus d
                          WHERE       a.tipo_documento IN ('D')
                                  AND a.jornada IN (p_jornada)
                                  AND a.documento = c.documento
                                  AND c.usuario_anulo IS NULL
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.socio = b.socio
                                  AND c.sku = d.sku
                                  AND (C.SKU <> cg_f_parameter_value ('SPIC')
                                       AND C.SKU <>
                                             cg_f_parameter_value ('SFE'))
                                  --and    nvl(d.impuesto,1) <> 0 -- VENTAS EXCENTAS SON A PRODUCTOS QUE NO PAGAN IMPUESTOS
                                  --AND    A.SOCIO_ES_EXCENTO IS NULL
                                  AND ROUND (NVL (c.impuesto, 0), 2) = 0);
         -- VENTAS A GRAVADAS  sin impuesto sin descuento
         ELSIF p_rubro = 581
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total /*MODIFICADO PARA QUE APAREZCA LA FACTURA/NOTA DE CREDITO IMGF*/
                 FROM   (SELECT   a.documento,
                                     a.serie_padre
                                  || ' '
                                  || a.no_documento_padre
                                  || ' ('
                                  || d.sku_alterno
                                  || ')'
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  ROUND (c.precio_unitario * c.cantidad * -1,
                                         8)
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  wms_socios b,
                                  wms_skus_x_documento c,
                                  wms_skus d
                          WHERE       a.tipo_documento IN ('D')
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.socio = b.socio
                                  --AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                                  AND a.documento = c.documento
                                  AND c.usuario_anulo IS NULL
                                  AND c.sku = d.sku
                                  AND ROUND (NVL (c.impuesto, 0), 2) > 0);
         --and    WMS_F_FACTANUL(a.documento_padre) <> 0);

         --descuento exentos
         ELSIF p_rubro = 582
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total /*MODIFICADO PARA QUE APAREZCA LA FACTURA/NOTA DE CREDITO IMGF*/
                 FROM   (SELECT   a.documento,
                                     a.serie_padre
                                  || ' '
                                  || a.no_documento_padre
                                  || ' ('
                                  || d.sku_alterno
                                  || ')'
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  ROUND (c.descuento * c.cantidad * -1, 8)
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  wms_socios b,
                                  wms_skus_x_documento c,
                                  wms_skus d
                          WHERE       a.tipo_documento IN ('D')
                                  AND a.jornada IN (p_jornada)
                                  AND a.documento = c.documento
                                  AND c.usuario_anulo IS NULL
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.socio = b.socio
                                  AND a.jornada IN (p_jornada)
                                  AND c.sku = d.sku
                                  --and    nvl(d.impuesto,1) <> 0 -- VENTAS EXCENTAS SON A PRODUCTOS QUE NO PAGAN IMPUESTOS
                                  --AND    A.SOCIO_ES_EXCENTO IS NULL
                                  AND ROUND (NVL (c.impuesto, 0), 2) = 0);
         -- descuento gravado
         ELSIF p_rubro = 583
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total /*MODIFICADO PARA QUE APAREZCA LA FACTURA/NOTA DE CREDITO IMGF*/
                 FROM   (SELECT   a.documento,
                                     a.serie_padre
                                  || ' '
                                  || a.no_documento_padre
                                  || ' ('
                                  || d.sku_alterno
                                  || ')'
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  ROUND (c.descuento * c.cantidad * -1, 8)
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  wms_socios b,
                                  wms_skus_x_documento c,
                                  wms_skus d
                          WHERE       a.tipo_documento IN ('D')
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.socio = b.socio
                                  --AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                                  AND a.documento = c.documento
                                  AND c.usuario_anulo IS NULL
                                  AND c.sku = d.sku
                                  AND ROUND (NVL (c.impuesto, 0), 2) > 0);
         ELSIF p_rubro = 584
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   ( /*MODIFICADO PARA QUE APAREZCA LA FACTURA/NOTA DE CREDITO IMGF*/
                         SELECT   a.documento,
                                     a.serie_padre
                                  || ' '
                                  || a.no_documento_padre
                                  || ' ('
                                  || d.sku_alterno
                                  || ')'
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  ROUND ( (c.impuesto * c.cantidad * -1), 8)
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  wms_socios b,
                                  wms_skus_x_documento c,
                                  wms_skus d
                          WHERE       a.tipo_documento IN ('D')
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.socio = b.socio
                                  --AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                                  AND a.documento = c.documento
                                  AND c.usuario_anulo IS NULL
                                  AND c.sku = d.sku
                                  AND ROUND (NVL (c.impuesto, 0), 2) > 0);
         --and    WMS_F_FACTANUL(a.documento_padre) <> 0);


         -- solo devoluciones

         -- Devolucin de Gift.
         ELSIF p_rubro = 912
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total /*MODIFICADO PARA QUE APAREZCA LA FACTURA/NOTA DE CREDITO IMGF*/
                 FROM   (SELECT   a.documento,
                                     a.serie_padre
                                  || ' '
                                  || a.no_documento_padre
                                  || ' ('
                                  || d.sku_alterno
                                  || ')'
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  ROUND (c.precio_unitario * c.cantidad * -1,
                                         8)
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  wms_socios b,
                                  wms_skus_x_documento c,
                                  wms_skus d
                          WHERE       a.tipo_documento IN ('D')
                                  AND a.jornada IN (p_jornada)
                                  AND a.documento = c.documento
                                  AND c.usuario_anulo IS NULL
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.socio = b.socio
                                  AND a.jornada IN (p_jornada)
                                  AND c.sku = d.sku
                                  AND C.SKU = cg_f_parameter_value ('SPIC')
                                  --and    nvl(d.impuesto,1) <> 0 -- VENTAS EXCENTAS SON A PRODUCTOS QUE NO PAGAN IMPUESTOS
                                  --AND    A.SOCIO_ES_EXCENTO IS NULL
                                  AND ROUND (NVL (c.impuesto, 0), 2) = 0);
         -- FACTURAS CREDITO SIN IMPUESYO sin descuento
         ELSIF p_rubro = 585
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        total
                 FROM   (  SELECT   a.documento,
                                    a.serie || ' ' || a.no_documento
                                       no_documento,
                                    b.socio_alterno,
                                    b.nombre,
                                    ROUND (
                                       SUM (c.precio_unitario * c.cantidad),
                                       8
                                    )
                                       total
                             FROM   WMS_DOCUMENTOS a,
                                    wms_socios b,
                                    wms_skus_x_documento c
                            WHERE       a.tipo_documento IN ('F')
                                    AND a.jornada IN (p_jornada)
                                    AND NVL (a.situacion, 1) <> 11
                                    AND a.socio = b.socio
                                    AND a.documento = c.documento
                                    AND c.usuario_anulo IS NULL
                                    AND NVL (a.fecha_vencimiento,
                                             fecha_emision) > fecha_emision
                         GROUP BY   a.documento,
                                    a.serie || ' ' || a.no_documento,
                                    b.socio_alterno,
                                    b.nombre);
         -- FACTURAS CREDITO  descuento
         ELSIF p_rubro = 586
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        total
                 FROM   (  SELECT   a.documento,
                                    a.serie || ' ' || a.no_documento
                                       no_documento,
                                    b.socio_alterno,
                                    b.nombre,
                                    ROUND (SUM (c.descuento * c.cantidad), 8)
                                       total
                             FROM   WMS_DOCUMENTOS a,
                                    wms_socios b,
                                    wms_skus_x_documento c
                            WHERE       a.tipo_documento IN ('F')
                                    AND a.jornada IN (p_jornada)
                                    AND NVL (a.situacion, 1) <> 11
                                    AND a.socio = b.socio
                                    AND a.documento = c.documento
                                    AND c.usuario_anulo IS NULL
                                    AND NVL (a.fecha_vencimiento,
                                             fecha_emision) > fecha_emision
                         GROUP BY   a.documento,
                                    a.serie || ' ' || a.no_documento,
                                    b.socio_alterno,
                                    b.nombre);
         -- FACTURAS CREDITO IMPUESto
         ELSIF p_rubro = 587
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        total
                 FROM   (  SELECT   a.documento,
                                    a.serie || ' ' || a.no_documento
                                       no_documento,
                                    b.socio_alterno,
                                    b.nombre,
                                    ROUND (SUM (c.impuesto * c.cantidad), 8)
                                       total
                             FROM   WMS_DOCUMENTOS a,
                                    wms_socios b,
                                    wms_skus_x_documento c
                            WHERE       a.tipo_documento IN ('F')
                                    AND a.jornada IN (p_jornada)
                                    AND NVL (a.situacion, 1) <> 11
                                    AND a.socio = b.socio
                                    AND a.documento = c.documento
                                    AND c.usuario_anulo IS NULL
                                    AND NVL (a.fecha_vencimiento,
                                             fecha_emision) > fecha_emision
                         GROUP BY   a.documento,
                                    a.serie || ' ' || a.no_documento,
                                    b.socio_alterno,
                                    b.nombre);
         -- DEVOLUCIONES EN VALE
         ELSIF p_rubro = 566
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   ( /*MODIFICADO PARA QUE APAREZCA LA FACTURA/NOTA DE CREDITO IMGF*/
                         SELECT   a.documento,
                                     a.serie_padre
                                  || ' '
                                  || a.no_documento_padre
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     a.total,
                                     a.total / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b
                          WHERE       a.tipo_documento = 'D'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND SUBTIPO_DOCUMENTO = 'V'
                                  AND NVL (a.situacion, 1) <> 11);
         --DETALLE PAGOS CON GIFT CARD
         ELSIF p_rubro = 596
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   ( /*MODIFICADO PARA QUE APAREZCA LA FACTURA/NOTA DE CREDITO IMGF*/
                         SELECT   A.DOCUMENTO,
                                  E.SERIE || ' ' || E.NO_DOCUMENTO
                                     NO_DOCUMENTO,
                                  B.SOCIO_ALTERNO,
                                  B.NOMBRE,
                                  A.JORNADA,
                                  DECODE (
                                     CG_F_PARAMETER_VALUE ('MOJO'),
                                     'MB',
                                     C.VALOR,
                                     C.VALOR / NVL (A.TASA_CAMBIO_MA, 1)
                                  )
                                     TOTAL
                           FROM   WMS_DOCUMENTOS A,
                                  WMS_SOCIOS B,
                                  WMS_PAGO_DOCUMENTOS C,
                                  DOC_ABONO_DOCUMENTOS D,
                                  WMS_DOCUMENTOS E
                          WHERE       A.TIPO_DOCUMENTO = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '14'
                                  AND A.SOCIO = B.SOCIO(+)
                                  AND A.JORNADA IN (p_jornada)
                                  AND NVL (A.SITUACION, 1) <> 11
                                  AND D.RECIBO = A.DOCUMENTO
                                  AND D.DOCUMENTO = E.DOCUMENTO
                                  AND NVL (E.FECHA_VENCIMIENTO,
                                           E.FECHA_EMISION) =
                                        NVL (E.FECHA_EMISION, SYSDATE)
                                  AND WMS_F_FACTANUL (E.DOCUMENTO) <> 0
                         UNION ALL
                         SELECT   DISTINCT
                                  (A.DOCUMENTO),
                                  A.SERIE || ' ' || A.NO_DOCUMENTO
                                     NO_DOCUMENTO,
                                  B.SOCIO_ALTERNO,
                                  B.NOMBRE,
                                  A.JORNADA,
                                  DECODE (
                                     CG_F_PARAMETER_VALUE ('MOJO'),
                                     'MB',
                                     C.VALOR,
                                     C.VALOR / NVL (A.TASA_CAMBIO_MA, 1)
                                  )
                                     TOTAL
                           FROM   WMS_DOCUMENTOS A,
                                  WMS_SOCIOS B,
                                  WMS_PAGO_DOCUMENTOS C,
                                  WMS_DOCUMENTOS F,
                                  DOC_ABONO_DOCUMENTOS D
                          WHERE       A.TIPO_DOCUMENTO = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '14'
                                  AND A.SOCIO = B.SOCIO(+)
                                  AND A.JORNADA IN (p_jornada)
                                  AND NVL (A.SITUACION, 1) <> 11
                                  AND A.DOCUMENTO = D.RECIBO
                                  AND D.DOCUMENTO = F.DOCUMENTO
                                  AND TRUNC(NVL (F.FECHA_VENCIMIENTO,
                                                 F.FECHA_EMISION)) <>
                                        TRUNC (F.FECHA_EMISION));
         --DETALLE PAGOS CON GIFT CARD
         ELSIF p_rubro = 597
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   ( /*MODIFICADO PARA QUE APAREZCA LA FACTURA/NOTA DE CREDITO IMGF*/
                         SELECT   A.DOCUMENTO,
                                  E.SERIE || ' ' || E.NO_DOCUMENTO
                                     NO_DOCUMENTO,
                                  B.SOCIO_ALTERNO,
                                  B.NOMBRE,
                                  A.JORNADA,
                                  DECODE (
                                     CG_F_PARAMETER_VALUE ('MOJO'),
                                     'MB',
                                     C.VALOR,
                                     C.VALOR / NVL (A.TASA_CAMBIO_MA, 1)
                                  )
                                     TOTAL
                           FROM   WMS_DOCUMENTOS A,
                                  WMS_SOCIOS B,
                                  WMS_PAGO_DOCUMENTOS C,
                                  DOC_ABONO_DOCUMENTOS D,
                                  WMS_DOCUMENTOS E
                          WHERE       A.TIPO_DOCUMENTO = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '14'
                                  AND A.SOCIO = B.SOCIO(+)
                                  AND A.JORNADA IN (p_jornada)
                                  AND NVL (A.SITUACION, 1) <> 11
                                  AND D.RECIBO = A.DOCUMENTO
                                  AND D.DOCUMENTO = E.DOCUMENTO
                                  AND NVL (E.FECHA_VENCIMIENTO,
                                           E.FECHA_EMISION) =
                                        NVL (E.FECHA_EMISION, SYSDATE)
                                  AND WMS_F_FACTANUL (E.DOCUMENTO) <> 0
                         UNION ALL
                         SELECT   DISTINCT
                                  (A.DOCUMENTO),
                                  A.SERIE || ' ' || A.NO_DOCUMENTO
                                     NO_DOCUMENTO,
                                  B.SOCIO_ALTERNO,
                                  B.NOMBRE,
                                  A.JORNADA,
                                  DECODE (
                                     CG_F_PARAMETER_VALUE ('MOJO'),
                                     'MB',
                                     C.VALOR,
                                     C.VALOR / NVL (A.TASA_CAMBIO_MA, 1)
                                  )
                                     TOTAL
                           FROM   WMS_DOCUMENTOS A,
                                  WMS_SOCIOS B,
                                  WMS_PAGO_DOCUMENTOS C,
                                  WMS_DOCUMENTOS F,
                                  DOC_ABONO_DOCUMENTOS D
                          WHERE       A.TIPO_DOCUMENTO = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '14'
                                  AND A.SOCIO = B.SOCIO(+)
                                  AND A.JORNADA IN (p_jornada)
                                  AND NVL (A.SITUACION, 1) <> 11
                                  AND A.DOCUMENTO = D.RECIBO
                                  AND D.DOCUMENTO = F.DOCUMENTO
                                  AND TRUNC(NVL (F.FECHA_VENCIMIENTO,
                                                 F.FECHA_EMISION)) <>
                                        TRUNC (F.FECHA_EMISION));
         --CREDIX
         ELSIF p_rubro = 610
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   DOCUMENTO,
                                  FACTURA NO_DOCUMENTO,
                                  SOCIO_ALTERNO,
                                  SOCIO NOMBRE,
                                  JORNADA,
                                  NVL (MONTO, 0) TOTAL
                           FROM   WMS_V_CREDIX
                          WHERE   JORNADA = p_jornada
                         UNION ALL
                         SELECT   DOCUMENTO,
                                  ' ' NO_DOCUMENTO,
                                  ' ' SOCIO_ALTERNO,
                                  ' ' SOCIO,
                                  JORNADA,
                                  NVL (TO_NUMBER (MONTO), 0) TOTAL
                           FROM   WMS_CREDIX_TRANS
                          WHERE   AUTORIZACION NOT IN
                                        (SELECT   DISTINCT D.AUTORIZACION
                                           FROM            WMS_PAGO_DOCUMENTOS A
                                                        INNER JOIN
                                                           WMS_DOCUMENTOS B
                                                        ON A.DOCUMENTO =
                                                              B.DOCUMENTO
                                                           AND A.TIPO_PAGO =
                                                                 32
                                                     INNER JOIN
                                                        WMS_DOCUMENTOS C
                                                     ON B.DOCUMENTO_PADRE =
                                                           C.DOCUMENTO
                                                  INNER JOIN
                                                     WMS_CREDIX_TRANS D
                                                  ON C.DOCUMENTO_PADRE =
                                                        D.DOCUMENTO
                                          WHERE   D.AUTORIZACION IS NOT NULL)
                                  AND ESTADO = 'C'
                                  AND JORNADA = p_jornada);
         --FLEXI
         ELSIF p_rubro = 615
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   DOCUMENTO,
                                  FACTURA NO_DOCUMENTO,
                                  SOCIO_ALTERNO,
                                  SOCIO NOMBRE,
                                  JORNADA,
                                  NVL (MONTO, 0) TOTAL
                           FROM   WMS_V_FLEXI
                          WHERE   JORNADA = p_jornada);
         --CREDICUOTAS
         ELSIF p_rubro = 611
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   DOCUMENTO,
                                  FACTURA NO_DOCUMENTO,
                                  SOCIO_ALTERNO,
                                  SOCIO NOMBRE,
                                  JORNADA,
                                  NVL (MONTO, 0) TOTAL
                           FROM   WMS_V_CREDITOEK
                          WHERE   JORNADA = p_jornada
                                  AND POS_F_ES_RECIBO_MARCHAMO (DOCUMENTO) =
                                        0
                         UNION ALL
                         SELECT   B.DOCUMENTO,
                                  ' ' NO_DOCUMENTO,
                                  ' ' SOCIO_ALTERNO,
                                  ' ' NOMBRE,
                                  A.JORNADA,
                                  A.VALORCOMPRA TOTAL
                           FROM         WMS_CREDITOEK_RPAGS A
                                     INNER JOIN
                                        WMS_DOCUMENTOS B
                                     ON A.DOCUMENTO = B.DOCUMENTO
                                        AND B.TIPO_DOCUMENTO = 'P'
                                  LEFT OUTER JOIN
                                     WMS_DOCUMENTOS C
                                  ON B.DOCUMENTO = C.DOCUMENTO_PADRE
                          WHERE       A.ESTADO = 'C'
                                  AND C.DOCUMENTO IS NULL
                                  AND A.JORNADA = p_JORNADA);
         -- ABONOS CON CREDI-E
         ELSIF p_rubro = 613
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   DISTINCT
                                  (a.documento),
                                  a.serie || ' ' || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     E.VALORCOMPRA,
                                     E.VALORCOMPRA
                                     / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_documentos C,
                                  doc_Abono_documentos d,
                                  WMS_CREDITOEK_RPAGS E
                          WHERE       a.tipo_documento = 'R'
                                  AND E.ESTADO = 'C'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.documento = d.recibo
                                  AND d.documento = C.documento
                                  AND TRUNC(NVL (C.fecha_vencimiento,
                                                 C.fecha_emision)) <>
                                        TRUNC (C.fecha_emision)
                                  AND wms_F_pago_asociaciones (a.documento) =
                                        0 -- EXCLUIMOS LAS FACTURAS CON PAGOS A ASOCIACIONES
                                  AND A.DOCUMENTO = E.DOCUMENTO
                         UNION ALL
                         SELECT   DISTINCT
                                  (a.documento),
                                  a.serie || ' ' || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.VALORCOMPRA,
                                     c.VALORCOMPRA
                                     / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  WMS_CREDITOEK_RPAGS C
                          WHERE       a.tipo_documento = 'R'
                                  AND C.ESTADO = 'C'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND A.DOCUMENTO NOT IN
                                           (SELECT   RECIBO
                                              FROM   DOC_ABONO_DOCUMENTOS
                                             WHERE   RECIBO = A.DOCUMENTO)
                                  AND wms_F_pago_asociaciones (a.documento) =
                                        0);
         -- ANULACIONES
         ELSIF p_rubro = 161
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        total
                 FROM   (  SELECT                            /*+ FIRST_ROWS */
                                 b  .documento,
                                    b.serie || ' ' || b.no_documento
                                       no_documento,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       NVL (
                                          SUM(NVL (a.cantidad, 0)
                                              * (  NVL (a.precio_unitario, 0)
                                                 + NVL (a.impuesto, 0)
                                                 - NVL (a.descuento, 0))),
                                          0
                                       ),
                                       NVL (
                                          SUM( (NVL (a.cantidad, 0)
                                                * (  NVL (a.precio_unitario, 0)
                                                   + NVL (a.impuesto, 0)
                                                   - NVL (a.descuento, 0)))
                                              / NVL (b.tasa_cambio_ma, 1)),
                                          0
                                       )
                                    )
                                       AS total
                             FROM   WMS_SKUS_X_DOCUMENTO a,
                                    WMS_DOCUMENTOS b,
                                    WMS_SKUS c
                            WHERE       a.documento = b.documento
                                    AND a.sku = c.sku
                                    AND b.tipo_documento = 'F'
                                    AND b.situacion = 11
                                    AND b.jornada IN (p_jornada)
                         GROUP BY   b.documento, b.serie, b.no_documento
                         ORDER BY   2);
         -- DESCUENTOS DE ANULACIONES
         ELSIF p_rubro = 193
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        total
                 FROM   (  SELECT                            /*+ FIRST_ROWS */
                                 b  .documento,
                                    b.serie || ' ' || b.no_documento
                                       no_documento,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       NVL (
                                          SUM(NVL (a.descuento, 0)
                                              * NVL (a.cantidad, 0)
                                              * (1
                                                 + NVL (
                                                      c.impuesto / 100,
                                                      Cg_F_Parameter_Value (
                                                         'PIVA'
                                                      )
                                                      / 100
                                                   ))),
                                          0
                                       ),
                                       NVL (
                                          SUM( (NVL (a.descuento, 0)
                                                * NVL (a.cantidad, 0)
                                                * (1
                                                   + NVL (
                                                        c.impuesto / 100,
                                                        Cg_F_Parameter_Value (
                                                           'PIVA'
                                                        )
                                                        / 100
                                                     )))
                                              / NVL (b.tasa_cambio_ma, 1)),
                                          0
                                       )
                                    )
                                       AS total
                             FROM   WMS_SKUS_X_DOCUMENTO a,
                                    WMS_DOCUMENTOS b,
                                    WMS_SKUS c
                            WHERE       a.documento = b.documento
                                    AND a.sku = c.sku
                                    AND b.tipo_documento = 'F'
                                    AND b.situacion = 11
                                    AND NVL (a.descuento, 0) > 0
                                    AND b.jornada IN (p_jornada)
                         GROUP BY   b.documento, b.serie, b.no_documento
                         ORDER BY   2);
         -- DESCUENTOS
         ELSIF p_rubro = 162
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        total
                 FROM   (  SELECT                            /*+ FIRST_ROWS */
                                 b  .documento,
                                    b.serie || ' ' || b.no_documento
                                       no_documento,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       NVL (
                                          SUM(NVL (a.descuento, 0)
                                              * NVL (a.cantidad, 0)
                                              * (1
                                                 + NVL (
                                                      c.impuesto / 100,
                                                      Cg_F_Parameter_Value (
                                                         'PIVA'
                                                      )
                                                      / 100
                                                   ))),
                                          0
                                       ),
                                       NVL (
                                          SUM( (NVL (a.descuento, 0)
                                                * NVL (a.cantidad, 0)
                                                * (1
                                                   + NVL (
                                                        c.impuesto / 100,
                                                        Cg_F_Parameter_Value (
                                                           'PIVA'
                                                        )
                                                        / 100
                                                     )))
                                              / NVL (b.tasa_cambio_ma, 1)),
                                          0
                                       )
                                    )
                                       AS total
                             FROM   WMS_SKUS_X_DOCUMENTO a,
                                    WMS_DOCUMENTOS b,
                                    WMS_SKUS c
                            WHERE       a.documento = b.documento
                                    AND a.sku = c.sku
                                    AND b.tipo_documento = 'F'
                                    AND NVL (b.situacion, 1) <> 11
                                    AND NVL (a.descuento, 0) > 0
                                    AND b.jornada IN (p_jornada)
                         GROUP BY   b.documento, b.serie, b.no_documento
                         ORDER BY   2);
         -- PROPINAS FACTURADAS
         ELSIF p_rubro = 163
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        total
                 FROM   (  SELECT                            /*+ FIRST ROWS */
                                 documento,
                                    serie || ' ' || no_documento no_documento,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       NVL (SUM (NVL (propina, 0)), 0),
                                       NVL (
                                          SUM(NVL (propina, 0)
                                              / NVL (tasa_cambio_ma, 1)),
                                          0
                                       )
                                    )
                                       total
                             FROM   WMS_DOCUMENTOS
                            WHERE       jornada IN (p_jornada)
                                    AND imprimir_propina = 'S'
                                    AND NVL (situacion, 1) <> 11
                                    AND tipo_documento = 'F'
                                    AND NVL (propina, 0) > 0
                         GROUP BY   documento, serie, no_documento
                         ORDER BY   documento);
         -- FACTURACION
         ELSIF p_rubro = 164
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        total
                 FROM   (  SELECT   DOCUMENTO, NO_DOCUMENTO, TOTAL
                             FROM   (  SELECT                /*+ first_rows */
                                             b  .documento,
                                                b.serie || ' ' || b.no_documento
                                                   no_documento,
                                                ROUND (
                                                   DECODE (
                                                      Cg_F_Parameter_Value (
                                                         'MOJO'
                                                      ),
                                                      'MB',
                                                      (NVL (
                                                          SUM( (NVL (
                                                                   a.precio_unitario,
                                                                   0
                                                                )
                                                                + NVL (
                                                                     a.impuesto,
                                                                     0
                                                                  )
                                                                - NVL (
                                                                     a.descuento,
                                                                     0
                                                                  ))
                                                              * NVL (a.cantidad,
                                                                     0)),
                                                          0
                                                       ))
                                                      + DECODE (
                                                           NVL (
                                                              MAX(b.imprimir_propina),
                                                              'N'
                                                           ),
                                                           'S',
                                                           NVL (MAX (b.propina),
                                                                0),
                                                           0
                                                        ),
                                                      ( (NVL (
                                                            SUM( (NVL (
                                                                     a.precio_unitario,
                                                                     0
                                                                  )
                                                                  + NVL (
                                                                       a.impuesto,
                                                                       0
                                                                    )
                                                                  - NVL (
                                                                       a.descuento,
                                                                       0
                                                                    ))
                                                                * NVL (
                                                                     a.cantidad,
                                                                     0
                                                                  )),
                                                            0
                                                         ))
                                                       + DECODE (
                                                            NVL (
                                                               MAX(b.imprimir_propina),
                                                               'N'
                                                            ),
                                                            'S',
                                                            NVL (MAX (b.propina),
                                                                 0),
                                                            0
                                                         ))
                                                      / MAX(NVL (
                                                               b.tasa_cambio_ma,
                                                               1
                                                            ))
                                                   ),
                                                   2
                                                )
                                                   total
                                         FROM   WMS_SKUS_X_DOCUMENTO a,
                                                WMS_DOCUMENTOS b
                                        WHERE       a.documento = b.documento
                                                AND b.tipo_documento = 'F'
                                                AND b.jornada IN (p_jornada)
                                                AND NVL (b.situacion, 1) <> 11
                                                AND WMS_F_FACTANUL (b.documento) <>
                                                      0
                                                AND a.sku <>
                                                      cg_f_parameter_value (
                                                         'SPIC'
                                                      )
                                     GROUP BY   b.documento,
                                                b.serie,
                                                b.no_documento
                                     UNION ALL
                                     SELECT   DOCUMENTO,
                                              ' ' NO_DOCUMENTO,
                                              NVL (TO_NUMBER (MONTO), 0) TOTAL
                                       FROM   WMS_CREDIX_TRANS
                                      WHERE   AUTORIZACION NOT IN
                                                    (SELECT   DISTINCT
                                                              D.AUTORIZACION
                                                       FROM            WMS_PAGO_DOCUMENTOS A
                                                                    INNER JOIN
                                                                       WMS_DOCUMENTOS B
                                                                    ON A.DOCUMENTO =
                                                                          B.DOCUMENTO
                                                                       AND A.TIPO_PAGO =
                                                                             32
                                                                 INNER JOIN
                                                                    WMS_DOCUMENTOS C
                                                                 ON B.DOCUMENTO_PADRE =
                                                                       C.DOCUMENTO
                                                              INNER JOIN
                                                                 WMS_CREDIX_TRANS D
                                                              ON C.DOCUMENTO_PADRE =
                                                                    D.DOCUMENTO
                                                      WHERE   D.AUTORIZACION IS NOT NULL)
                                              AND ESTADO = 'C'
                                              AND JORNADA = p_jornada
                                     UNION ALL
                                     SELECT   B.DOCUMENTO,
                                              ' ' NO_DOCUMENTO,
                                              A.VALORCOMPRA TOTAL
                                       FROM         WMS_CREDITOEK_RPAGS A
                                                 INNER JOIN
                                                    WMS_DOCUMENTOS B
                                                 ON A.DOCUMENTO = B.DOCUMENTO
                                                    AND B.TIPO_DOCUMENTO = 'P'
                                              LEFT OUTER JOIN
                                                 WMS_DOCUMENTOS C
                                              ON B.DOCUMENTO =
                                                    C.DOCUMENTO_PADRE
                                      WHERE       A.ESTADO = 'C'
                                              AND C.DOCUMENTO IS NULL
                                              AND A.JORNADA = p_JORNADA)
                         ORDER BY   2);
         -- FACTURAS CREDITO
         ELSIF p_rubro = 165
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        total
                 FROM   (SELECT   a.documento,
                                  serie || ' ' || no_documento no_documento,
                                  NVL (
                                     wms_f_pago_asociacion (a.documento,
                                                            p_jornada),
                                     DECODE (
                                        Cg_F_Parameter_Value ('MOJO'),
                                        'MB',
                                        NVL (total, 0),
                                        NVL (total, 0)
                                        / NVL (tasa_cambio_ma, 1)
                                     )
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS A
                          WHERE       jornada = p_jornada
                                  AND a.tipo_documento = 'F'
                                  AND NVL (situacion, 1) <> 11
                                  AND NVL (fecha_vencimiento, fecha_emision) >
                                        fecha_emision
                                  AND WMS_F_FACTANUL (NVL (A.DOCUMENTO, 1)) <>
                                        0);
         --          INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (
         --             jornada, rubro, linea, texto1, monto2 )
         --        SELECT p_jornada, p_rubro, ROWNUM, no_documento, total
         --       FROM   (
         --                   SELECT documento, serie||' '||no_documento no_documento,
         --                    DECODE(Cg_F_Parameter_Value('MOJO'),'MB',NVL(total,0), NVL(total,0) / NVL(tasa_cambio_ma,1)) total
         --                    FROM   WMS_DOCUMENTOS
         --                    WHERE  jornada = p_jornada
         --                    AND    tipo_documento = 'F'
         --                    AND    NVL(situacion,1) <> 11
         --                    AND    NVL(fecha_vencimiento,fecha_emision) > fecha_emision);
         --            --        AND    (NVL(saldo,0) > 0    OR NVL(fecha_vencimiento,fecha_emision) > fecha_emision));
         /*
            UNION
            SELECT
            c.documento, c.serie||' '||c.no_documento no_documento,
             DECODE(Cg_F_Parameter_Value('MOJO'),'MB', NVL(-a.valor,0), NVL(-a.valor / NVL(b.tasa_cambio_ma,1),0))
             FROM doc_Abono_documentos a, wms_documentos b, wms_documentos c
            WHERE a.documento  = b.documento
            AND b.jornada =p_jornada
            AND c.jornada = p_jornada
            AND  a.recibo = c.documento
            AND b.tipo_documento = 'F'
            AND    NVL(b.situacion,1) <> 11
            AND    NVL(c.situacion,1) <> 11
            AND    (NVL(b.saldo,0) > 0    OR  NVL(b.fecha_vencimiento,b.fecha_emision) > b.fecha_emision) );
        */

         -- NOTAS DE CREDITO
         ELSIF p_rubro = 166
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   a.documento,
                                  a.serie || ' ' || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     a.total,
                                     a.total / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b
                          WHERE       a.tipo_documento = 'N'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11);
         -- NOTAS DE CREDITO POR TRANSFERENCIA
         ELSIF p_rubro = 627
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   ( /*MODIFICADO PARA QUE APAREZCA LA FACTURA/NOTA DE CREDITO IMGF*/
                         SELECT   a.documento,
                                     a.serie_padre
                                  || ' '
                                  || a.no_documento_padre
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     a.total,
                                     a.total / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b
                          WHERE       a.tipo_documento = 'D'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND SUBTIPO_DOCUMENTO = 'R'
                                  AND NVL (a.situacion, 1) <> 11);
         -- DEVOLUCIONES EN EFECTIVO
         ELSIF p_rubro = 174
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   ( /*MODIFICADO PARA QUE APAREZCA LA FACTURA/NOTA DE CREDITO IMGF*/
                         SELECT   a.documento,
                                     a.serie_padre
                                  || ' '
                                  || a.no_documento_padre
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     a.total,
                                     a.total / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b
                          WHERE       a.tipo_documento = 'D'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND SUBTIPO_DOCUMENTO = 'D'
                                  AND NVL (a.situacion, 1) <> 11);
         --APARTADOS ANULADOS
         ELSIF p_rubro = 598
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   ( /*MODIFICADO PARA QUE APAREZCA LA FACTURA/NOTA DE CREDITO IMGF*/
                         SELECT   a.documento,
                                     a.serie_padre
                                  || ' '
                                  || a.no_documento_padre
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     a.total,
                                     a.total / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  WMS_DOCUMENTOS C
                          WHERE       a.tipo_documento = 'D'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND A.SUBTIPO_DOCUMENTO = 'A'
                                  AND NVL (a.situacion, 1) <> 11
                                  AND A.DOCUMENTO_PADRE = C.DOCUMENTO
                                  AND NVL (C.APARTADO, 'N') = 'S');
         --FACTURAS ANULADAS
         ELSIF p_rubro = 599
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   ( /*MODIFICADO PARA QUE APAREZCA LA FACTURA/NOTA DE CREDITO IMGF*/
                         SELECT   a.documento,
                                     a.serie_padre
                                  || ' '
                                  || a.no_documento_padre
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     a.total,
                                     a.total / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  WMS_DOCUMENTOS C
                          WHERE       a.tipo_documento = 'D'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND A.SUBTIPO_DOCUMENTO = 'A'
                                  AND NVL (a.situacion, 1) <> 11
                                  AND A.DOCUMENTO_PADRE = C.DOCUMENTO
                                  AND NVL (C.APARTADO, 'N') <> 'S');
         -- DEVOLUCIONES TIPO ACREDITAR
         ELSIF p_rubro = 540
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   ( /*MODIFICADO PARA QUE APAREZCA LA FACTURA/NOTA DE CREDITO IMGF*/
                         SELECT   a.documento,
                                     a.serie_padre
                                  || ' '
                                  || a.no_documento_padre
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     a.total,
                                     a.total / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b
                          WHERE       a.tipo_documento = 'D'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND SUBTIPO_DOCUMENTO = 'C'
                                  AND NVL (a.situacion, 1) <> 11);
         -- DEVOLUCIONES TIPO CHEQUE
         ELSIF p_rubro = 541
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   a.documento,
                                  a.serie || ' ' || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     a.total,
                                     a.total / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b
                          WHERE       a.tipo_documento = 'D'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND SUBTIPO_DOCUMENTO = 'T'
                                  AND NVL (a.situacion, 1) <> 11);
         -- PAGOS EN CHEQUE A FACTURAS DE CONTADO SIN TOMAR EN CUENTA DEVOLUCIONES .
         ELSIF p_rubro = 519
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   a.documento,
                                  a.serie || ' ' || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c,
                                  DOC_ABONO_DOCUMENTOS d,
                                  wms_documentos e
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '4'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND d.recibo = a.documento
                                  AND d.documento = e.documento
                                  AND NVL (e.fecha_vencimiento,
                                           e.fecha_emision) =
                                        NVL (e.fecha_emision, SYSDATE));
         -- PAGOS EN EFECTIVO A FACTURAS DE CONTADO SIN TOMAR EN CUENTA DEVOLUCIONES
         ELSIF p_rubro = 520
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (     /*MODIFICADO PARA QUE APAREZCA LA FACTURA IMGF*/
                         SELECT   e.serie || ' ' || e.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c,
                                  doc_abono_documentos d,
                                  wms_documentos e
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '3'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND d.recibo = a.documento
                                  AND d.documento = e.documento
                                  AND NVL (e.fecha_vencimiento,
                                           e.fecha_emision) =
                                        NVL (e.fecha_emision, SYSDATE)
                                  AND WMS_F_FACTANUL (E.DOCUMENTO) <> 0
                         UNION ALL
                         SELECT   a.serie || ' ' || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (Cg_F_Parameter_Value ('MOJO'),
                                          'MB', d.cvuelto * -1,
                                          d.cvuelto * -1)
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pague_servicios c,
                                  wms_bacserv_res_a d
                          WHERE       a.tipo_documento = 'R'
                                  AND a.documento = c.documento
                                  AND a.socio = b.socio(+)
                                  AND c.trans_proveedor = d.nnumcomprobante
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND NVL (a.fecha_vencimiento,
                                           a.fecha_emision) =
                                        NVL (a.fecha_emision, SYSDATE)
                                  AND WMS_F_FACTANUL (a.documento) <> 0
                                  AND D.CMONEDAPAGO = 2);
         -- PAGOS EN EFECTIVO  DOLARES A FACTURAS DE CONTADO SIN TOMAR EN CUENTA DEVOLUCIONES
         ELSIF p_rubro = 588
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2,
                                                        texto4,
                                                        texto5)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total,
                        tipo_cambio,
                        totalDolar
                 FROM   ( /*MODIFICADO PARA QUE APAREZCA LA FACTURA/NOTA DE CREDITO IMGF*/
                         SELECT   a.documento,
                                  e.serie || ' ' || e.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  ROUND (c.valor / NVL (a.tasa_cambio_ma, 1),
                                         2)
                                     total,
                                  c.tasa_cambio tipo_cambio,
                                  c.VALOR_MONEDA totalDolar
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c,
                                  doc_abono_documentos d,
                                  wms_documentos e
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.MONEDA = WMS_F_MONEDA_ALTERNA
                                  AND C.TIPO_PAGO = '3'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND d.recibo = a.documento
                                  AND d.documento = e.documento
                                  AND NVL (e.fecha_vencimiento,
                                           e.fecha_emision) =
                                        NVL (e.fecha_emision, SYSDATE)
                                  AND WMS_F_FACTANUL (
                                        NVL (A.DOCUMENTO_PADRE, 1)
                                     ) <> 0
                         UNION ALL
                         SELECT   DISTINCT
                                  (a.documento),
                                  a.serie || ' ' || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  c.valor / NVL (a.tasa_cambio_ma, 1) total,
                                  c.tasa_cambio tipo_cambio,
                                  c.VALOR_MONEDA totalDolar
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c,
                                  wms_documentos f,
                                  doc_Abono_documentos d
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '3'
                                  AND c.moneda = wms_f_moneda_alterna
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.documento = d.recibo
                                  AND d.documento = f.documento
                                  AND TRUNC(NVL (f.fecha_vencimiento,
                                                 f.fecha_emision)) <>
                                        TRUNC (f.fecha_emision)
                         UNION ALL
                         SELECT   DISTINCT
                                  (a.documento),
                                  a.serie || ' ' || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  c.valor / NVL (a.tasa_cambio_ma, 1) total,
                                  c.tasa_cambio tipo_cambio,
                                  c.VALOR_MONEDA totalDolar
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '3'
                                  AND c.moneda = wms_f_moneda_alterna
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND A.DOCUMENTO NOT IN
                                           (SELECT   RECIBO
                                              FROM   DOC_ABONO_DOCUMENTOS
                                             WHERE   RECIBO = A.DOCUMENTO)
                         UNION ALL
                         SELECT   S.DOCUMENTO,
                                  D.NO_DOCUMENTO,
                                  NULL SOCIO_ALTERNO,
                                  NULL NOMBRE,
                                  R.JORNADA,
                                  R.MONTODOL TOTAL,
                                  R.VENTADOLAR TIPO_CAMBIO,
                                  r.PAGACON totalDolar
                           FROM   WMS_HABLAMAS_REQ R,
                                  WMS_PAGUE_SERVICIOS S,
                                  WMS_DOCUMENTOS D
                          WHERE       R.JORNADA = p_jornada
                                  AND R.CODSTATE = 0
                                  AND R.Moneda = 2
                                  AND D.DOCUMENTO = S.DOCUMENTO
                                  AND S.TIPO_SERVICIO = '04'
                                  AND S.TRANS_PROVEEDOR = R.ID
                         UNION ALL
                         SELECT   S.DOCUMENTO,
                                  D.NO_DOCUMENTO,
                                  NULL SOCIO_ALTERNO,
                                  NULL NOMBRE,
                                  R.JORNADA,
                                  R.MONTODOL TOTAL,
                                  R.VENTADOLAR TIPO_CAMBIO,
                                  0 totalDolar
                           FROM   WMS_HABLAMAS_REQ R,
                                  WMS_PAGUE_SERVICIOS S,
                                  WMS_DOCUMENTOS D
                          WHERE       R.JORNADA = p_jornada
                                  AND R.CODSTATE = 0
                                  AND R.Moneda = 1
                                  AND D.DOCUMENTO = S.DOCUMENTO
                                  AND S.TIPO_SERVICIO = '04'
                                  AND S.TRANS_PROVEEDOR = R.ID--SELECT EFECTIVO FROM WMS_V_EFECTIVO_CAJA WHERE MONEDA = 2 AND CAJA = JORNADA = &&
                        );
         -- FACTURAS CREDITO sin apartados
         ELSIF p_rubro = 589
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        total
                 FROM   (SELECT   a.documento,
                                  serie || ' ' || no_documento no_documento,
                                  NVL (
                                     wms_f_pago_asociacion (a.documento,
                                                            p_jornada),
                                     DECODE (
                                        Cg_F_Parameter_Value ('MOJO'),
                                        'MB',
                                        NVL (total, 0),
                                        NVL (total, 0)
                                        / NVL (tasa_cambio_ma, 1)
                                     )
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS A
                          WHERE       jornada = p_jornada
                                  AND a.tipo_documento = 'F'
                                  AND NVL (situacion, 1) <> 11
                                  AND NVL (fecha_vencimiento, fecha_emision) >
                                        fecha_emision
                                  AND NVL (a.apartado, 'N') = 'N'
                                  AND WMS_F_FACTANUL (A.DOCUMENTO) <> 0);
         -- PAGO CERTICADOS, VALES Y PUNTOS
         ELSIF p_rubro = 567
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (     /*MODIFICADO PARA QUE APAREZCA LA FACTURA IMGF*/
                         SELECT   a.documento,
                                  e.serie || ' ' || e.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c,
                                  doc_abono_documentos d,
                                  wms_documentos e
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO IN ('24', '6', '16')
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND d.recibo = a.documento
                                  AND d.documento = e.documento
                                  AND NVL (e.fecha_vencimiento,
                                           e.fecha_emision) =
                                        NVL (e.fecha_emision, SYSDATE)
                                  AND WMS_F_FACTANUL (E.DOCUMENTO) <> 0);
         -- PAGOS EN TARJETA DE CREDITO  A FACTURAS DE CONTADO SIN TOMAR EN CUENTA DEVOLUCIONES
         ELSIF p_rubro = 521
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (     /*MODIFICADO PARA QUE APAREZCA LA FACTURA IMGF*/
                         SELECT   a.documento,
                                  e.serie || ' ' || e.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c,
                                  doc_Abono_documentos d,
                                  wms_documentos e
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO IN ('1')       -- 1->TARJETA
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND d.recibo = a.documento
                                  AND d.documento = e.documento
                                  AND TRUNC(NVL (e.fecha_vencimiento,
                                                 e.fecha_emision)) =
                                        TRUNC (
                                           NVL (e.fecha_emision, SYSDATE)
                                        )              --COMENTADO GMH 12-2014
                                  AND WMS_F_FACTANUL (e.documento) <> 0);
         ELSIF p_rubro = 600
         THEN                                                     --DONACIONES
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (     /*MODIFICADO PARA QUE APAREZCA LA FACTURA IMGF*/
                         SELECT   e.serie || ' ' || e.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  ROUND (
                                     f.precio_unitario
                                     * DECODE (NVL (g.IMPUESTO, 1),
                                               0, 1,
                                               1.13),
                                     2
                                  )
                                  * f.cantidad
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  doc_abono_documentos d,
                                  wms_documentos e,
                                  wms_skus_x_documento f,
                                  wms_skus g
                          WHERE       a.tipo_documento = 'R'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND d.recibo = a.documento
                                  AND d.documento = e.documento
                                  AND f.sku = g.sku
                                  AND TRUNC(NVL (e.fecha_vencimiento,
                                                 e.fecha_emision)) =
                                        TRUNC (
                                           NVL (e.fecha_emision, SYSDATE)
                                        )              --COMENTADO GMH 12-2014
                                  AND e.documento = f.documento
                                  AND f.sku =
                                        WMS_F_BUSCAR_SKU (
                                           CG_F_PARAMETER_VALUE ('SADO')
                                        )
                                  AND f.USUARIO_ANULO IS NULL
                                  AND WMS_F_FACTANUL (E.DOCUMENTO) <> 0);
         -- PAGOS EN  EFECTIVO DE DOCUMENTOS DE CREDITO  O PAGOS ANTICIPADOS
         ELSIF p_rubro = 542
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (  SELECT   documento,
                                    no_documento,
                                    socio_alterno,
                                    nombre,
                                    jornada,
                                    SUM (total) total
                             FROM   ( -- se elimina el distinct a a.documento, cuando hay mas de una abono a una factura solo aparece uno
                                     SELECT    DISTINCT
                                               (a.documento),
                                               a.serie || ' ' || a.no_documento
                                                  no_documento,
                                               b.socio_alterno,
                                               b.nombre,
                                               a.jornada,
                                               DECODE (
                                                  Cg_F_Parameter_Value ('MOJO'),
                                                  'MB',
                                                  c.valor,
                                                  c.valor
                                                  / NVL (a.tasa_cambio_ma, 1)
                                               )
                                                  total
                                        FROM   WMS_DOCUMENTOS a,
                                               WMS_SOCIOS b,
                                               wms_pago_documentos c,
                                               wms_documentos f,
                                               doc_Abono_documentos d
                                       WHERE       a.tipo_documento = 'R'
                                               AND A.DOCUMENTO = C.DOCUMENTO
                                               AND C.TIPO_PAGO = '3'
                                               AND a.socio = b.socio(+)
                                               AND a.jornada IN (p_jornada)
                                               AND NVL (a.situacion, 1) <> 11
                                               AND a.documento = d.recibo
                                               AND d.documento = f.documento
                                               AND TRUNC(NVL (
                                                            f.fecha_vencimiento,
                                                            f.fecha_emision
                                                         )) <>
                                                     TRUNC (f.fecha_emision)
                                               AND wms_F_pago_asociaciones (
                                                     a.documento
                                                  ) = 0 -- EXCLUIMOS LAS FACTURAS CON PAGOS A ASOCIACIONES
                                               AND A.SERIE NOT LIKE 'C%'
                                     UNION ALL
                                     SELECT   a.documento,
                                              a.serie || ' ' || a.no_documento
                                                 no_documento,
                                              b.socio_alterno,
                                              b.nombre,
                                              a.jornada,
                                              DECODE (
                                                 Cg_F_Parameter_Value ('MOJO'),
                                                 'MB',
                                                 c.valor,
                                                 c.valor
                                                 / NVL (a.tasa_cambio_ma, 1)
                                              )
                                                 total
                                       FROM   WMS_DOCUMENTOS a,
                                              WMS_SOCIOS b,
                                              wms_pago_documentos c
                                      WHERE       a.tipo_documento = 'R'
                                              AND A.DOCUMENTO = C.DOCUMENTO
                                              AND C.TIPO_PAGO = '3'
                                              AND a.socio = b.socio(+)
                                              AND a.jornada IN (p_jornada)
                                              AND NVL (a.situacion, 1) <> 11
                                              AND A.DOCUMENTO NOT IN
                                                       (SELECT   RECIBO
                                                          FROM   DOC_ABONO_DOCUMENTOS
                                                         WHERE   RECIBO =
                                                                    A.DOCUMENTO)
                                              AND wms_F_pago_asociaciones (
                                                    a.documento
                                                 ) = 0
                                              AND POS_F_ES_RECIBO_MARCHAMO (
                                                    A.DOCUMENTO
                                                 ) = 0) -- EXCLUIMOS LAS FACTURAS CON PAGOS A ASOCIACIONES
                         GROUP BY   documento,
                                    no_documento,
                                    socio_alterno,
                                    nombre,
                                    jornada);
         -- PAGOS EN TARJETA DE CREDITO DE DOCUMENTOS DE CREDITO
         ELSIF p_rubro = 543
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   DISTINCT
                                  (a.documento),
                                  a.serie || ' ' || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total,
                                  C.AUTORIZACION
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c,
                                  wms_documentos f,
                                  doc_Abono_documentos d
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '1'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.documento = d.recibo
                                  AND d.documento = f.documento
                                  AND TRUNC(NVL (f.fecha_vencimiento,
                                                 f.fecha_emision)) <>
                                        TRUNC (f.fecha_emision)
                                  AND wms_F_pago_asociaciones (a.documento) =
                                        0 -- EXCLUIMOS LAS FACTURAS CON PAGOS A ASOCIACIONES
                         UNION ALL
                         SELECT   DISTINCT
                                  (a.documento),
                                  a.serie || ' ' || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total,
                                  C.AUTORIZACION
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '1'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND A.DOCUMENTO NOT IN
                                           (SELECT   RECIBO
                                              FROM   DOC_ABONO_DOCUMENTOS
                                             WHERE   RECIBO = A.DOCUMENTO)
                                  AND wms_F_pago_asociaciones (a.documento) =
                                        0
                                  AND POS_F_ES_RECIBO_MARCHAMO (A.DOCUMENTO) =
                                        0); -- EXCLUIMOS LAS FACTURAS CON PAGOS A ASOCIACIONES;
         -- PAGOS EN  EFECTIVO DE DOCUMENTOS DE CREDITO  O PAGOS ANTICIPADOS
         ELSIF p_rubro = 590
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   ( /*MODIFICADO PARA QUE APAREZCA LA FACTURA/NOTA DE CREDITO IMGF*/
                         SELECT   DISTINCT
                                  (a.documento),
                                  f.serie || ' ' || f.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c,
                                  wms_documentos f,
                                  doc_Abono_documentos d
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '3'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.documento = d.recibo
                                  AND d.documento = f.documento
                                  AND TRUNC(NVL (f.fecha_vencimiento,
                                                 f.fecha_emision)) <>
                                        TRUNC (f.fecha_emision)
                                  AND wms_F_pago_asociaciones (a.documento) <>
                                        0 -- EXCLUIMOS LAS FACTURAS CON PAGOS A ASOCIACIONES
                         UNION ALL
                         SELECT   DISTINCT
                                  (a.documento),
                                  a.serie || ' ' || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '3'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND A.DOCUMENTO NOT IN
                                           (SELECT   RECIBO
                                              FROM   DOC_ABONO_DOCUMENTOS
                                             WHERE   RECIBO = A.DOCUMENTO)
                                  AND wms_F_pago_asociaciones (a.documento) <>
                                        0 -- EXCLUIMOS LAS FACTURAS CON PAGOS A ASOCIACIONES
                                         );
         -- PAGOS EN TARJETA DE CREDITO DE DOCUMENTOS DE CREDITO
         ELSIF p_rubro = 591
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   ( /*MODIFICADO PARA QUE APAREZCA LA FACTURA/NOTA DE CREDITO IMGF*/
                         SELECT   DISTINCT
                                  (a.documento),
                                  f.serie || ' ' || f.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c,
                                  wms_documentos f,
                                  doc_Abono_documentos d
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '1'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.documento = d.recibo
                                  AND d.documento = f.documento
                                  AND TRUNC(NVL (f.fecha_vencimiento,
                                                 f.fecha_emision)) <>
                                        TRUNC (f.fecha_emision)
                                  AND wms_F_pago_asociaciones (a.documento) <>
                                        0 -- EXCLUIMOS LAS FACTURAS CON PAGOS A ASOCIACIONES
                         UNION ALL
                         SELECT   DISTINCT
                                  (a.documento),
                                  a.serie || ' ' || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '1'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND A.DOCUMENTO NOT IN
                                           (SELECT   RECIBO
                                              FROM   DOC_ABONO_DOCUMENTOS
                                             WHERE   RECIBO = A.DOCUMENTO)
                                  AND wms_F_pago_asociaciones (a.documento) <>
                                        0); -- EXCLUIMOS LAS FACTURAS CON PAGOS A ASOCIACIONES;
         -- ABONOS CON GIFT CARD
         ELSIF p_rubro = 609
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   ( /*MODIFICADO PARA QUE APAREZCA LA FACTURA/NOTA DE CREDITO IMGF*/
                         SELECT   DISTINCT
                                  (a.documento),
                                  a.serie || ' ' || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c,
                                  wms_documentos f,
                                  doc_Abono_documentos d
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '14'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.documento = d.recibo
                                  AND d.documento = f.documento
                                  AND TRUNC(NVL (f.fecha_vencimiento,
                                                 f.fecha_emision)) <>
                                        TRUNC (f.fecha_emision)
                                  AND wms_F_pago_asociaciones (a.documento) =
                                        0 -- EXCLUIMOS LAS FACTURAS CON PAGOS A ASOCIACIONES
                         UNION ALL
                         SELECT   DISTINCT
                                  (a.documento),
                                  a.serie || ' ' || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '14'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND A.DOCUMENTO NOT IN
                                           (SELECT   RECIBO
                                              FROM   DOC_ABONO_DOCUMENTOS
                                             WHERE   RECIBO = A.DOCUMENTO)
                                  AND wms_F_pago_asociaciones (a.documento) =
                                        0); -- EXCLUIMOS LAS FACTURAS CON PAGOS A ASOCIACIONES;
         -- PAGOS EN CHEQUE DE DOCUMENTOS DE CREDITO
         ELSIF p_rubro = 544
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   DISTINCT
                                  (a.documento),
                                  a.serie || ' ' || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c,
                                  wms_documentos f,
                                  doc_Abono_documentos d
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '4'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.documento = d.recibo
                                  AND d.documento = f.documento
                                  AND TRUNC(NVL (f.fecha_vencimiento,
                                                 f.fecha_emision)) <>
                                        TRUNC (f.fecha_emision)
                         UNION ALL
                         SELECT   DISTINCT
                                  (a.documento),
                                  a.serie || ' ' || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '4'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND A.DOCUMENTO NOT IN
                                           (SELECT   RECIBO
                                              FROM   DOC_ABONO_DOCUMENTOS
                                             WHERE   RECIBO = A.DOCUMENTO));
         --and    nvl(f.fecha_vencimiento,f.fecha_emision) > f.fecha_emision);


         -- SALDO EN CREDITO      VENTAS CREDITO - DEVOLUCIONES CON TIPO ACREDITAR
         ELSIF p_rubro = 545
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   documento,
                                  'Fact# ' || serie || ' ' || no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     NVL (total, 0),
                                     NVL (total, 0) / NVL (tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a, wms_socios b
                          WHERE       jornada = p_jornada
                                  AND tipo_documento = 'F'
                                  AND NVL (situacion, 1) <> 11
                                  AND A.SOCIO = B.SOCIO
                                  AND NVL (fecha_vencimiento, fecha_emision) >
                                        fecha_emision
                         UNION ALL
                         SELECT   a.documento,
                                     'Dev. Acreditar# '
                                  || a.serie
                                  || ' '
                                  || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     a.total,
                                     a.total / NVL (a.tasa_cambio_ma, 1)
                                  )
                                  * -1
                                     total
                           FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b
                          WHERE       a.tipo_documento = 'D'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND SUBTIPO_DOCUMENTO = 'C'
                                  AND NVL (a.situacion, 1) <> 11);
         -- VENTAS CONTADO, TODO MENOS FACTURAS DE CREDITO
         ELSIF p_rubro = 546
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   a.documento,
                                     f.rv_meaning
                                  || ' '
                                  || a.serie
                                  || ' '
                                  || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c,
                                  doc_Abono_documentos d,
                                  wms_documentos e,
                                  cg_ref_codes f
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND d.recibo = a.documento
                                  AND d.documento = e.documento
                                  AND f.rv_domain = 'TIPO PAGO'
                                  AND f.rv_low_value = c.tipo_pago
                                  AND NVL (e.fecha_vencimiento,
                                           e.fecha_emision) =
                                        NVL (e.fecha_emision, SYSDATE));
         -- DEVOLUCIONES DE CONTADO...... DEVOLUCIONE DE TIPO DISTINTO ACREDITAR
         ELSIF p_rubro = 547
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   a.documento,
                                     f.rv_meaning
                                  || a.serie
                                  || ' '
                                  || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     a.total,
                                     a.total / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  cg_Ref_codes f
                          WHERE       a.tipo_documento = 'D'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND SUBTIPO_DOCUMENTO NOT IN ('C')
                                  AND f.rv_domain = 'TIPO DEVOLUCION'
                                  AND f.rv_low_value = a.SUBTIPO_DOCUMENTO
                                  AND NVL (a.situacion, 1) <> 11);
         -- VENTAS CREDITO, TODO MENOS FACTURAS DE CCNTADO
         ELSIF p_rubro = 548
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   DISTINCT
                                  (a.documento),
                                     f.rv_meaning
                                  || ' '
                                  || a.serie
                                  || ' '
                                  || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c,
                                  doc_Abono_documentos d,
                                  wms_documentos e,
                                  cg_ref_codes f
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND d.recibo = a.documento
                                  AND d.documento = e.documento
                                  AND f.rv_domain = 'TIPO PAGO'
                                  AND f.rv_low_value = c.tipo_pago
                                  AND TRUNC(NVL (e.fecha_vencimiento,
                                                 e.fecha_emision)) <>
                                        TRUNC (e.fecha_emision)
                         UNION ALL
                         SELECT   DISTINCT
                                  (a.documento),
                                     f.rv_meaning
                                  || ' '
                                  || a.serie
                                  || ' '
                                  || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c,
                                  cg_ref_codes f
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND f.rv_domain = 'TIPO PAGO'
                                  AND f.rv_low_value = c.tipo_pago
                                  AND a.documento NOT IN
                                           (SELECT   RECIBO
                                              FROM   doc_abono_documentos
                                             WHERE   recibo = a.documento));
         --            and   nvl(e.fecha_vencimiento,e.fecha_emision) >  nvl(e.fecha_emision, sysdate));


         -- TOTAL RECIBOS - DEVOLUCIONES  (NO DE ACREDITAR)
         ELSIF p_rubro = 549
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   a.documento,
                                     d.rv_meaning
                                  || ' '
                                  || a.serie
                                  || ' '
                                  || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c,
                                  cg_ref_codes d
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND d.rv_domain = 'TIPO PAGO'
                                  AND d.rv_low_value = c.tipo_pago
                                  AND NVL (a.situacion, 1) <> 11
                         UNION ALL                  --DEVOLUCIONES  EN TARJETA
                         SELECT   a.documento,
                                     d.rv_meaning
                                  || ' NC '
                                  || a.serie
                                  || ' '
                                  || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     a.total,
                                     a.total / NVL (a.tasa_cambio_ma, 1)
                                  )
                                  * -1
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  cg_ref_codes d
                          WHERE       a.tipo_documento = 'D'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND SUBTIPO_DOCUMENTO NOT IN ('C')
                                  AND d.rv_domain = 'TIPO DEVOLUCION'
                                  AND d.rv_low_value = SUBTIPO_DOCUMENTO
                                  AND NVL (a.situacion, 1) <> 11);
         -- VENTAS A A CLIENTES EXCENTOS
         ELSIF p_rubro = 550
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   a.documento,
                                     a.serie
                                  || ' '
                                  || a.no_documento
                                  || ' ('
                                  || d.sku_alterno
                                  || ')'
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  ROUND (
                                     (  c.precio_unitario
                                      - NVL (ROUND (c.descuento, 8), 0)
                                      + NVL (c.impuesto, 0))
                                     * c.cantidad,
                                     8
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  wms_socios b,
                                  wms_skus_x_documento c,
                                  wms_skus d
                          WHERE       a.tipo_documento = 'F'
                                  AND a.jornada IN (p_jornada)
                                  AND a.documento = c.documento
                                  AND c.usuario_anulo IS NULL
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.socio = b.socio
                                  AND a.jornada IN (p_jornada)
                                  AND c.sku = d.sku
                                  --and    nvl(d.impuesto,1) <> 0 -- VENTAS EXCENTAS SON A PRODUCTOS QUE NO PAGAN IMPUESTOS
                                  --AND    A.SOCIO_ES_EXCENTO IS NULL
                                  AND ROUND (NVL (c.impuesto, 0), 2) = 0);
         -- VENTAS A GRAVADAS
         ELSIF p_rubro = 551
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   a.documento,
                                     a.serie
                                  || ' '
                                  || a.no_documento
                                  || ' ('
                                  || d.sku_alterno
                                  || ')'
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  ROUND (
                                     (  c.precio_unitario
                                      - NVL (ROUND (c.descuento, 8), 0)
                                      + NVL (c.impuesto, 0))
                                     * c.cantidad,
                                     8
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  wms_socios b,
                                  wms_skus_x_documento c,
                                  wms_skus d
                          WHERE       a.tipo_documento = 'F'
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.socio = b.socio
                                  --AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                                  AND a.documento = c.documento
                                  AND c.usuario_anulo IS NULL
                                  AND c.sku = d.sku
                                  AND ROUND (NVL (c.impuesto, 0), 2) > 0);
         -- VENTAS EXCENTAS (SKU NO PAGA IMPUESTO )
         ELSIF p_rubro = 552
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   a.documento,
                                     a.serie
                                  || ' '
                                  || a.no_documento
                                  || ' ('
                                  || d.sku_alterno
                                  || ')'
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  ROUND (
                                     (  c.precio_unitario
                                      - NVL (ROUND (c.descuento, 8), 0)
                                      + NVL (c.impuesto, 0))
                                     * c.cantidad,
                                     8
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  wms_socios b,
                                  wms_skus_x_documento c,
                                  wms_skus d
                          WHERE       a.tipo_documento = 'F'
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.socio = b.socio
                                  --      AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                                  AND c.sku = d.sku
                                  AND NVL (d.impuesto, 1) = 0 -- VENTAS EXCENTAS SON A PRODUCTOS QUE NO PAGAN IMPUESTOS
                                  AND a.documento = c.documento
                                  AND c.usuario_anulo IS NULL
                                  AND ROUND (NVL (c.impuesto, 0), 2) = 0);
         -- DEVOLUCIONES A VENTAS A CLIENTES EXCENTOS
         ELSIF p_rubro = 553
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   a.documento,
                                     a.serie
                                  || ' '
                                  || a.no_documento
                                  || ' ('
                                  || d.sku_alterno
                                  || ')'
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  ROUND (
                                     (  c.precio_unitario
                                      - NVL (ROUND (c.descuento, 8), 0)
                                      + NVL (c.impuesto, 0))
                                     * c.cantidad,
                                     8
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  wms_socios b,
                                  wms_skus_x_documento c,
                                  wms_skus d
                          WHERE       a.tipo_documento = 'D'
                                  AND a.jornada IN (p_jornada)
                                  AND a.documento = c.documento
                                  AND c.usuario_anulo IS NULL
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.socio = b.socio
                                  AND a.jornada IN (p_jornada)
                                  AND c.sku = d.sku
                                  AND NVL (d.impuesto, 1) <> 0 -- VENTAS EXCENTAS SON A PRODUCTOS QUE NO PAGAN IMPUESTOS
                                  AND ROUND (NVL (c.impuesto, 0), 2) = 0);
         --    AND    A.SOCIO_ES_EXCENTO IS NULL);

         -- DEVOLUCIONES A VENTAS A GRAVADAS
         ELSIF p_rubro = 554
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   a.documento,
                                     a.serie
                                  || ' '
                                  || a.no_documento
                                  || ' ('
                                  || d.sku_alterno
                                  || ')'
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  ROUND (
                                     (  c.precio_unitario
                                      - NVL (ROUND (c.descuento, 8), 0)
                                      + NVL (c.impuesto, 0))
                                     * c.cantidad,
                                     8
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  wms_socios b,
                                  wms_skus_x_documento c,
                                  wms_skus d
                          WHERE       a.tipo_documento = 'D'
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.socio = b.socio
                                  --AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                                  AND a.documento = c.documento
                                  AND c.usuario_anulo IS NULL
                                  AND c.sku = d.sku
                                  AND ROUND (NVL (c.impuesto, 0), 2) > 0);
         -- DEVOLUCIONES A VENTAS EXCENTAS (SKU NO PAGA IMPUESTO )
         ELSIF p_rubro = 555
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   a.documento,
                                     a.serie
                                  || ' '
                                  || a.no_documento
                                  || ' ('
                                  || d.sku_alterno
                                  || ')'
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  ROUND (
                                     (  c.precio_unitario
                                      - NVL (ROUND (c.descuento, 8), 0)
                                      + NVL (c.impuesto, 0))
                                     * c.cantidad,
                                     8
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  wms_socios b,
                                  wms_skus_x_documento c,
                                  wms_skus d
                          WHERE       a.tipo_documento = 'D'
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.socio = b.socio
                                  --      AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                                  AND c.sku = d.sku
                                  AND NVL (d.impuesto, 1) = 0 -- VENTAS EXCENTAS SON A PRODUCTOS QUE NO PAGAN IMPUESTOS
                                  AND a.documento = c.documento
                                  AND c.usuario_anulo IS NULL
                                  AND ROUND (NVL (c.impuesto, 0), 2) = 0);
         -- TOTAL VENTAS A CLIENTES EXCENTOS MENOS DEVOLUCIONES A CLIENTES EXCENTOS
         ELSIF p_rubro = 556
         THEN
            /*
              INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (
                     jornada, rubro, linea, texto1, texto2, texto3, monto2 )
              SELECT p_jornada, p_rubro, ROWNUM, no_documento, socio_alterno, nombre, total
              FROM   (select a.documento , a.serie ||' '||a.no_documento|| ' (' || d.sku_alterno || ')'  no_documento, b.socio_alterno, b.nombre,
                       round(  ( c.precio_unitario -  nvl(  round(c.descuento,8), 0) + nvl(c.impuesto,0))* c.cantidad, 8) total
                          FROM   WMS_DOCUMENTOS a, wms_socios b, wms_skus_x_documento c, wms_skus d
                    WHERE  a.tipo_documento = 'F'
                    AND    a.jornada IN ( p_jornada )
                    and    a.documento = c.documento
                    and    c.usuario_anulo is null
                    AND    NVL (a.situacion, 1) <> 11
                    and    a.socio = b.socio
                    AND    a.jornada IN ( p_jornada )
                    and    c.sku = d.sku
                    and    nvl(d.impuesto,1) <> 0 -- VENTAS EXCENTAS SON A PRODUCTOS QUE NO PAGAN IMPUESTOS
                    AND    A.SOCIO_ES_EXCENTO IS NULL
                    UNION
                    select a.documento , a.serie ||' '||a.no_documento|| ' (' || d.sku_alterno || ')'  no_documento, b.socio_alterno, b.nombre,
                       round(  ( c.precio_unitario -  nvl(  round(c.descuento,8), 0) + nvl(c.impuesto,0))* -c.cantidad, 8) total
                          FROM   WMS_DOCUMENTOS a, wms_socios b, wms_skus_x_documento c, wms_skus d
                    WHERE  a.tipo_documento = 'D'
                    AND    a.jornada IN ( p_jornada )
                    and    a.documento = c.documento
                    and    c.usuario_anulo is null
                    AND    NVL (a.situacion, 1) <> 11
                    and    a.socio = b.socio
                    AND    a.jornada IN ( p_jornada )
                    and    c.sku = d.sku
                    and    nvl(d.impuesto,1) <> 0 -- VENTAS EXCENTAS SON A PRODUCTOS QUE NO PAGAN IMPUESTOS
                    and    round(nvl(c.impuesto,0),2) = 0);
            */
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        1,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   'FA-EXENTAS' no_documento,
                                  'EXENTOS' socio_alterno,
                                  'CLIENTES EXENTOS' nombre,
                                  ROUND (SUM (MONTO2), 2) total
                           FROM   WMS_HISTORICO_DETALLE_JORNADAS
                          WHERE   RUBRO = 550 AND JORNADA = P_JORNADA);

            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        2,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   'DEV-EXENTAS' no_documento,
                                  'EXENTOS' socio_alterno,
                                  'CLIENTES EXENTOS' nombre,
                                  ROUND (SUM (-MONTO2), 2) total
                           FROM   WMS_HISTORICO_DETALLE_JORNADAS
                          WHERE   RUBRO = 553 AND JORNADA = P_JORNADA);
         -- TOTAL VENTAS A GRAVADAS  -  DEVOLUCIONES A VENTAS GRAVADAS
         ELSIF p_rubro = 557
         THEN
            /*
              INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (
                     jornada, rubro, linea, texto1, texto2, texto3, monto2 )
              SELECT p_jornada, p_rubro, ROWNUM, no_documento, socio_alterno, nombre, total
              FROM   (select a.documento , a.serie ||' '||a.no_documento || ' (' || d.sku_alterno || ')' no_documento, b.socio_alterno, b.nombre,
                       round((c.precio_unitario-nvl(round(c.descuento,8),0) +nvl(c.impuesto,0) )* c.cantidad, 8) total
                          FROM   WMS_DOCUMENTOS a, wms_socios b, wms_skus_x_documento c, wms_skus d
                    WHERE  a.tipo_documento = 'F'
                    AND    a.jornada IN ( p_jornada )
                    AND    NVL (a.situacion, 1) <> 11
                    and    a.socio = b.socio
                    --AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                    AND    a.documento = c.documento
                    and    c.usuario_anulo is null
                    and c.sku = d.sku
                    and    round(nvl(c.impuesto,0),2) > 0
                    UNION
                    select a.documento , a.serie ||' '||a.no_documento || ' (' || d.sku_alterno || ')' no_documento, b.socio_alterno, b.nombre,
                       round((c.precio_unitario-nvl(round(c.descuento,8),0) +nvl(c.impuesto,0) )* -c.cantidad, 8) total
                          FROM   WMS_DOCUMENTOS a, wms_socios b, wms_skus_x_documento c, wms_skus d
                    WHERE  a.tipo_documento = 'D'
                    AND    a.jornada IN ( p_jornada )
                    AND    NVL (a.situacion, 1) <> 11
                    and    a.socio = b.socio
                    --AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                    AND    a.documento = c.documento
                    and    c.usuario_anulo is null
                    and    c.sku = d.sku
                    and    round(nvl(c.impuesto,0),2) > 0);
            */

            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        1,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   'FA-GRAVADAS' no_documento,
                                  'GRAVADAS' socio_alterno,
                                  'PRODUCTOS GRAVADOS' nombre,
                                  ROUND (SUM (MONTO2), 2) total
                           FROM   WMS_HISTORICO_DETALLE_JORNADAS
                          WHERE   RUBRO = 551 AND JORNADA = P_JORNADA);

            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        2,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   'DEV-GRAVADAS' no_documento,
                                  'GRAVADAS' socio_alterno,
                                  'PRODUCTOS GRAVADOS' nombre,
                                  ROUND (SUM (-MONTO2), 2) total
                           FROM   WMS_HISTORICO_DETALLE_JORNADAS
                          WHERE   RUBRO = 554 AND JORNADA = P_JORNADA);
         -- TOTAL VENTAS EXCENTAS (SKU NO PAGA IMPUESTO )  - DEVOLUCIONES A VENTAS EXCENTAS
         ELSIF p_rubro = 558
         THEN
            /*
              INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (
                     jornada, rubro, linea, texto1, texto2, texto3, monto2 )
              SELECT p_jornada, p_rubro, ROWNUM, no_documento, socio_alterno, nombre, total
              FROM   (select a.documento , a.serie ||' '||a.no_documento || ' (' || d.sku_alterno || ')' no_documento, b.socio_alterno, b.nombre,
                       round((c.precio_unitario-nvl(round(c.descuento,8),0) +nvl(c.impuesto,0) )* c.cantidad, 8) total
                          FROM   WMS_DOCUMENTOS a, wms_socios b, wms_skus_x_documento c, wms_skus d
                    WHERE  a.tipo_documento = 'F'
                    AND    a.jornada IN ( p_jornada )
                    AND    NVL (a.situacion, 1) <> 11
                    and    a.socio = b.socio
              --      AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                    and    c.sku = d.sku
                    and    nvl(d.impuesto,1) = 0 -- VENTAS EXCENTAS SON A PRODUCTOS QUE NO PAGAN IMPUESTOS
                    AND    a.documento = c.documento
                    and    c.usuario_anulo is null
                    and    round(nvl(c.impuesto,0),2) = 0
                    UNION
                    select a.documento , a.serie ||' '||a.no_documento || ' (' || d.sku_alterno || ')' no_documento, b.socio_alterno, b.nombre,
                       round((c.precio_unitario-nvl(round(c.descuento,8),0) +nvl(c.impuesto,0) )* -c.cantidad, 8) total
                          FROM   WMS_DOCUMENTOS a, wms_socios b, wms_skus_x_documento c, wms_skus d
                    WHERE  a.tipo_documento = 'D'
                    AND    a.jornada IN ( p_jornada )
                    AND    NVL (a.situacion, 1) <> 11
                    and    a.socio = b.socio
              --      AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                    and    c.sku = d.sku
                    and    nvl(d.impuesto,1) = 0 -- VENTAS EXCENTAS SON A PRODUCTOS QUE NO PAGAN IMPUESTOS
                    AND    a.documento = c.documento
                    and    c.usuario_anulo is null
                    and    round(nvl(c.impuesto,0),2) = 0);
            */

            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        1,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   'FA-EXENTAS' no_documento,
                                  'EXENTAS' socio_alterno,
                                  'PRODUCTOS EXENTOS' nombre,
                                  ROUND (SUM (MONTO2), 2) total
                           FROM   WMS_HISTORICO_DETALLE_JORNADAS
                          WHERE   RUBRO = 552 AND JORNADA = P_JORNADA);

            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        2,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   'DEV-EXENTAS' no_documento,
                                  'EXENTOS' socio_alterno,
                                  'PRODUCTOS EXENTOS' nombre,
                                  ROUND (SUM (-MONTO2), 2) total
                           FROM   WMS_HISTORICO_DETALLE_JORNADAS
                          WHERE   RUBRO = 555 AND JORNADA = P_JORNADA);
         -- PAGOS EN TARJETA DE CREDITO
         ELSIF p_rubro = 213
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   a.documento,
                                  a.serie || ' ' || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '1'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                         UNION ALL                  --DEVOLUCIONES  EN TARJETA
                         SELECT   a.documento,
                                     'DEV TARJETA.#'
                                  || a.serie
                                  || ' '
                                  || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     a.total,
                                     a.total / NVL (a.tasa_cambio_ma, 1)
                                  )
                                  * -1
                                     total
                           FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b
                          WHERE       a.tipo_documento = 'D'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND SUBTIPO_DOCUMENTO IN ('A')
                                  AND NVL (a.situacion, 1) <> 11);
         -- PAGOS EN CHEQUE
         ELSIF p_rubro = 221
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   a.documento,
                                  a.serie || ' ' || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '4'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                         UNION ALL                   --DEVOLUCIONES  EN CHEQUE
                         SELECT   a.documento,
                                     'DEV CHEQUE.#'
                                  || a.serie
                                  || ' '
                                  || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     a.total,
                                     a.total / NVL (a.tasa_cambio_ma, 1)
                                  )
                                  * -1
                                     total
                           FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b
                          WHERE       a.tipo_documento = 'D'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND SUBTIPO_DOCUMENTO = 'T'
                                  AND NVL (a.situacion, 1) <> 11);
         -- PAGOS EN EFECTIVO
         ELSIF p_rubro = 209
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total
                 FROM   (SELECT   a.documento,
                                  a.serie || ' ' || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     c.valor,
                                     c.valor / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  wms_pago_documentos c
                          WHERE       a.tipo_documento = 'R'
                                  AND A.DOCUMENTO = C.DOCUMENTO
                                  AND C.TIPO_PAGO = '3'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11
                         UNION ALL                 --DEVOLUCIONES  EN EFECTIVO
                         SELECT   a.documento,
                                     'DEV EFEC.#'
                                  || a.serie
                                  || ' '
                                  || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     a.total,
                                     a.total / NVL (a.tasa_cambio_ma, 1)
                                  )
                                  * -1
                                     total
                           FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b
                          WHERE       a.tipo_documento = 'D'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND SUBTIPO_DOCUMENTO = 'D'
                                  AND NVL (a.situacion, 1) <> 11);
         -- DEVOLUCIONES POR TIPO DE DEVOLUCION
         ELSIF p_rubro = 518
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2,
                                                        texto4)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        total,
                        Tipo
                 FROM   (SELECT   a.documento,
                                     C.RV_MEANING
                                  || ' -'
                                  || a.serie
                                  || ' '
                                  || a.no_documento
                                     no_documento,
                                  b.socio_alterno,
                                  b.nombre,
                                  a.jornada,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     a.total,
                                     a.total / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total,
                                  C.RV_MEANING tipo
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SOCIOS b,
                                  CG_REF_CODES C
                          WHERE       a.tipo_documento = 'D'
                                  AND a.socio = b.socio(+)
                                  AND a.jornada IN (p_jornada)
                                  AND C.RV_DOMAIN = 'TIPO DEVOLUCION'
                                  AND A.SUBTIPO_DOCUMENTO = C.RV_LOW_VALUE
                                  AND NVL (a.situacion, 1) <> 11);
         -- RECIBOS DE PAGO OTRA JORNADA
         ELSIF p_rubro = 167
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        jornada,
                        fecha,
                        total
                 FROM   (SELECT   b.serie || ' ' || b.no_documento
                                     no_documento,
                                  b.jornada,
                                  TO_CHAR (TRUNC (b.fecha_emision),
                                           'dd/mm/yyyy')
                                     fecha,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     NVL (a.valor, 0),
                                     NVL (a.valor, 0)
                                     / NVL (b.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   DOC_ABONO_DOCUMENTOS a,
                                  WMS_DOCUMENTOS b,
                                  WMS_DOCUMENTOS c
                          WHERE       a.recibo = b.documento
                                  AND a.documento = c.documento
                                  AND b.jornada <> c.jornada
                                  AND c.jornada IN (p_jornada)
                                  AND NVL (b.situacion, 1) <> 11);
         -- RECIBOS DE PAGO OTRA JORNADA
         ELSIF p_rubro = 168
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        texto4,
                                                        texto5,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        socio_alterno,
                        nombre,
                        subtipo_documento,
                        observaciones,
                        total
                 FROM   (SELECT   c.serie || ' ' || c.no_documento
                                     no_documento,
                                  d.socio_alterno,
                                  d.nombre,
                                  Cg_F_Code_Meaning ('TIPO NOTA DEBITO',
                                                     c.subtipo_documento)
                                     subtipo_documento,
                                  c.observaciones,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     NVL (b.valor, 0),
                                     NVL (b.valor, 0)
                                     / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total
                           FROM   WMS_DOCUMENTOS a,
                                  DOC_ABONO_DOCUMENTOS b,
                                  WMS_DOCUMENTOS c,
                                  WMS_SOCIOS d
                          WHERE       a.tipo_documento = 'R'
                                  AND NVL (a.situacion, 1) <> 11
                                  AND a.jornada IN (p_jornada)
                                  AND a.documento = b.recibo
                                  AND b.documento = c.documento
                                  AND c.tipo_documento = 'B'
                                  AND c.socio = d.socio
                                  AND d.cliente = 'S');
         -- COBROS FACTURAS CREDITO
         ELSIF p_rubro = 169
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        total
                 FROM   (  SELECT   c.serie || ' ' || c.no_documento
                                       no_documento,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       SUM (NVL (b.valor, 0)),
                                       SUM(NVL (b.valor, 0)
                                           / NVL (c.tasa_cambio_ma, 1))
                                    )
                                       total
                             FROM   WMS_DOCUMENTOS a,
                                    DOC_ABONO_DOCUMENTOS b,
                                    WMS_DOCUMENTOS c
                            WHERE       a.tipo_documento = 'R'
                                    AND NVL (a.situacion, 1) <> 11
                                    AND a.jornada IN (p_jornada)
                                    AND a.documento = b.recibo
                                    AND b.documento = c.documento
                                    AND c.tipo_documento = 'F'
                                    AND c.jornada NOT IN (p_jornada)
                         GROUP BY   c.serie, c.no_documento);
         -- PAGOS ANTICIPADOS
         ELSIF p_rubro = 170
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        fecha_emision,
                        total
                 FROM   (SELECT   a.serie || ' ' || a.no_documento
                                     no_documento,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     (NVL (a.total, 0)
                                      - NVL (abono_documentos (a.documento),
                                             0)),
                                     (NVL (a.total, 0)
                                      - NVL (abono_documentos (a.documento),
                                             0))
                                     / NVL (a.tasa_cambio_ma, 1)
                                  )
                                     total,
                                  TO_CHAR (a.fecha_emision, 'dd/mm/yyyy')
                                     fecha_emision
                           FROM   WMS_DOCUMENTOS a
                          WHERE   a.tipo_documento = 'R'
                                  AND NVL (abono_documentos(a.documento), 0) <
                                        a.total
                                  AND a.jornada IN (p_jornada)
                                  AND NVL (a.situacion, 1) <> 11);
         -- OTROS INGRESOS
         ELSIF p_rubro = 171
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        fecha_emision,
                        total
                 FROM   (SELECT   b.serie || ' ' || b.no_documento
                                     no_documento,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     a.valor,
                                     a.valor / NVL (b.tasa_cambio_ma, 1)
                                  )
                                     total,
                                  TO_CHAR (b.fecha_emision, 'dd/mm/yyyy')
                                     fecha_emision
                           FROM   DOC_ABONO_DOCUMENTOS a, WMS_DOCUMENTOS b
                          WHERE       a.recibo = b.documento
                                  AND b.jornada IN (p_jornada)
                                  AND a.tipo_documento = 'P');
         -- COBROS PROPINAS NO FACTURADAS
         ELSIF p_rubro = 172
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        total
                 FROM   (  SELECT   serie || ' ' || no_documento no_documento,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       NVL (SUM (propina), 0),
                                       SUM(NVL (propina, 0)
                                           / NVL (tasa_cambio_ma, 1))
                                    )
                                       total
                             FROM   WMS_DOCUMENTOS
                            WHERE       jornada IN (p_jornada)
                                    AND NVL (imprimir_propina, 'N') = 'N'
                                    AND tipo_documento = 'F'
                                    AND NVL (situacion, 1) <> 11
                                    AND NVL (propina, 0) > 0
                         GROUP BY   serie, no_documento);
         -- PAGOS EFECTIVO MB
         -- PAGOS TARJETA DE CREDITO MB
         -- PAGOS TARJETA DE DEBITO MB
         -- EXONERACION DE IMPUESTO
         ELSIF p_rubro IN (175, 176, 177, 183)
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        texto4,
                                                        texto5,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        facturas,
                        DECODE (p_rubro, 183, nombre, emisor),
                        tarjeta,
                        autorizacion,
                        total
                 FROM   (SELECT   b.serie || ' ' || b.no_documento
                                     no_documento,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     NVL (a.valor, 0) + NVL (a.propina, 0),
                                     NVL (a.valor, 0)
                                     + NVL (a.propina, 0)
                                       / NVL (b.tasa_cambio_ma, 1)
                                  )
                                     total,
                                  Cg_F_Code_Meaning ('TARJETA', a.emisor)
                                     emisor,
                                  a.tarjeta,
                                  a.autorizacion,
                                  c.nombre,
                                  Wms_F_Facturas_Recibo (b.documento)
                                     facturas
                           FROM   WMS_PAGO_DOCUMENTOS a,
                                  WMS_DOCUMENTOS b,
                                  WMS_SOCIOS c
                          WHERE       a.documento = b.documento
                                  AND b.jornada IN (p_jornada)
                                  AND a.tipo_pago = DECODE (p_rubro,
                                                            175,
                                                            3,
                                                            176,
                                                            1,
                                                            177,
                                                            2,
                                                            183,
                                                            12)
                                  AND b.tipo_documento = 'R'
                                  AND NVL (b.situacion, 1) <> 11
                                  AND b.socio = c.socio(+)
                                  AND c.cliente(+) = 'S');

            IF p_rubro IN (175, 176)
            THEN
               -- Obteniendo el siguiente numero de linea
               IF p_rubro = 175
               THEN --Modificado por Randall, 9-6-08, insertar devolucion de caja chica
                  SELECT   NVL (MAX (linea), 0) + 1
                    INTO   v_linea
                    FROM   WMS_HISTORICO_DETALLE_JORNADAS
                   WHERE   jornada = p_jornada AND rubro = p_rubro;

                  -- Agregando monto en devoluciones en efectivo
                  INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                              rubro,
                                                              linea,
                                                              texto1,
                                                              monto2)
                     SELECT   p_jornada,
                              p_rubro,
                              v_linea,
                              no_documento,
                              -total
                       FROM   (SELECT      '(-) Dev. '
                                        || DECODE (p_rubro,
                                                   175,
                                                   'Efectivo',
                                                   176,
                                                   'Credito')
                                        || ''
                                           no_documento,
                                        NVL (SUM (total), 0) total
                                 FROM   WMS_DOCUMENTOS
                                WHERE   tipo_documento = 'D'
                                        AND subtipo_documento =
                                              DECODE (p_rubro,
                                                      175,
                                                      'D',
                                                      176,
                                                      'A')
                                        AND jornada IN (p_jornada))
                     UNION
                     SELECT   p_jornada,
                              p_rubro,
                              30,
                              '(-) Gastos de Caja Chica' no_documento,
                              -NVL (SUM (VALOR), 0)
                       FROM   WMS_GASTOS_JORNADA
                      WHERE   JORNADA = p_jornada;
               ELSE
                  SELECT   NVL (MAX (linea), 0) + 1
                    INTO   v_linea
                    FROM   WMS_HISTORICO_DETALLE_JORNADAS
                   WHERE   jornada = p_jornada AND rubro = p_rubro;

                  -- Agregando monto en devoluciones en efectivo
                  INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                              rubro,
                                                              linea,
                                                              texto1,
                                                              monto2)
                     SELECT   p_jornada,
                              p_rubro,
                              v_linea,
                              no_documento,
                              -total
                       FROM   (SELECT      '(-) Dev. '
                                        || DECODE (p_rubro,
                                                   175,
                                                   'Efectivo',
                                                   176,
                                                   'Credito')
                                        || ''
                                           no_documento,
                                        NVL (SUM (total), 0) total
                                 FROM   WMS_DOCUMENTOS
                                WHERE   tipo_documento = 'D'
                                        AND subtipo_documento =
                                              DECODE (p_rubro,
                                                      175,
                                                      'D',
                                                      176,
                                                      'A')
                                        AND jornada IN (p_jornada));
               END IF;
            END IF;
         -- PAGOS CHEQUE MB
         -- DEPOSITOS MB
         ELSIF p_rubro IN (178, 182)
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        texto4,
                                                        texto5,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        facturas,
                        banco,
                        DECODE (p_rubro,
                                178,
                                cheque,
                                182,
                                deposito),
                        autorizacion,
                        total
                 FROM   (SELECT   b.serie || ' ' || b.no_documento
                                     no_documento,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     NVL (a.valor, 0) + NVL (a.propina, 0),
                                     NVL (a.valor, 0)
                                     + NVL (a.propina, 0)
                                       / NVL (b.tasa_cambio_ma, 1)
                                  )
                                     total,
                                  Cg_F_Code_Meaning ('BANCOS', a.banco) banco,
                                  a.cheque,
                                  a.deposito,
                                  a.autorizacion,
                                  Wms_F_Facturas_Recibo (b.documento)
                                     facturas
                           FROM   WMS_PAGO_DOCUMENTOS a, WMS_DOCUMENTOS b
                          WHERE       a.documento = b.documento
                                  AND b.jornada IN (p_jornada)
                                  AND a.tipo_pago = DECODE (p_rubro,
                                                            178,
                                                            4,
                                                            182,
                                                            2)
                                  AND b.tipo_documento = 'R'
                                  AND NVL (b.situacion, 1) <> 11);
         -- VALES Y CERTIFICADOS DE REGALO
         ELSIF p_rubro IN (179, 180)
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        texto4,
                                                        texto5,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        facturas,
                        vale,
                        nombre,
                        fecha_emision,
                        total
                 FROM   (SELECT   b.serie || ' ' || b.no_documento
                                     no_documento,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     NVL (a.valor, 0),
                                     NVL (a.valor, 0)
                                     / NVL (b.tasa_cambio_ma, 1)
                                  )
                                     total,
                                  c.nombre,
                                  TO_CHAR (b.fecha_emision, 'dd/mm/yyyy')
                                     fecha_emision,
                                  e.vale,
                                  Wms_F_Facturas_Recibo (b.documento)
                                     facturas
                           FROM   WMS_PAGO_DOCUMENTOS a,
                                  WMS_DOCUMENTOS b,
                                  WMS_SOCIOS c,
                                  DOC_VALES e
                          WHERE       a.documento = b.documento
                                  AND b.jornada IN (p_jornada)
                                  AND a.tipo_pago IN (6, 24)
                                  AND b.tipo_documento = 'R'
                                  AND NVL (b.situacion, 1) <> 11
                                  AND a.vale = e.vale
                                  AND e.tipo = DECODE (p_rubro,
                                                       179,
                                                       'D',
                                                       180,
                                                       'A')
                                  AND b.socio = c.socio(+)
                                  AND c.cliente(+) = 'S');
         -- VALES Y CERTIFICADOS DE REGALO v.6.X
         ELSIF p_rubro IN (330, 331)
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        texto4,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        vale,
                        nombre,
                        fecha_emision,
                        total
                 FROM   (SELECT   a.serie || ' ' || a.no_documento
                                     no_documento,
                                  -DECODE (
                                      Cg_F_Parameter_Value ('MOJO'),
                                      'MB',
                                      (b.cantidad
                                       * (b.precio_unitario + b.impuesto)),
                                      (b.cantidad
                                       * (b.precio_unitario + b.impuesto))
                                      / NVL (a.tasa_cambio_ma, 1)
                                   )
                                     total,
                                  c.nombre,
                                  TO_CHAR (a.fecha_emision, 'dd/mm/yyyy')
                                     fecha_emision,
                                  d.vale
                           FROM   WMS_DOCUMENTOS a,
                                  WMS_SKUS_X_DOCUMENTO b,
                                  WMS_SOCIOS c,
                                  DOC_VALES d
                          WHERE       a.documento = b.documento
                                  AND a.jornada IN (p_jornada)
                                  AND a.tipo_documento = 'F'
                                  AND NVL (a.situacion, 1) <> 11
                                  AND b.vale = d.vale
                                  AND d.tipo = DECODE (p_rubro,
                                                       330,
                                                       'D',
                                                       331,
                                                       'A')
                                  AND b.cantidad < 0
                                  AND a.socio = c.socio(+)
                                  AND c.cliente(+) = 'S');
         -- VALES Y CERTIFICADOS DE REGALO EMITIDOS
         ELSIF p_rubro IN (361, 362)
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        texto4,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        a_nombre_de,
                        fecha_emision,
                        fecha_vencimiento,
                        total
                 FROM   (SELECT   a.vale no_documento,
                                  NVL (a.monto, 0) total,
                                  a.a_nombre_de,
                                  TO_CHAR (a.creado_el, 'dd/mm/yyyy')
                                     fecha_emision,
                                  TO_CHAR (a.vence_el, 'dd/mm/yyyy')
                                     fecha_vencimiento
                           FROM   DOC_VALES a
                          WHERE   a.jornada IN (p_jornada)
                                  AND a.tipo = DECODE (p_rubro,
                                                       361,
                                                       'D',
                                                       362,
                                                       'A'));
         -- PAGOS OTRAS MONEDAS
         ELSIF p_rubro = 181
         THEN
            -- Obteniendo moneda por omision
            SELECT   rv_low_value
              INTO   v_moneda
              FROM   CG_REF_CODES
             WHERE   rv_domain = 'MONEDA' AND rv_mpnc01 = 1;

            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        texto4,
                                                        texto5,
                                                        monto1,
                                                        monto2,
                                                        monto3)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        facturas,
                        moneda,
                        TO_CHAR (pagado, '999,999,990.00'),
                        TO_CHAR (tasa_cambio, '999,990.00'),
                        vuelto,
                        total,
                        pagado_om
                 FROM   (SELECT   b.serie || ' ' || b.no_documento
                                     no_documento,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     (NVL (a.valor, 0) + NVL (a.propina, 0)),
                                     (NVL (a.valor, 0) + NVL (a.propina, 0))
                                     / NVL (b.tasa_cambio_ma, 1)
                                  )
                                     total,
                                  Cg_F_Code_Meaning (
                                     'MONEDA',
                                     NVL (a.moneda, v_moneda)
                                  )
                                     moneda,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     NVL (a.pagado, 0),
                                     NVL (a.pagado, 0)
                                     / NVL (b.tasa_cambio_ma, 1)
                                  )
                                     pagado,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     NVL (a.tasa_cambio, 0),
                                     NVL (a.tasa_cambio, 0)
                                     / NVL (b.tasa_cambio_ma, 1)
                                  )
                                     tasa_cambio,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     NVL (a.pagado, 0)
                                     - (NVL (a.valor, 0) + NVL (a.propina, 0)),
                                     NVL (a.pagado, 0)
                                     - (NVL (a.valor, 0) + NVL (a.propina, 0))
                                       / NVL (b.tasa_cambio_ma, 1)
                                  )
                                     vuelto,
                                  NVL (a.pagado, 0) / NVL (a.tasa_cambio, 1)
                                     pagado_om,
                                  Wms_F_Facturas_Recibo (b.documento)
                                     facturas
                           FROM   WMS_PAGO_DOCUMENTOS a,
                                  WMS_DOCUMENTOS b,
                                  WMS_SOCIOS c
                          WHERE       a.documento = b.documento
                                  AND b.jornada IN (p_jornada)
                                  AND a.tipo_pago = 11
                                  AND b.tipo_documento = 'R'
                                  AND NVL (b.situacion, 1) <> 11
                                  AND b.socio = c.socio(+)
                                  AND c.cliente(+) = 'S');
         -- PAGOS EFECTIVO MA
         ELSIF p_rubro = 184
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        total
                 FROM   (SELECT   b.serie || ' ' || b.no_documento
                                     no_documento,
                                  (NVL (a.valor, 0) + NVL (a.propina, 0))
                                  / NVL (b.tasa_cambio_ma, 1)
                                     total,
                                  Cg_F_Code_Meaning ('TARJETA', a.emisor)
                                     emisor,
                                  a.tarjeta,
                                  a.autorizacion,
                                  c.nombre,
                                  Wms_F_Facturas_Recibo (b.documento)
                                     facturas
                           FROM   WMS_PAGO_DOCUMENTOS a,
                                  WMS_DOCUMENTOS b,
                                  WMS_SOCIOS c
                          WHERE       a.documento = b.documento
                                  AND b.jornada IN (p_jornada)
                                  AND a.tipo_pago = 17
                                  AND b.tipo_documento = 'R'
                                  AND NVL (b.situacion, 1) <> 11
                                  AND b.socio = c.socio(+)
                                  AND c.cliente(+) = 'S');
         ELSIF p_rubro = 278
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        texto4,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        facturas,
                        beneficiario,
                        nombre,
                        total
                 FROM   (SELECT   b.serie || ' ' || b.no_documento
                                     no_documento,
                                  DECODE (
                                     Cg_F_Parameter_Value ('MOJO'),
                                     'MB',
                                     NVL (a.donado, 0),
                                     NVL (a.donado, 0)
                                     / NVL (b.tasa_cambio_ma, 1)
                                  )
                                     total,
                                  c.nombre,
                                  Wms_F_Facturas_Recibo (b.documento)
                                     facturas,
                                  Cg_F_Code_Meaning ('BENEFICIARIO DONACION',
                                                     a.beneficiario_donacion)
                                     beneficiario
                           FROM   WMS_PAGO_DOCUMENTOS a,
                                  WMS_DOCUMENTOS b,
                                  WMS_SOCIOS c
                          WHERE       a.documento = b.documento
                                  AND b.jornada IN (p_jornada)
                                  AND b.tipo_documento = 'R'
                                  AND NVL (a.donado, 0) > 0
                                  AND NVL (b.situacion, 1) <> 11
                                  AND b.socio = c.socio(+)
                                  AND c.cliente(+) = 'S');
         -- CAJA CHICA
         ELSIF p_rubro = 269
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        tipo_gasto,
                        simbolo_moneda,
                        observaciones,
                        valor
                 FROM   (SELECT   a.jornada,
                                  a.linea,
                                  Cg_F_Code_Meaning ('TIPO GASTO JORNADA',
                                                     a.tipo_gasto)
                                     tipo_gasto,
                                  Wms_F_Simbolo_Moneda (a.moneda)
                                     simbolo_moneda,
                                  observaciones,
                                  valor
                           FROM   WMS_GASTOS_JORNADA a
                          WHERE   a.jornada IN (p_jornada));
         /* ESTADISTICAS */
         -- FACTURACION POR DOCUMENTO
         ELSIF p_rubro = 194
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto4,
                                                        texto5,
                                                        monto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        ROUND (monto, 2),
                        ROUND (impuesto, 2),
                        ROUND (propina, 2),
                        ROUND (total, 2)
                 FROM   (  SELECT   b.serie || ' ' || b.no_documento
                                       no_documento,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       (SUM( (  NVL (a.precio_unitario, 0)
                                              + NVL (a.impuesto, 0)
                                              - NVL (a.descuento, 0))
                                            * NVL (a.cantidad, 0))),
                                       (SUM( (  NVL (a.precio_unitario, 0)
                                              + NVL (a.impuesto, 0)
                                              - NVL (a.descuento, 0))
                                            * NVL (a.cantidad, 0)))
                                       / MAX (NVL (b.tasa_cambio_ma, 1))
                                    )
                                       monto,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       (SUM(NVL (a.impuesto, 0)
                                            * NVL (a.cantidad, 0))
                                        + ( (DECODE (
                                                NVL (MAX (b.imprimir_propina),
                                                     'N'),
                                                'S',
                                                NVL (MAX (b.propina), 0),
                                                0
                                             )
                                             / (1
                                                + NVL (
                                                     Cg_F_Parameter_Value (
                                                        'PIVA'
                                                     ),
                                                     12
                                                  )
                                                  / 100))
                                           * NVL (
                                                Cg_F_Parameter_Value ('PIVA'),
                                                12
                                             ))),
                                       (SUM(NVL (a.impuesto, 0)
                                            * NVL (a.cantidad, 0))
                                        + ( (DECODE (
                                                NVL (MAX (b.imprimir_propina),
                                                     'N'),
                                                'S',
                                                NVL (MAX (b.propina), 0),
                                                0
                                             )
                                             / (1
                                                + NVL (
                                                     Cg_F_Parameter_Value (
                                                        'PIVA'
                                                     ),
                                                     12
                                                  )
                                                  / 100))
                                           * NVL (
                                                Cg_F_Parameter_Value ('PIVA'),
                                                12
                                             )))
                                       / MAX (NVL (b.tasa_cambio_ma, 1))
                                    )
                                       impuesto,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       (DECODE (
                                           NVL (MAX (b.imprimir_propina), 'N'),
                                           'S',
                                           NVL (MAX (b.propina), 0),
                                           0
                                        )),
                                       (DECODE (
                                           NVL (MAX (b.imprimir_propina), 'N'),
                                           'S',
                                           NVL (MAX (b.propina), 0),
                                           0
                                        ))
                                       / MAX (NVL (b.tasa_cambio_ma, 1))
                                    )
                                       propina,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       (SUM( (  NVL (a.precio_unitario, 0)
                                              + NVL (a.impuesto, 0)
                                              - NVL (a.descuento, 0))
                                            * NVL (a.cantidad, 0)))
                                       + DECODE (
                                            NVL (MAX (b.imprimir_propina), 'N'),
                                            'S',
                                            NVL (MAX (b.propina), 0),
                                            0
                                         ),
                                       ( (SUM( (  NVL (a.precio_unitario, 0)
                                                + NVL (a.impuesto, 0)
                                                - NVL (a.descuento, 0))
                                              * NVL (a.cantidad, 0)))
                                        + DECODE (
                                             NVL (MAX (b.imprimir_propina),
                                                  'N'),
                                             'S',
                                             NVL (MAX (b.propina), 0),
                                             0
                                          ))
                                       / MAX (NVL (b.tasa_cambio_ma, 1))
                                    )
                                       total
                             FROM   WMS_SKUS_X_DOCUMENTO a, WMS_DOCUMENTOS b
                            WHERE   a.documento = b.documento
                                    AND b.tipo_documento = 'F'
                                    AND b.jornada IN
                                             (SELECT   jornada
                                                FROM   WMS_JORNADAS
                                               WHERE   fecha_apertura BETWEEN TRUNC(p_fecha_inicial)
                                                                          AND  TRUNC(p_fecha_final)
                                                                               + 0.99999)
                                    AND NVL (b.situacion, 1) <> 11
                         GROUP BY   b.documento, b.serie, b.no_documento
                         ORDER BY   b.documento);
         -- FACTURACION POR PRODUCTO
         ELSIF p_rubro = 195
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        descripcion,
                        ROUND (cantidad, 2),
                        ROUND (total, 2)
                 FROM   (  SELECT   c.descripcion,
                                    SUM (a.cantidad) cantidad,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       (SUM( (  NVL (a.precio_unitario, 0)
                                              + NVL (a.impuesto, 0)
                                              - NVL (a.descuento, 0))
                                            * NVL (a.cantidad, 0))),
                                       (SUM( (  NVL (a.precio_unitario, 0)
                                              + NVL (a.impuesto, 0)
                                              - NVL (a.descuento, 0))
                                            * NVL (a.cantidad, 0)))
                                       / MAX (NVL (b.tasa_cambio_ma, 1))
                                    )
                                       total
                             FROM   WMS_SKUS_X_DOCUMENTO a,
                                    WMS_DOCUMENTOS b,
                                    WMS_SKUS c
                            WHERE       a.documento = b.documento
                                    AND a.sku = c.sku
                                    AND b.tipo_documento = 'F'
                                    AND b.jornada IN
                                             (SELECT   jornada
                                                FROM   WMS_JORNADAS
                                               WHERE   fecha_apertura BETWEEN TRUNC(p_fecha_inicial)
                                                                          AND  TRUNC(p_fecha_final)
                                                                               + 0.99999)
                                    AND NVL (b.situacion, 1) <> 11
                         GROUP BY   c.descripcion
                         ORDER BY   c.descripcion);
         -- FACTURACION POR EMPLEADO
         ELSIF p_rubro = 196
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto4,
                                                        texto5,
                                                        monto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        nombre,
                        ROUND (monto, 2),
                        ROUND (impuesto, 2),
                        ROUND (propina, 2),
                        ROUND (monto + impuesto + propina, 2)
                 FROM   (  SELECT   c.usuario,
                                    NVL (c.nombres, c.usuario) nombre,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       (SUM( (NVL (a.precio_unitario, 0)
                                              - NVL (a.descuento, 0))
                                            * NVL (a.cantidad, 0))),
                                       (SUM( (NVL (a.precio_unitario, 0)
                                              - NVL (a.descuento, 0))
                                            * NVL (a.cantidad, 0)))
                                       / MAX (NVL (b.tasa_cambio_ma, 1))
                                    )
                                       monto,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       (SUM(NVL (a.impuesto, 0)
                                            * NVL (a.cantidad, 0)))
                                       + NVL (
                                            ( (MAX( (wms_f_propina (
                                                        p_fecha_inicial,
                                                        p_fecha_final,
                                                        b.usuario1
                                                     )))
                                               / (1
                                                  + NVL (
                                                       Cg_F_Parameter_Value (
                                                          'PIVA'
                                                       ),
                                                       12
                                                    )
                                                    / 100))
                                             * NVL (
                                                  Cg_F_Parameter_Value ('PIVA'),
                                                  12
                                               )),
                                            0
                                         ),
                                       ( (SUM(NVL (a.impuesto, 0)
                                              * NVL (a.cantidad, 0)))
                                        + NVL (
                                             ( (MAX( (wms_f_propina (
                                                         p_fecha_inicial,
                                                         p_fecha_final,
                                                         b.usuario1
                                                      )))
                                                / (1
                                                   + NVL (
                                                        Cg_F_Parameter_Value (
                                                           'PIVA'
                                                        ),
                                                        12
                                                     )
                                                     / 100))
                                              * NVL (
                                                   Cg_F_Parameter_Value (
                                                      'PIVA'
                                                   ),
                                                   12
                                                )),
                                             0
                                          ))
                                       / MAX (NVL (b.tasa_cambio_ma, 1))
                                    )
                                       impuesto,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       NVL (
                                          MAX( (wms_f_propina (p_fecha_inicial,
                                                               p_fecha_final,
                                                               b.usuario1)))
                                          / (1
                                             + NVL (
                                                  Cg_F_Parameter_Value ('PIVA'),
                                                  12
                                               )
                                               / 100),
                                          0
                                       ),
                                       NVL (
                                          MAX( (wms_f_propina (p_fecha_inicial,
                                                               p_fecha_final,
                                                               b.usuario1)))
                                          / (1
                                             + NVL (
                                                  Cg_F_Parameter_Value ('PIVA'),
                                                  12
                                               )
                                               / 100),
                                          0
                                       )
                                       / MAX (NVL (b.tasa_cambio_ma, 1))
                                    )
                                       propina
                             FROM   WMS_SKUS_X_DOCUMENTO a,
                                    WMS_DOCUMENTOS b,
                                    WMS_USUARIOS c
                            WHERE       a.documento = b.documento
                                    AND b.creado_por = c.usuario(+)
                                    AND b.tipo_documento = 'F'
                                    AND b.jornada IN
                                             (SELECT   jornada
                                                FROM   WMS_JORNADAS
                                               WHERE   fecha_apertura BETWEEN TRUNC(p_fecha_inicial)
                                                                          AND  TRUNC(p_fecha_final)
                                                                               + 0.99999)
                                    AND NVL (b.situacion, 1) <> 11
                         GROUP BY   c.usuario, NVL (c.nombres, c.usuario)
                         ORDER BY   2);
         -- ANULACIONES POR DOCUMENTO
         ELSIF p_rubro = 197
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto4,
                                                        texto5,
                                                        monto1,
                                                        monto2,
                                                        texto2,
                                                        texto3)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        ROUND (monto, 2),
                        ROUND (impuesto, 2),
                        ROUND (propina, 2),
                        ROUND (total, 2),
                        creado_por,
                        anulada_por
                 FROM   (  SELECT   b.serie || ' ' || b.no_documento
                                       no_documento,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       (SUM( (NVL (a.precio_unitario, 0)
                                              - NVL (a.descuento, 0))
                                            * NVL (a.cantidad, 0))),
                                       (SUM( (NVL (a.precio_unitario, 0)
                                              - NVL (a.descuento, 0))
                                            * NVL (a.cantidad, 0)))
                                       / MAX (NVL (b.tasa_cambio_ma, 1))
                                    )
                                       monto,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       SUM(NVL (a.impuesto, 0)
                                           * NVL (a.cantidad, 0))
                                       + ( (DECODE (
                                               NVL (MAX (b.imprimir_propina),
                                                    'N'),
                                               'S',
                                               NVL (MAX (b.propina), 0),
                                               0
                                            )
                                            / (1
                                               + NVL (
                                                    Cg_F_Parameter_Value (
                                                       'PIVA'
                                                    ),
                                                    12
                                                 )
                                                 / 100))
                                          * NVL (Cg_F_Parameter_Value ('PIVA'),
                                                 12)),
                                       SUM(NVL (a.impuesto, 0)
                                           * NVL (a.cantidad, 0))
                                       + ( (DECODE (
                                               NVL (MAX (b.imprimir_propina),
                                                    'N'),
                                               'S',
                                               NVL (MAX (b.propina), 0),
                                               0
                                            )
                                            / (1
                                               + NVL (
                                                    Cg_F_Parameter_Value (
                                                       'PIVA'
                                                    ),
                                                    12
                                                 )
                                                 / 100))
                                          * NVL (Cg_F_Parameter_Value ('PIVA'),
                                                 12))
                                         / MAX (NVL (b.tasa_cambio_ma, 1))
                                    )
                                       Impuesto,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       (DECODE (
                                           NVL (MAX (b.imprimir_propina), 'N'),
                                           'S',
                                           NVL (MAX (b.propina), 0),
                                           0
                                        )
                                        / (1
                                           + NVL (
                                                Cg_F_Parameter_Value ('PIVA'),
                                                12
                                             )
                                             / 100)),
                                       (DECODE (
                                           NVL (MAX (b.imprimir_propina), 'N'),
                                           'S',
                                           NVL (MAX (b.propina), 0),
                                           0
                                        )
                                        / (1
                                           + NVL (
                                                Cg_F_Parameter_Value ('PIVA'),
                                                12
                                             )
                                             / 100))
                                       / MAX (NVL (b.tasa_cambio_ma, 1))
                                    )
                                       Propina,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       (SUM( (  NVL (a.precio_unitario, 0)
                                              + NVL (a.impuesto, 0)
                                              - NVL (a.descuento, 0))
                                            * NVL (a.cantidad, 0)))
                                       + DECODE (
                                            NVL (MAX (b.imprimir_propina), 'N'),
                                            'S',
                                            NVL (MAX (b.propina), 0),
                                            0
                                         ),
                                       (SUM( (  NVL (a.precio_unitario, 0)
                                              + NVL (a.impuesto, 0)
                                              - NVL (a.descuento, 0))
                                            * NVL (a.cantidad, 0)))
                                       + DECODE (
                                            NVL (MAX (b.imprimir_propina), 'N'),
                                            'S',
                                            NVL (MAX (b.propina), 0),
                                            0
                                         )
                                         / MAX (NVL (b.tasa_cambio_ma, 1))
                                    )
                                       total,
                                    b.creado_por,
                                    b.anulada_por
                             FROM   WMS_SKUS_X_DOCUMENTO a, WMS_DOCUMENTOS b
                            WHERE   a.documento = b.documento
                                    AND b.tipo_documento = 'F'
                                    AND b.jornada IN
                                             (SELECT   jornada
                                                FROM   WMS_JORNADAS
                                               WHERE   fecha_apertura BETWEEN TRUNC(p_fecha_inicial)
                                                                          AND  TRUNC(p_fecha_final)
                                                                               + 0.99999)
                                    AND b.situacion = 11
                         GROUP BY   b.documento,
                                    b.serie,
                                    b.no_documento,
                                    b.creado_por,
                                    b.anulada_por
                         ORDER BY   b.documento);
         -- DESCUENTOS POR DOCUMENTO
         ELSIF p_rubro = 200
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2,
                                                        texto2,
                                                        texto3)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        ROUND (total, 2),
                        creado_por,
                        usuario
                 FROM   (  SELECT   b.serie || ' ' || b.no_documento
                                       no_documento,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       (SUM( (NVL (a.descuento, 0))
                                            * NVL (a.cantidad, 0))),
                                       (SUM( (NVL (a.descuento, 0))
                                            * NVL (a.cantidad, 0)))
                                       / MAX (NVL (b.tasa_cambio_ma, 1))
                                    )
                                       total,
                                    b.creado_por,
                                    a.usuario
                             FROM   WMS_SKUS_X_DOCUMENTO a, WMS_DOCUMENTOS b
                            WHERE   a.documento = b.documento
                                    AND b.tipo_documento = 'F'
                                    AND b.jornada IN
                                             (SELECT   jornada
                                                FROM   WMS_JORNADAS
                                               WHERE   fecha_apertura BETWEEN TRUNC(p_fecha_inicial)
                                                                          AND  TRUNC(p_fecha_final)
                                                                               + 0.99999)
                                    AND NVL (b.situacion, 1) <> 11
                                    AND NVL (a.descuento, 0) > 0
                         GROUP BY   b.documento,
                                    b.serie,
                                    b.no_documento,
                                    b.creado_por,
                                    a.usuario
                         ORDER BY   b.documento);
         -- PEDIDOS BONIFICADOS
         ELSIF p_rubro = 203
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        orden,
                        cortesias,
                        autorizo,
                        ROUND (total, 2)
                 FROM   (  SELECT   a.documento orden,
                                    a.no_documento cortesias,
                                    c.nombre autorizo,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       SUM(cantidad
                                           * (b.precio_unitario + b.impuesto))
                                       * (1
                                          + NVL (Cg_F_Parameter_Value ('PIVA'),
                                                 12)),
                                       SUM(cantidad
                                           * (b.precio_unitario + b.impuesto))
                                       * (1
                                          + NVL (Cg_F_Parameter_Value ('PIVA'),
                                                 12))
                                       / MAX (NVL (a.tasa_cambio_ma, 1))
                                    )
                                       Total
                             FROM   WMS_DOCUMENTOS a,
                                    WMS_SKUS_X_DOCUMENTO b,
                                    wms_v_usuarios c
                            WHERE       a.tipo_documento = 'P'
                                    AND a.bonificacion IS NOT NULL
                                    AND a.documento = b.documento
                                    AND b.usuario_anulo IS NULL
                                    AND b.usuario = c.usuario
                                    AND NVL (a.situacion, 1) <> 11
                                    AND a.jornada IN
                                             (SELECT   jornada
                                                FROM   WMS_JORNADAS
                                               WHERE   fecha_apertura BETWEEN TRUNC(p_fecha_inicial)
                                                                          AND  TRUNC(p_fecha_final)
                                                                               + 0.99999)
                         GROUP BY   a.documento, a.no_documento, c.nombre
                         ORDER BY   a.documento, a.no_documento);
         -- PEDIDOS ABIERTOS
         ELSIF p_rubro = 205
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        texto4,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        orden,
                        no_documento,
                        fecha_emision,
                        anulo,
                        ROUND (total, 2)
                 FROM   (  SELECT   a.documento orden,
                                    a.serie || ' ' || a.no_documento
                                       no_documento,
                                    a.fecha_emision,
                                    MAX (a.creado_por) anulo,
                                    SUM(NVL (b.cantidad, 1)
                                        * ( (  NVL (b.precio_unitario, 0)
                                             + NVL (b.impuesto, 0)
                                             - NVL (b.descuento, 0))))
                                       total
                             FROM   WMS_DOCUMENTOS a, WMS_SKUS_X_DOCUMENTO b
                            WHERE   a.tipo_documento = 'P'
                                    AND a.usuario2 IS NULL
                                    AND a.fecha_emision BETWEEN TRUNC(p_fecha_inicial)
                                                            AND  TRUNC(p_fecha_final)
                                                                 + 0.99999
                                    AND a.situacion IN (1, 3)
                                    AND a.fecha_vencimiento IS NULL
                                    AND a.tipo_documento = 'P'
                                    AND NVL (a.subtipo_documento, 'R') <> 'F'
                                    AND a.documento = b.documento(+)
                         GROUP BY   a.documento,
                                    a.serie,
                                    a.no_documento,
                                    a.fecha_emision
                         ORDER BY   a.documento);
         -- PEDIDOS ANULADOS
         ELSIF p_rubro = 206
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        texto4,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        orden,
                        no_documento,
                        creado_por,
                        anulada_por,
                        ROUND (total, 2)
                 FROM   (  SELECT   a.documento orden,
                                    a.serie || ' ' || a.no_documento
                                       no_documento,
                                    MAX (a.creado_por) creado_por,
                                    MAX (a.anulada_por) anulada_por,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       SUM(NVL (b.cantidad, 1)
                                           * (  NVL (b.precio_unitario, 0)
                                              - NVL (b.descuento, 0)
                                              + NVL (b.impuesto, 0))),
                                       SUM(NVL (b.cantidad, 1)
                                           * (  NVL (b.precio_unitario, 0)
                                              - NVL (b.descuento, 0)
                                              + NVL (b.impuesto, 0)))
                                       / MAX (NVL (a.tasa_cambio_ma, 1))
                                    )
                                       total
                             FROM   WMS_DOCUMENTOS a, WMS_SKUS_X_DOCUMENTO b
                            WHERE   a.tipo_documento = 'P'
                                    AND NVL (a.situacion, 1) = 11
                                    AND a.anulada_el BETWEEN TRUNC (
                                                                p_fecha_inicial
                                                             )
                                                         AND  TRUNC (
                                                                 p_fecha_final
                                                              )
                                                              + 0.99999
                                    AND a.documento = b.documento
                         GROUP BY   a.documento, a.serie, a.no_documento);
         -- PERSONAS ATENDIDAS
         ELSIF p_rubro = 207
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        no_documento,
                        ROUND (total, 2)
                 FROM   (  SELECT   a.serie || ' ' || a.no_documento
                                       no_documento,
                                    SUM (NVL (a.personas, 0)) total
                             FROM   WMS_DOCUMENTOS a
                            WHERE       a.tipo_documento = 'F'
                                    AND NVL (a.situacion, 1) <> 11
                                    AND NVL (a.personas, 0) > 0
                                    AND a.fecha_emision BETWEEN TRUNC(p_fecha_inicial)
                                                            AND  TRUNC(p_fecha_final)
                                                                 + 0.99999
                         GROUP BY   a.documento, a.serie, a.no_documento
                         ORDER BY   a.documento);
         -- PRODUCTOS ANULADOS
         ELSIF p_rubro = 208
         THEN
            INSERT INTO WMS_HISTORICO_DETALLE_JORNADAS (jornada,
                                                        rubro,
                                                        linea,
                                                        texto1,
                                                        texto2,
                                                        texto3,
                                                        texto4,
                                                        monto1,
                                                        monto2)
               SELECT   p_jornada,
                        p_rubro,
                        ROWNUM,
                        documento,
                        no_documento,
                        sku_alterno,
                        descripcion,
                        ROUND (cantidad, 2),
                        ROUND (total, 2)
                 FROM   (  SELECT   TO_CHAR (a.fecha_emision, 'dd/mm/yyyy')
                                       fecha_emision,
                                    a.documento,
                                    a.serie || ' ' || a.no_documento
                                       no_documento,
                                    c.sku_alterno,
                                    c.descripcion,
                                    DECODE (
                                       Cg_F_Parameter_Value ('MOJO'),
                                       'MB',
                                       (  NVL (b.precio_unitario, 0)
                                        + NVL (b.impuesto, 0)
                                        - NVL (b.descuento, 0))
                                       * NVL (b.cantidad, 0),
                                       (  NVL (b.precio_unitario, 0)
                                        + NVL (b.impuesto, 0)
                                        - NVL (b.descuento, 0))
                                       * NVL (b.cantidad, 0)
                                       / NVL (a.tasa_cambio_ma, 1)
                                    )
                                       total,
                                    NVL (b.cantidad, 0) cantidad
                             FROM   WMS_DOCUMENTOS a,
                                    WMS_SKUS_X_DOCUMENTO b,
                                    WMS_SKUS c
                            WHERE       a.documento = b.documento
                                    AND a.tipo_documento = 'P'
                                    AND b.usuario_anulo IS NOT NULL
                                    AND c.sku = b.sku
                                    AND a.fecha_emision BETWEEN TRUNC(p_fecha_inicial)
                                                            AND  TRUNC(p_fecha_final)
                                                                 + 0.99999
                         ORDER BY   1);
         END IF;
      END IF;

      -- Grabamos los cambios
      COMMIT;
   END detalle_jornada;

   --------------------------------------------------------------------------
   -- Este procedimiento actualiza las variables asociadas a los formatos
   -- de los cierres de caja ejecutados en el backoffice
   --------------------------------------------------------------------------
   PROCEDURE cierre_caja (p_jornada NUMBER)
   IS
      -- Obtenemos los tipos de pago asociados a variables
      CURSOR c_detalles
      IS
         SELECT   b.rv_low_value tipo_pago
           FROM   CG_REF_CODES a, CG_REF_CODES b
          WHERE   a.rv_domain = 'VARIABLE'
                  AND TO_NUMBER (a.rv_low_value) < 209
                  AND (INSTR (a.rv_mpcc01, 'RETAIL') > 0
                       OR INSTR (a.rv_mpcc01, 'J') > 0)
                  AND a.rv_high_value IS NOT NULL
                  AND b.rv_domain = 'TIPO PAGO'
                  AND a.rv_high_value = b.rv_low_value;

      -- Definimos Variables locales
      v_mojo         VARCHAR2 (2) := NVL (Cg_F_Parameter_Value ('MOJO'), 'MB');
      v_piva NUMBER (5, 2)
            := NVL (TO_NUMBER (Cg_F_Parameter_Value ('PIVA')), 0) / 100 ;
      v_resultado    NUMBER;
      v_resultado2   NUMBER;
      v_resultado3   NUMBER;
      v_total        NUMBER;
      v_factnettot   NUMBER;
      v_fecha        DATE;
      v_recibos      NUMBER;
      v_res1         NUMBER;
      v_res2         NUMBER;
      v_res3         NUMBER;

      V_EXISTE       NUMBER;

      V_IMP NUMBER (1)
            := NVL (TO_NUMBER (Cg_F_Parameter_Value ('IMP')), 0) ;
      V_REJO         VARCHAR2 (5) := CG_F_PARAMETER_VALUE ('REJO');
   BEGIN
      IF jornada_cerrada (p_jornada) = 'N'
      THEN
         -- Creamos el detalle de la jornada para que digite los montos el usuario
         FOR v_detalles IN c_detalles
         LOOP
            BEGIN
               INSERT INTO WMS_DETALLE_JORNADAS (jornada, tipo_pago, monto)
                 VALUES   (p_jornada, v_detalles.tipo_pago, 0);
            EXCEPTION
               WHEN DUP_VAL_ON_INDEX
               THEN
                  NULL;
            END;
         END LOOP;

         -- Eliminamos las variables del cierre excepto las estadisticas
         -- Estas se calculan en la pantalla de jornadas en el backoffice
         DELETE   WMS_HISTORICO_JORNADAS
          WHERE   jornada = p_jornada
                  AND ( (rubro < 194 OR rubro > 208) AND rubro <> 565);


         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', c.valor,
                                 c.valor / NVL (a.tasa_cambio_ma, 1)))
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a, wms_pago_documentos c
             WHERE       a.tipo_documento = 'R'
                     AND A.DOCUMENTO = C.DOCUMENTO
                     AND C.TIPO_PAGO = '3'
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 520, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 520  RECIBOS DE PAGO EN EFECTIVO SIN DEVOLUCIONES

         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM (TOTAL)
              INTO   v_resultado
              FROM   (SELECT   SUM (c.valor) TOTAL, 'VENTA'
                        FROM   WMS_DOCUMENTOS a, wms_pago_documentos c
                       WHERE       a.tipo_documento = 'R'
                               AND A.DOCUMENTO = C.DOCUMENTO
                               AND C.TIPO_PAGO = '3'
                               AND a.jornada IN (p_jornada)
                               --AND c.moneda = wms_f_moneda_alterna --ACC 01122020
                               AND c.moneda IN (wms_f_moneda_alterna, 8) --ACC 01122020
                               AND NVL (a.situacion, 1) <> 11
                      UNION
                      SELECT   SUM (R.PAGACON) TOTAL, 'RECNIC'
                        FROM   WMS_HABLAMAS_REQ R,
                               WMS_PAGUE_SERVICIOS S,
                               WMS_DOCUMENTOS D
                       WHERE       R.JORNADA = p_jornada
                               AND R.CODSTATE = 0
                               AND R.Moneda = 2
                               AND D.DOCUMENTO = S.DOCUMENTO
                               AND S.TIPO_SERVICIO = '04'
                               AND S.TRANS_PROVEEDOR = R.ID);
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 588, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 520  RECIBOS DE PAGO EN EFECTIVO SIN DEVOLUCIONES


         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', c.valor,
                                 c.valor / NVL (a.tasa_cambio_ma, 1)))
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a, wms_pago_documentos c
             WHERE       a.tipo_documento = 'R'
                     AND A.DOCUMENTO = C.DOCUMENTO
                     AND C.TIPO_PAGO IN ('6', '24', '16')
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND WMS_F_FACTANUL (A.DOCUMENTO_PADRE) <> 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- abonos por vales
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 567, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 520  RECIBOS DE PAGO EN EFECTIVO SIN DEVOLUCIONES

         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', c.valor,
                                 c.valor / NVL (a.tasa_cambio_ma, 1))
                         - b.total)
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a,
                     wms_pago_documentos c,
                     wms_documentos b
             WHERE       a.tipo_documento = 'R'
                     AND A.DOCUMENTO = C.DOCUMENTO
                     AND C.TIPO_PAGO = '1'
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND B.jornada IN (p_jornada)
                     AND NVL (B.situacion, 1) <> 11
                     AND B.TIPO_DOCUMENTO = 'D'
                     AND B.SUBTIPO_DOCUMENTO = 'A';
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;


         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 521, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 521  RECIBOS DE PAGO EN TARJETA DE CREDITO SIN DEVOLUCIONES



         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', c.valor,
                                 c.valor / NVL (a.tasa_cambio_ma, 1)))
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a, wms_pago_documentos c
             WHERE       a.tipo_documento = 'R'
                     AND A.DOCUMENTO = C.DOCUMENTO
                     AND C.TIPO_PAGO = '4'
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 519, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 519  RECIBOS DE PAGO EN CHEQUE SIN DEVOLUCIONES



         IF v_rejo = 'NO'
         THEN
            SELECT   SUM(DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', a.total,
                                 a.total / NVL (a.tasa_cambio_ma, 1)))
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b
             WHERE       a.tipo_documento = 'D'
                     AND a.socio = b.socio(+)
                     AND a.jornada IN (p_jornada)
                     AND SUBTIPO_DOCUMENTO IN ('C')
                     AND NVL (a.situacion, 1) <> 11;
         ELSE
            v_Resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- 540 = Devoluciones Credito (Acreditar)
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 540, NVL (v_resultado, 0));



         IF v_rejo = 'NO'
         THEN
            SELECT   SUM(DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', a.total,
                                 a.total / NVL (a.tasa_cambio_ma, 1)))
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b
             WHERE       a.tipo_documento = 'D'
                     AND a.socio = b.socio(+)
                     AND a.jornada IN (p_jornada)
                     AND SUBTIPO_DOCUMENTO IN ('T')
                     AND NVL (a.situacion, 1) <> 11;
         ELSE
            v_Resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- 541 Devoluciones Cheque
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 541, NVL (v_resultado, 0));


         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(ROUND (
                            f.precio_unitario
                            * DECODE (NVL (g.IMPUESTO, 1), 0, 1, 1.13),
                            2
                         )
                         * f.cantidad)
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a,
                     WMS_SOCIOS b,
                     doc_abono_documentos d,
                     wms_documentos e,
                     wms_skus_x_documento f,
                     wms_skus g
             WHERE       a.tipo_documento = 'R'
                     AND a.socio = b.socio(+)
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND d.recibo = a.documento
                     AND d.documento = e.documento
                     AND f.sku = g.sku
                     AND NVL (e.fecha_vencimiento, e.fecha_emision) =
                           NVL (e.fecha_emision, SYSDATE)
                     AND e.documento = f.documento
                     AND f.sku =
                           WMS_F_BUSCAR_SKU (CG_F_PARAMETER_VALUE ('SADO'))
                     AND f.USUARIO_ANULO IS NULL
                     AND WMS_F_FACTANUL (E.DOCUMENTO) <> 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- DONACIONES
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 600, NVL (v_resultado, 0));


         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', c.valor,
                                 c.valor / NVL (a.tasa_cambio_ma, 1)))
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a,
                     wms_pago_documentos c,
                     WMS_documentos b,
                     doc_abono_documentos d
             WHERE       a.tipo_documento = 'R'
                     AND A.DOCUMENTO = C.DOCUMENTO
                     AND C.TIPO_PAGO = '3'
                     AND a.jornada IN (p_jornada)
                     AND a.documento = d.recibo
                     AND d.documento = b.documento
                     AND b.jornada NOT IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND POS_F_ES_RECIBO_MARCHAMO (A.DOCUMENTO) = 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- RECIBOS DE PAGO DE OTRAS JORNADAS EN EFECTIVO
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 542, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 542

         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', c.valor,
                                 c.valor / NVL (a.tasa_cambio_ma, 1)))
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a,
                     wms_pago_documentos c,
                     wms_documentos b,
                     doc_abono_documentos d
             WHERE       a.tipo_documento = 'R'
                     AND A.DOCUMENTO = C.DOCUMENTO
                     AND C.TIPO_PAGO = '4'
                     AND a.jornada IN (p_jornada)
                     AND a.documento = d.recibo
                     AND d.documento = b.documento
                     AND b.jornada NOT IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND POS_F_ES_RECIBO_MARCHAMO (A.DOCUMENTO) = 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;



         -- RECIBOS DE PAGO DE OTRAS JORNADAS EN TARJETA DE CREDITO
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 543, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 543



         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', c.valor,
                                 c.valor / NVL (a.tasa_cambio_ma, 1)))
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a,
                     wms_pago_documentos c,
                     WMS_documentos b,
                     doc_abono_documentos d
             WHERE       a.tipo_documento = 'R'
                     AND A.DOCUMENTO = C.DOCUMENTO
                     AND C.TIPO_PAGO = '3'
                     AND a.jornada IN (p_jornada)
                     AND a.documento = d.recibo
                     AND d.documento = b.documento
                     AND b.jornada NOT IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- RECIBOS DE PAGO DE OTRAS JORNADAS EN EFECTIVO
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 590, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 542

         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', c.valor,
                                 c.valor / NVL (a.tasa_cambio_ma, 1)))
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a,
                     wms_pago_documentos c,
                     wms_documentos b,
                     doc_abono_documentos d
             WHERE       a.tipo_documento = 'R'
                     AND A.DOCUMENTO = C.DOCUMENTO
                     AND C.TIPO_PAGO = '4'
                     AND a.jornada IN (p_jornada)
                     AND a.documento = d.recibo
                     AND d.documento = b.documento
                     AND b.jornada NOT IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;



         -- RECIBOS DE PAGO DE OTRAS JORNADAS EN TARJETA DE CREDITO
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 591, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 543


         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', c.valor,
                                 c.valor / NVL (a.tasa_cambio_ma, 1)))
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a,
                     wms_pago_documentos c,
                     wms_documentos b,
                     doc_abono_documentos d
             WHERE       a.tipo_documento = 'R'
                     AND A.DOCUMENTO = C.DOCUMENTO
                     AND C.TIPO_PAGO = '14'
                     AND a.jornada IN (p_jornada)
                     AND a.documento = d.recibo
                     AND d.documento = b.documento
                     AND b.jornada NOT IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;



         -- ABONOS CON GIFT CARD
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 609, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 609


         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', c.valor,
                                 c.valor / NVL (a.tasa_cambio_ma, 1)))
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a,
                     wms_pago_documentos c,
                     wms_documentos b,
                     doc_abono_documentos d
             WHERE       a.tipo_documento = 'R'
                     AND A.DOCUMENTO = C.DOCUMENTO
                     AND C.TIPO_PAGO = '4'
                     AND a.jornada IN (p_jornada)
                     AND a.documento = d.recibo
                     AND d.documento = b.documento
                     AND b.jornada NOT IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- RECIBOS DE PAGO DE OTRAS JORNADAS EN CHEQUE
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 544, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 544



         IF v_Rejo = 'NO'
         THEN
            -- FACTURAS DE CREDITO
            SELECT   SUM(DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', NVL (total, 0),
                                 NVL (total, 0) / NVL (tasa_cambio_ma, 1)))
                        total
              INTO   V_RESULTADO
              FROM   WMS_DOCUMENTOS a, wms_socios b
             WHERE       jornada = p_jornada
                     AND tipo_documento = 'F'
                     AND NVL (situacion, 1) <> 11
                     AND A.SOCIO = B.SOCIO
                     AND NVL (fecha_vencimiento, fecha_emision) >
                           fecha_emision;

            -- DEVOLUCIONES ACREDITAR
            SELECT   SUM(DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', a.total,
                                 a.total / NVL (a.tasa_cambio_ma, 1))
                         * -1)
              INTO   V_RESULTADO2
              FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b
             WHERE       a.tipo_documento = 'D'
                     AND a.socio = b.socio(+)
                     AND a.jornada IN (p_jornada)
                     AND SUBTIPO_DOCUMENTO = 'C'
                     AND NVL (a.situacion, 1) <> 11;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
            v_resultado2 := 0;
         END IF;

         -- SALDO EN CREDITO    FACTURAS DE CREDITO - DEVOLUCIONES TIPO ACREDITAR
         INSERT INTO WMS_HISTORICO_JORNADAS (
                                                jornada,
                                                rubro,
                                                monto
                    )
           VALUES   (
                        p_jornada,
                        545,
                        NVL (v_resultado, 0) + NVL (v_Resultado2, 0)
                    );             -- SE CREA EL ENCABEZADO DE LA VARIABLE 545



         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', c.valor,
                                 c.valor / NVL (a.tasa_cambio_ma, 1)))
              INTO   V_RESULTADO
              FROM   WMS_DOCUMENTOS a,
                     WMS_SOCIOS b,
                     wms_pago_documentos c,
                     doc_Abono_documentos d,
                     wms_documentos e,
                     cg_ref_codes f
             WHERE       a.tipo_documento = 'R'
                     AND A.DOCUMENTO = C.DOCUMENTO
                     AND a.socio = b.socio(+)
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND d.recibo = a.documento
                     AND d.documento = e.documento
                     AND f.rv_domain = 'TIPO PAGO'
                     AND f.rv_low_value = c.tipo_pago
                     AND NVL (e.fecha_vencimiento, e.fecha_emision) =
                           NVL (e.fecha_emision, SYSDATE);
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- VENTAS CONTADO.... TODO LAS VENTAS A DOCUMENTOS QUE NO SON DE CREDITO
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 546, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 546



         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', a.total,
                                 a.total / NVL (a.tasa_cambio_ma, 1)))
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b, cg_Ref_codes f
             WHERE       a.tipo_documento = 'D'
                     AND a.socio = b.socio(+)
                     AND a.jornada IN (p_jornada)
                     AND SUBTIPO_DOCUMENTO NOT IN ('C')
                     AND f.rv_domain = 'TIPO DEVOLUCION'
                     AND f.rv_low_value = a.SUBTIPO_DOCUMENTO
                     AND NVL (a.situacion, 1) <> 11;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- VENTAS CONTADO.... TODO LAS VENTAS A DOCUMENTOS QUE NO SON DE CREDITO
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 547, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 547



         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', c.valor,
                                 c.valor / NVL (a.tasa_cambio_ma, 1)))
              INTO   V_RESULTADO
              FROM   WMS_DOCUMENTOS a,
                     WMS_SOCIOS b,
                     wms_pago_documentos c,
                     doc_Abono_documentos d,
                     wms_documentos e,
                     cg_ref_codes f
             WHERE       a.tipo_documento = 'R'
                     AND A.DOCUMENTO = C.DOCUMENTO
                     AND a.socio = b.socio(+)
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND d.recibo = a.documento
                     AND d.documento = e.documento
                     AND f.rv_domain = 'TIPO PAGO'
                     AND f.rv_low_value = c.tipo_pago
                     AND NVL (e.fecha_vencimiento, e.fecha_emision) >
                           NVL (e.fecha_emision, SYSDATE);
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- VENTAS CONTADO.... TODO LAS VENTAS A DOCUMENTOS QUE NO SON DE CREDITO
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 548, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 548



         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', c.valor,
                                 c.valor / NVL (a.tasa_cambio_ma, 1)))
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a,
                     WMS_SOCIOS b,
                     wms_pago_documentos c,
                     cg_ref_codes d
             WHERE       a.tipo_documento = 'R'
                     AND A.DOCUMENTO = C.DOCUMENTO
                     AND a.socio = b.socio(+)
                     AND a.jornada IN (p_jornada)
                     AND d.rv_domain = 'TIPO PAGO'
                     AND d.rv_low_value = c.tipo_pago
                     AND NVL (a.situacion, 1) <> 11;


            SELECT   SUM(DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', a.total,
                                 a.total / NVL (a.tasa_cambio_ma, 1))
                         * -1)
              INTO   v_resultado2
              FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b, cg_ref_codes d
             WHERE       a.tipo_documento = 'D'
                     AND a.socio = b.socio(+)
                     AND a.jornada IN (p_jornada)
                     AND SUBTIPO_DOCUMENTO NOT IN ('C')
                     AND d.rv_domain = 'TIPO DEVOLUCION'
                     AND d.rv_low_value = SUBTIPO_DOCUMENTO
                     AND NVL (a.situacion, 1) <> 11;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
            v_resultado2 := 0;
         END IF;


         -- TOTAL RECIBOS MENOS DEVOLUCIONES EXCEPTO LAS DE ACREDITAR
         INSERT INTO WMS_HISTORICO_JORNADAS (
                                                jornada,
                                                rubro,
                                                monto
                    )
           VALUES   (
                        p_jornada,
                        549,
                        NVL (v_resultado, 0) + NVL (v_Resultado2, 0)
                    );             -- SE CREA EL ENCABEZADO DE LA VARIABLE 549



         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(DECODE (
                            Cg_F_Parameter_Value ('MOJO'),
                            'MB',
                            ROUND( (  c.precio_unitario
                                    - NVL (ROUND (c.descuento, 2), 0)
                                    + NVL (c.impuesto, 0))
                                  * c.cantidad),
                            (ROUND (
                                (  c.precio_unitario
                                 - NVL (ROUND (c.descuento, 2), 0)
                                 + NVL (c.impuesto, 0))
                                * c.cantidad,
                                2
                             )
                             / NVL (a.tasa_cambio_ma, 1))
                         ))
              INTO   V_RESULTADO
              FROM   WMS_DOCUMENTOS a, wms_skus_x_documento c
             WHERE       a.tipo_documento = 'F'
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND a.documento = c.documento
                     AND c.usuario_anulo IS NULL
                     AND A.SOCIO_ES_EXCENTO IS NULL;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;


         -- FACTURAS A CLIENTES EXCENTOS
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 550, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 550

         -- certificados de regalo emitidos

         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(DECODE (
                            tipo_documento,
                            'F',
                            ROUND (
                               NVL (
                                  SUM( (  NVL (precio_unitario, 0)
                                        - NVL (descuento, 0)
                                        + NVL (a.impuesto, 0))
                                      * cantidad),
                                  0
                               ),
                               2
                            ),
                            ROUND (
                               NVL (
                                  SUM( (  NVL (precio_unitario, 0)
                                        - NVL (descuento, 0)
                                        + NVL (a.impuesto, 0))
                                      * cantidad),
                                  0
                               ),
                               2
                            )
                            * -1
                         ))
              INTO   v_resultado
              FROM   wms_skus_x_documento a, wms_documentos b
             WHERE       a.documento = b.documento
                     AND a.usuario_anulo IS NULL
                     AND b.tipo_documento IN ('F', 'D')
                     AND NVL (b.situacion, 1) <> 11
                     AND a.sku = cg_f_parameter_value ('SPIC')
                     AND WMS_F_FACTANUL (B.DOCUMENTO) <> 0
                     AND b.jornada = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;


         -- GIFT CARD VENTA - certificados de regalo emitidos
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 561, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 560

         ---

         -- retiros de dinero colones

         IF v_Rejo = 'NO'
         THEN
            --SELECT  ROUND(sum (DEPOSITO * NVL(TASA_CAMBIO,1)),2)
            SELECT   ROUND (SUM (DEPOSITO * NVL (TASA_CAMBIO, 1)), 2)
              INTO   v_resultado
              FROM   wms_retiros
             WHERE       jornada = p_jornada
                     AND ANULADO_EL IS NULL
                     AND moneda = 1;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;


         -- retiros de dinero colones (depositos)
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 562, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 562


         -- retiros de dinero dolares

         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (DEPOSITO), 2)
              INTO   v_resultado
              FROM   wms_retiros
             --WHERE  jornada = p_jornada AND ANULADO_EL is null and moneda = 2; --ACC 01122020
             WHERE       jornada = p_jornada
                     AND ANULADO_EL IS NULL
                     AND moneda IN (2, 8);                      --ACC 01122020
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;


         -- retiros de dinero dolares (depositos)
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 617, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 617



         -- FONABE
         IF v_Rejo = 'NO'
         THEN
            SELECT   NVL (SUM (EFECTIVO_ENTREGADO), 0)
              INTO   v_resultado
              FROM   WMS_CASHBACK
             WHERE   JORNADA = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         SELECT   NVL (SUM (EFECTIVO_ENTREGADO), 0)
           INTO   v_resultado
           FROM   WMS_CASHBACK
          WHERE   JORNADA = p_jornada AND ANULADO_EL IS NULL;

         -- FONABE (Efectivo entregado)
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 592, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 592

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 593, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 592

         --CAJA CHICA
         IF v_Rejo = 'NO'
         THEN
            SELECT   NVL (SUM (MONTO), 0)
              INTO   v_resultado
              FROM   WMS_CAJACHICA
             WHERE   JORNADA = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         SELECT   NVL (SUM (MONTO), 0)
           INTO   v_resultado
           FROM   WMS_CAJACHICA
          WHERE   JORNADA = p_jornada AND ANULADO_EL IS NULL;

         --CAJA CHICA
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 594, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 592

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 595, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 592

         ---

         -- BN SERVICIOS

         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (MONTO), 2)
              INTO   v_resultado
              FROM   WMS_V_BNSERVICIOS
             WHERE   jornada = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;


         -- BN SERVICIOS
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 607, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 607

         ---


         -- TARJETAS BAC COLONES

         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (MONTO), 2)
              INTO   v_resultado
              FROM   WMS_V_TARJBAC
             WHERE   jornada = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- TARJETAS BAC
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 628, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 628

         ---

         -- TARJETAS BAC DOLARES

         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (MONTO), 2)
              INTO   v_resultado
              FROM   WMS_V_TARJBAC_DOLAR
             WHERE   jornada = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- TARJETAS BAC
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 629, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 629

         ---

         -- TARJETAS BAC VUELTOS

         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (bd.cvuelto), 2)
              INTO   v_resultado
              FROM   WMS_V_TARJBAC_DOLAR bd
             WHERE   bd.jornada = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- TARJETAS BAC
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 918, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 918

         ---------------------------------------------DEPOSITO INICIO


         --DEPOSITOS A CUENTA BANCARIA DEL BAC COLONES

         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (MONTO), 2)
              INTO   v_resultado
              FROM   wms_v_depositobac_colon
             WHERE   jornada = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- TARJETAS BAC
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 630, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 628


         -- DEPOSTIOS BAC DOLARES

         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (MONTO), 2)
              INTO   v_resultado
              FROM   wms_v_depositosbac
             WHERE   jornada = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- TARJETAS BAC
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 631, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 629


         -- DEPOSITOS BAC VUELTOS

         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (bd.cvuelto), 2)
              INTO   v_resultado
              FROM   wms_v_depositosbac bd
             WHERE   bd.jornada = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- TARJETAS BAC
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 919, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 918


         ----------------------------------------------DEPOSITO FIN


         ---------------------RETIROS INICIO BAC



         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (MONTO), 2)
              INTO   v_resultado
              FROM   wms_v_retirosbac_colon
             WHERE   jornada = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- retiros BAC
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 632, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 628



         ---------------RETIROS FIN  BAC

         -- RECARGAS

         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (MONTO), 2)
              INTO   v_resultado
              FROM   WMS_V_RECARGAS2
             WHERE   jornada = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;


         -- RECARGAS
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 608, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 608

         ---

         -- RECARGAS NIC

         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (MONTO), 2)
              INTO   v_resultado
              FROM   WMS_V_RECARGSNIC
             WHERE   jornada = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;


         -- RECARGAS  NIC
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 614, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 614

         ---

         ---PAGOS INSTACREDIT

         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (MONTO), 2)
              INTO   v_resultado
              FROM   wms_v_pagoscredito
             WHERE   jornada = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 612, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 612

         ---

         -- PUNTOS

         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (MONTO), 2)
              INTO   v_resultado
              FROM   POS_V_PUNTOSCC
             WHERE   jornada = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 624, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 624

         ---

         -- FICHAS EXTRAVIADAS

         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (MONTO), 2)
              INTO   v_resultado
              FROM   POS_V_FICHAS_EXTRAVIADASCC
             WHERE   jornada = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 625, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 625

         ---

         -- FICHAS EXTRAVIADAS ANULADAS

         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (MONTO), 2)
              INTO   v_resultado
              FROM   POS_V_ANULFICHAS_EXTRAVIADASCC
             WHERE   jornada = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 626, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 626

         ---

         -- VALES POR RIFA

         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (MONTO), 2)
              INTO   V_RESULTADO
              FROM   DOC_VALES
             WHERE       TIPO = 'R'
                     AND JORNADA = p_JORNADA
                     AND BODEGA = CG_F_PARAMETER_VALUE ('BREE');
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 906, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 906

         ---

         -- FONDO DISPONIBLE WESTERNUNION

         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (wu_f_fondodispwu (p_jornada), 2)
              INTO   v_resultado
              FROM   DUAL;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 917, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 917

         ---

         -- MARCHAMOS --

         -- Colones
         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (MONTO), 2)
              INTO   V_RESULTADO
              FROM   POS_V_MARCHAMOS_EFECTIVOCC
             WHERE   TIPO_MONEDA = 1 AND JORNADA = p_JORNADA;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 909, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 909

         -- Credi-e
         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (MONTO), 2)
              INTO   V_RESULTADO
              FROM   POS_V_MARCHAMOS_CREDIECC
             WHERE   JORNADA = p_JORNADA;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 911, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 911

         -- FIN MARCHAMOS --

         -- WESTERN UNION

         --Pagos WU
         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (MONTO), 2)
              INTO   v_resultado
              FROM   wms_v_WesternUnion
             WHERE   TIPO = 'P' AND jornada = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 913, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 913

         --Envios WU Col
         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (MONTO), 2)
              INTO   v_resultado
              FROM   wms_v_WesternUnion
             WHERE   TIPO = 'EC' AND jornada = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 914, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 914

         --Envios WU Dol
         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (MONTO), 2)
              INTO   v_resultado
              FROM   wms_v_WesternUnion
             WHERE   TIPO = 'ED' AND jornada = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 915, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 915

         --Vuelto WU Col
         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (MONTO), 2)
              INTO   v_resultado
              FROM   wms_v_WesternUnion
             WHERE   TIPO = 'VC' AND jornada = p_jornada;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 916, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 916

         --- FIN WESTERN UNION

         -- total a depositar

         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM (total)
              INTO   v_resultado
              FROM   (SELECT   a.serie || ' ' || a.no_documento,
                               b.valor total
                        FROM   wms_documentos a, wms_pago_documentos b
                       WHERE       a.documento = b.documento
                               AND b.tipo_pago = 3
                               AND a.jornada = 21000004
                      UNION ALL
                      SELECT   a.serie || ' ' || a.no_documento no_documento,
                               (DECODE (Cg_F_Parameter_Value ('MOJO'),
                                        'MB', a.total,
                                        a.total / NVL (a.tasa_cambio_ma, 1))
                                * -1)
                                  total
                        FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b
                       WHERE       a.tipo_documento = 'D'
                               AND a.socio = b.socio(+)
                               AND a.jornada IN (21000004)
                               AND SUBTIPO_DOCUMENTO = 'D'
                               AND NVL (a.situacion, 1) <> 11);
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;


         -- deposito
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 564, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 560

         ---

         -- total a depositar dolares

         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM (total)
              INTO   v_resultado
              FROM   (SELECT   a.serie || ' ' || a.no_documento,
                               b.valor total
                        FROM   wms_documentos a, wms_pago_documentos b
                       WHERE       a.documento = b.documento
                               AND b.tipo_pago = 3
                               AND a.jornada = 21000004
                      UNION ALL
                      SELECT   a.serie || ' ' || a.no_documento no_documento,
                               (DECODE (Cg_F_Parameter_Value ('MOJO'),
                                        'MB', a.total,
                                        a.total / NVL (a.tasa_cambio_ma, 1))
                                * -1)
                                  total
                        FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b
                       WHERE       a.tipo_documento = 'D'
                               AND a.socio = b.socio(+)
                               AND a.jornada IN (21000004)
                               AND SUBTIPO_DOCUMENTO = 'D'
                               AND NVL (a.situacion, 1) <> 11);
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;


         -- deposito
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 618, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 560

         ---

         -- apartados realizados

         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM (sr3_f_total_documento (documento))
              INTO   v_resultado
              FROM   wms_documentos a
             WHERE       a.tipo_documento = 'F'
                     AND a.interfasado_el IS NULL
                     AND NVL (apartado, 'N') = 'S'
                     AND a.jornada = p_jornada
                     AND NVL (a.fecha_emision, SYSDATE) <
                           NVL (a.fecha_vencimiento,
                                NVL (a.fecha_emision, SYSDATE))
                     AND WMS_F_FACTANUL (a.documento) <> 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;


         -- apartados
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 563, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 560



         ---
         -- DEPOSITO -- FALTANTE

         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM (TOTAL)
              INTO   V_RESULTADO
              FROM   (SELECT   'TOTAL A DEPOSITAR' no_documento,
                               b.valor total
                        FROM   wms_documentos a, wms_pago_documentos b
                       WHERE       a.documento = b.documento
                               AND b.tipo_pago IN (3, 36)               -- = 3
                               AND a.jornada = p_jornada
                      UNION ALL
                      SELECT   a.serie || ' ' || a.no_documento no_documento,
                               (DECODE (Cg_F_Parameter_Value ('MOJO'),
                                        'MB', a.total,
                                        a.total / NVL (a.tasa_cambio_ma, 1))
                                * -1)
                                  total
                        FROM   WMS_DOCUMENTOS a, WMS_SOCIOS b
                       WHERE       a.tipo_documento = 'D'
                               AND a.socio = b.socio(+)
                               AND a.jornada IN (p_jornada)
                               AND SUBTIPO_DOCUMENTO = 'D'
                               AND NVL (a.situacion, 1) <> 11
                      UNION ALL
                      SELECT   'TOTAL RETIROS' no_documento,
                               DEPOSITO * -1 total
                        FROM   wms_retiros
                       WHERE   jornada = p_jornada AND anulado_el IS NULL);
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- sobrante/faltante
         SELECT   COUNT (1)
           INTO   V_EXISTE
           FROM   WMS_HISTORICO_JORNADAS
          WHERE   JORNADA = P_JORNADA AND RUBRO = 565;

         IF V_EXISTE = 0
         THEN
            INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
              VALUES   (p_jornada, 565, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 565
         ELSIF V_EXISTE = 1
         THEN                                     --SE ACTUALIZA EL ENCABEZADO
            UPDATE   WMS_HISTORICO_JORNADAS
               SET   MONTO = NVL (V_RESULTADO, 0)
             WHERE   JORNADA = P_JORNADA AND RUBRO = 565;
         END IF;

         -- sobrante/faltante Dolar
         SELECT   COUNT (1)
           INTO   V_EXISTE
           FROM   WMS_HISTORICO_JORNADAS
          WHERE   JORNADA = P_JORNADA AND RUBRO = 619;

         IF V_EXISTE = 0
         THEN
            INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
              VALUES   (p_jornada, 619, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 619
         ELSIF V_EXISTE = 1
         THEN                                     --SE ACTUALIZA EL ENCABEZADO
            UPDATE   WMS_HISTORICO_JORNADAS
               SET   MONTO = NVL (V_RESULTADO, 0)
             WHERE   JORNADA = P_JORNADA AND RUBRO = 619;
         END IF;

         -- subtotal exento

         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM (ROUND (c.precio_unitario * c.cantidad, 8))
              INTO   V_RESULTADO
              FROM   WMS_DOCUMENTOS a,
                     wms_socios b,
                     wms_skus_x_documento c,
                     wms_skus d
             WHERE       a.tipo_documento IN ('F')
                     AND a.jornada IN (p_jornada)
                     AND a.documento = c.documento
                     AND c.usuario_anulo IS NULL
                     AND NVL (a.situacion, 1) <> 11
                     AND a.socio = b.socio
                     AND a.jornada IN (p_jornada)
                     AND c.sku = d.sku
                     --and    c.sku <> cg_f_parameter_value('SPIC')
                     AND c.sku NOT IN
                              (cg_f_parameter_value ('SPIC'),
                               cg_f_parameter_value ('SFE'),
                               WMS_F_BUSCAR_SKU (
                                  CG_F_PARAMETER_VALUE ('SADO')
                               ),
                               CG_F_PARAMETER_VALUE ('STR'))
                     --and    nvl(d.impuesto,1) <> 0 -- VENTAS EXCENTAS SON A PRODUCTOS QUE NO PAGAN IMPUESTOS
                     --AND    A.SOCIO_ES_EXCENTO IS NULL
                     AND ROUND (NVL (c.impuesto, 0), 2) = 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;



         -- total exento sin desc ,sin imp
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 568, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 560



         ---
         -- subtotal gravado

         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM (ROUND (c.precio_unitario * c.cantidad, 8))
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a,
                     wms_socios b,
                     wms_skus_x_documento c,
                     wms_skus d
             WHERE       a.tipo_documento IN ('F')
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND a.socio = b.socio
                     --AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                     AND a.documento = c.documento
                     AND c.usuario_anulo IS NULL
                     AND c.sku = d.sku
                     AND ROUND (NVL (c.impuesto, 0), 2) > 0
                     AND WMS_F_FACTANUL (a.documento) <> 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;



         -- total gravado sin desc ,sin imp
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 569, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 560

         ---descuento exento
         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM (ROUND (c.descuento * c.cantidad, 8))
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a,
                     wms_socios b,
                     wms_skus_x_documento c,
                     wms_skus d
             WHERE       a.tipo_documento IN ('F')
                     AND a.jornada IN (p_jornada)
                     AND a.documento = c.documento
                     AND c.usuario_anulo IS NULL
                     AND NVL (a.situacion, 1) <> 11
                     AND a.socio = b.socio
                     AND a.jornada IN (p_jornada)
                     AND c.sku = d.sku
                     --and    c.sku <> cg_f_parameter_value('SPIC')
                     AND c.sku NOT IN
                              (cg_f_parameter_value ('SPIC'),
                               cg_f_parameter_value ('SFE'),
                               WMS_F_BUSCAR_SKU (
                                  CG_F_PARAMETER_VALUE ('SADO')
                               ))
                     --and    nvl(d.impuesto,1) <> 0 -- VENTAS EXCENTAS SON A PRODUCTOS QUE NO PAGAN IMPUESTOS
                     --AND    A.SOCIO_ES_EXCENTO IS NULL
                     AND ROUND (NVL (c.impuesto, 0), 2) = 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;



         -- descuento exento
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 570, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 560

         ---
         ---descuento gravado
         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM (ROUND (c.descuento * c.cantidad, 8))
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a,
                     wms_socios b,
                     wms_skus_x_documento c,
                     wms_skus d
             WHERE       a.tipo_documento IN ('F')
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND a.socio = b.socio
                     --AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                     AND a.documento = c.documento
                     AND c.usuario_anulo IS NULL
                     AND c.sku = d.sku
                     AND ROUND (NVL (c.impuesto, 0), 2) > 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;



         -- descuento gravado
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 571, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 560

         ---
         ---impuesto
         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM (ROUND (c.impuesto * c.cantidad, 8))
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a,
                     wms_socios b,
                     wms_skus_x_documento c,
                     wms_skus d
             WHERE       a.tipo_documento IN ('F')
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND a.socio = b.socio
                     --AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                     AND a.documento = c.documento
                     AND c.usuario_anulo IS NULL
                     AND c.sku = d.sku
                     AND ROUND (NVL (c.impuesto, 0), 2) > 0
                     AND WMS_F_FACTANUL (a.documento) <> 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;



         -- impuesto
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 572, NVL (v_resultado, 0));

         ---  devoluciones inicio

         -- subtotal exento

         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM (ROUND (c.precio_unitario * c.cantidad, 8)) * -1
              INTO   V_RESULTADO
              FROM   WMS_DOCUMENTOS a,
                     wms_socios b,
                     wms_skus_x_documento c,
                     wms_skus d
             WHERE       a.tipo_documento IN ('F')
                     AND a.jornada IN (p_jornada)
                     AND a.documento = c.documento
                     AND c.usuario_anulo IS NULL
                     AND NVL (a.situacion, 1) <> 11
                     AND a.socio = b.socio
                     AND c.sku = d.sku
                     AND (C.SKU <> cg_f_parameter_value ('SPIC')
                          AND C.SKU <> cg_f_parameter_value ('SFE'))
                     --and    nvl(d.impuesto,1) <> 0 -- VENTAS EXCENTAS SON A PRODUCTOS QUE NO PAGAN IMPUESTOS
                     --AND    A.SOCIO_ES_EXCENTO IS NULL
                     AND ROUND (NVL (c.impuesto, 0), 2) = 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;



         -- total exento sin desc ,sin imp
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 580, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 560



         ---
         -- subtotal gravado

         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM (ROUND (c.precio_unitario * c.cantidad, 8)) * -1
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a,
                     wms_socios b,
                     wms_skus_x_documento c,
                     wms_skus d
             WHERE       a.tipo_documento IN ('F')
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND a.socio = b.socio
                     --AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                     AND a.documento = c.documento
                     AND c.usuario_anulo IS NULL
                     AND c.sku = d.sku
                     AND ROUND (NVL (c.impuesto, 0), 2) > 0
                     AND WMS_F_FACTANUL (a.documento) <> 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;



         -- total gravado sin desc ,sin imp
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 581, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 560

         ---descuento exento
         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM (ROUND (c.descuento * c.cantidad, 8)) * -1
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a,
                     wms_socios b,
                     wms_skus_x_documento c,
                     wms_skus d
             WHERE       a.tipo_documento IN ('F')
                     AND a.jornada IN (p_jornada)
                     AND a.documento = c.documento
                     AND c.usuario_anulo IS NULL
                     AND NVL (a.situacion, 1) <> 11
                     AND a.socio = b.socio
                     AND a.jornada IN (p_jornada)
                     AND c.sku = d.sku
                     --and    nvl(d.impuesto,1) <> 0 -- VENTAS EXCENTAS SON A PRODUCTOS QUE NO PAGAN IMPUESTOS
                     --AND    A.SOCIO_ES_EXCENTO IS NULL
                     AND ROUND (NVL (c.impuesto, 0), 2) = 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;



         -- descuento exento
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 582, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 560

         ---
         ---descuento gravado
         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM (ROUND (c.descuento * c.cantidad, 8)) * -1
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a,
                     wms_socios b,
                     wms_skus_x_documento c,
                     wms_skus d
             WHERE       a.tipo_documento IN ('F')
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND a.socio = b.socio
                     --AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                     AND a.documento = c.documento
                     AND c.usuario_anulo IS NULL
                     AND c.sku = d.sku
                     AND ROUND (NVL (c.impuesto, 0), 2) > 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;



         -- descuento gravado
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 583, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 560

         ---
         ---impuesto
         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM (ROUND (c.impuesto * c.cantidad, 8)) * -1
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a,
                     wms_socios b,
                     wms_skus_x_documento c,
                     wms_skus d
             WHERE       a.tipo_documento IN ('F')
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND a.socio = b.socio
                     --AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                     AND a.documento = c.documento
                     AND c.usuario_anulo IS NULL
                     AND c.sku = d.sku
                     AND ROUND (NVL (c.impuesto, 0), 2) > 0
                     AND WMS_F_FACTANUL (a.documento) <> 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;



         -- impuesto
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 584, NVL (v_resultado, 0));

         ---

         -- 912
         -- Devolucin de Gift.
         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM (ROUND (c.precio_unitario * c.cantidad * -1, 8))
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a,
                     wms_socios b,
                     wms_skus_x_documento c,
                     wms_skus d
             WHERE       a.tipo_documento IN ('D')
                     AND a.jornada IN (p_jornada)
                     AND a.documento = c.documento
                     AND c.usuario_anulo IS NULL
                     AND NVL (a.situacion, 1) <> 11
                     AND a.socio = b.socio
                     AND a.jornada IN (p_jornada)
                     AND c.sku = d.sku
                     AND C.SKU = cg_f_parameter_value ('SPIC')
                     --and    nvl(d.impuesto,1) <> 0 -- VENTAS EXCENTAS SON A PRODUCTOS QUE NO PAGAN IMPUESTOS
                     --AND    A.SOCIO_ES_EXCENTO IS NULL
                     AND ROUND (NVL (c.impuesto, 0), 2) = 0;
         ELSE
            v_resultado := 0;
         END IF;

         -- Devolucin de Gift.
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 912, NVL (v_resultado, 0));

         -- 585

         ---facturas de credito sin impuesto sin descuento
         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (c.precio_unitario * c.cantidad), 8)
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a, wms_skus_x_documento c
             WHERE       a.tipo_documento IN ('F')
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND a.documento = c.documento
                     AND c.usuario_anulo IS NULL
                     AND NVL (a.fecha_vencimiento, a.fecha_emision) >
                           a.fecha_emision;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;



         -- credito
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 585, NVL (v_resultado, 0));

         ---
         --   586
         ---ventas credito descuentos
         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (c.descuento * c.cantidad), 8)
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a, wms_skus_x_documento c
             WHERE       a.tipo_documento IN ('F')
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND a.documento = c.documento
                     AND c.usuario_anulo IS NULL
                     AND NVL (a.fecha_vencimiento, a.fecha_emision) >
                           a.fecha_emision;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;



         -- descuento
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 586, NVL (v_resultado, 0));

         ---
         --587

         --- credito impuesto
         IF v_Rejo = 'NO'
         THEN
            SELECT   ROUND (SUM (c.impuesto * c.cantidad), 8)
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a, wms_skus_x_documento c
             WHERE       a.tipo_documento IN ('F')
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND a.documento = c.documento
                     AND c.usuario_anulo IS NULL
                     AND NVL (a.fecha_vencimiento, a.fecha_emision) >
                           a.fecha_emision;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;



         -- impuesto
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 587, NVL (v_resultado, 0));

         ---





         --- devoluciones fin


         /*select sum(round(decode(tipo_documento, 'F', ((c.precio_unitario - nvl(c.descuento,0) + nvl(c.impuesto,0)) * c.cantidad),((c.precio_unitario - nvl(c.descuento,0) + nvl(c.impuesto,0)) * c.cantidad * -1)),8)) total
         into v_resultado
         FROM   WMS_DOCUMENTOS a, wms_socios b, wms_skus_x_documento c
         WHERE  a.tipo_documento in ('F','D')
         AND    a.jornada IN ( p_jornada )
         AND    NVL (a.situacion, 1) <> 11
         and    a.socio = b.socio
         --AND    A.SOCIO_ES_EXCENTO IS NOT NULL
         AND    a.documento = c.documento
         and    c.usuario_anulo is null
         AND    round(nvl(c.impuesto,0),2) >= 0;*/

         SELECT   SUM (TOTAL)
           INTO   v_resultado
           FROM   (SELECT   SUM(ROUND (
                                   DECODE (
                                      tipo_documento,
                                      'F',
                                      ( (  c.precio_unitario
                                         - NVL (c.descuento, 0)
                                         + NVL (c.impuesto, 0))
                                       * c.cantidad),
                                      ( (  c.precio_unitario
                                         - NVL (c.descuento, 0)
                                         + NVL (c.impuesto, 0))
                                       * c.cantidad
                                       * -1)
                                   ),
                                   8
                                ))
                               total
                     FROM   wms_documentos a,
                            wms_socios b,
                            wms_skus_x_documento c
                    WHERE       a.tipo_documento IN ('F', 'D')
                            AND a.jornada IN (p_jornada)
                            AND NVL (a.situacion, 1) <> 11
                            AND a.socio = b.socio
                            --AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                            AND a.documento = c.documento
                            AND c.usuario_anulo IS NULL
                            AND ROUND (NVL (c.impuesto, 0), 2) >= 0
                   UNION ALL
                   SELECT   NVL (ROUND (SUM (MONTO), 2), 0) * -1 TOTAL
                     FROM   POS_V_FICHAS_EXTRAVIADASCC
                    WHERE   jornada = (p_jornada)
                   UNION ALL                        -- SE RESTAN LAS GIFTCARDS
                   SELECT   SUM(ROUND (
                                   DECODE (
                                      tipo_documento,
                                      'F',
                                      ( (  c.precio_unitario
                                         - NVL (c.descuento, 0)
                                         + NVL (c.impuesto, 0))
                                       * c.cantidad),
                                      ( (  c.precio_unitario
                                         - NVL (c.descuento, 0)
                                         + NVL (c.impuesto, 0))
                                       * c.cantidad
                                       * -1)
                                   ),
                                   8
                                ))
                            * -1
                               total
                     FROM   wms_documentos a,
                            wms_socios b,
                            wms_skus_x_documento c
                    WHERE   a.tipo_documento IN ('F', 'D')
                            AND (C.SKU = CG_F_PARAMETER_VALUE ('SPIC')
                                 OR C.SKU =
                                      WMS_F_BUSCAR_SKU (
                                         CG_F_PARAMETER_VALUE ('SADO')
                                      )
                                 OR C.SKU = CG_F_PARAMETER_VALUE ('STR'))
                            AND a.jornada IN (p_jornada)
                            AND NVL (a.situacion, 1) <> 11
                            AND a.socio = b.socio
                            --AND    A.SOCIO_ES_EXCENTO IS NOT NULL
                            AND a.documento = c.documento
                            AND c.usuario_anulo IS NULL
                            AND ROUND (NVL (c.impuesto, 0), 2) >= 0);

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 573, NVL (v_resultado, 0));

         ---
         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(ROUND (
                            (  c.precio_unitario
                             - NVL (ROUND (c.descuento, 2), 0)
                             + NVL (c.impuesto, 0))
                            * c.cantidad,
                            2
                         ))
                        total
              INTO   V_RESULTADO
              FROM   WMS_DOCUMENTOS a, wms_socios b, wms_skus_x_documento c
             WHERE       a.tipo_documento = 'F'
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND a.socio = b.socio
                     AND A.SOCIO_ES_EXCENTO IS NOT NULL
                     AND a.documento = c.documento
                     AND C.USUARIO_ANULO IS NULL
                     AND ROUND (NVL (c.impuesto, 0), 2) > 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- TOTAL LINEAS GRAVADAS
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 551, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 550



         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(ROUND (
                            (  c.precio_unitario
                             - NVL (ROUND (c.descuento, 2), 0)
                             + NVL (c.impuesto, 0))
                            * c.cantidad,
                            2
                         ))
                        total
              INTO   V_RESULTADO
              FROM   WMS_DOCUMENTOS a, wms_socios b, wms_skus_x_documento c
             WHERE       a.tipo_documento = 'F'
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND a.socio = b.socio
                     AND A.SOCIO_ES_EXCENTO IS NOT NULL
                     AND a.documento = c.documento
                     AND C.USUARIO_ANULO IS NULL
                     AND ROUND (NVL (c.impuesto, 0), 2) = 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- TOTAL LINEAS EXCENTAS  ( EL SKU NO PAGA IMPUESTO )
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 552, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 552



         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(DECODE (
                            Cg_F_Parameter_Value ('MOJO'),
                            'MB',
                            ROUND( (  c.precio_unitario
                                    - NVL (ROUND (c.descuento, 2), 0)
                                    + NVL (c.impuesto, 0))
                                  * c.cantidad),
                            (ROUND (
                                (  c.precio_unitario
                                 - NVL (ROUND (c.descuento, 2), 0)
                                 + NVL (c.impuesto, 0))
                                * c.cantidad,
                                2
                             )
                             / NVL (a.tasa_cambio_ma, 1))
                         ))
              INTO   V_RESULTADO
              FROM   WMS_DOCUMENTOS a, wms_skus_x_documento c
             WHERE       a.tipo_documento = 'D'
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND a.documento = c.documento
                     AND c.usuario_anulo IS NULL
                     AND A.SOCIO_ES_EXCENTO IS NULL;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;


         -- DEVOLUCIONES A FACTURAS A CLIENTES EXCENTOS
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 553, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 553



         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(ROUND (
                            (  c.precio_unitario
                             - NVL (ROUND (c.descuento, 2), 0)
                             + NVL (c.impuesto, 0))
                            * c.cantidad,
                            2
                         ))
                        total
              INTO   V_RESULTADO
              FROM   WMS_DOCUMENTOS a, wms_socios b, wms_skus_x_documento c
             WHERE       a.tipo_documento = 'D'
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND a.socio = b.socio
                     AND A.SOCIO_ES_EXCENTO IS NOT NULL
                     AND a.documento = c.documento
                     AND C.USUARIO_ANULO IS NULL
                     AND ROUND (NVL (c.impuesto, 0), 2) > 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- DEVOLUCIONES A  TOTAL LINEAS GRAVADAS
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 554, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 550



         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(ROUND (
                            (  c.precio_unitario
                             - NVL (ROUND (c.descuento, 2), 0)
                             + NVL (c.impuesto, 0))
                            * c.cantidad,
                            2
                         ))
                        total
              INTO   V_RESULTADO
              FROM   WMS_DOCUMENTOS a, wms_socios b, wms_skus_x_documento c
             WHERE       a.tipo_documento = 'D'
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND a.socio = b.socio
                     AND A.SOCIO_ES_EXCENTO IS NOT NULL
                     AND a.documento = c.documento
                     AND C.USUARIO_ANULO IS NULL
                     AND ROUND (NVL (c.impuesto, 0), 2) = 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- DEVOLUCIONES A TOTAL LINEAS EXCENTAS  ( EL SKU NO PAGA IMPUESTO )
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 555, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 550



         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(DECODE (
                            Cg_F_Parameter_Value ('MOJO'),
                            'MB',
                            ROUND( (  c.precio_unitario
                                    - NVL (ROUND (c.descuento, 2), 0)
                                    + NVL (c.impuesto, 0))
                                  * c.cantidad
                                  * DECODE (tipo_documento, 'F', 1, -1)),
                            (ROUND (
                                (  c.precio_unitario
                                 - NVL (ROUND (c.descuento, 2), 0)
                                 + NVL (c.impuesto, 0))
                                * c.cantidad,
                                2
                             )
                             / NVL (a.tasa_cambio_ma, 1)
                             * DECODE (tipo_documento, 'F', 1, -1))
                         ))
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a, wms_skus_x_documento c
             WHERE       a.tipo_documento IN ('F', 'D')
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND a.documento = c.documento
                     AND c.usuario_anulo IS NULL
                     AND A.SOCIO_ES_EXCENTO IS NULL;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;



         -- FACTURAS A CLIENTES EXCENTOS
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 556, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 556



         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(ROUND (
                            (  c.precio_unitario
                             - NVL (ROUND (c.descuento, 2), 0)
                             + NVL (c.impuesto, 0))
                            * c.cantidad,
                            2
                         )
                         * DECODE (tipo_documento, 'F', 1, -1))
                        total
              INTO   V_RESULTADO
              FROM   WMS_DOCUMENTOS a, wms_socios b, wms_skus_x_documento c
             WHERE       a.tipo_documento IN ('F', 'D')
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND a.socio = b.socio
                     AND A.SOCIO_ES_EXCENTO IS NOT NULL
                     AND a.documento = c.documento
                     AND C.USUARIO_ANULO IS NULL
                     AND ROUND (NVL (c.impuesto, 0), 2) > 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- TOTAL LINEAS GRAVADAS
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 557, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 550



         IF v_Rejo = 'NO'
         THEN
            SELECT   SUM(ROUND (
                            (  c.precio_unitario
                             - NVL (ROUND (c.descuento, 2), 0)
                             + NVL (c.impuesto, 0))
                            * c.cantidad,
                            2
                         )
                         * DECODE (tipo_documento, 'F', 1, -1))
                        total
              INTO   V_RESULTADO
              FROM   WMS_DOCUMENTOS a, wms_socios b, wms_skus_x_documento c
             WHERE       a.tipo_documento IN ('F', 'D')
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11
                     AND a.socio = b.socio
                     AND A.SOCIO_ES_EXCENTO IS NOT NULL
                     AND a.documento = c.documento
                     AND C.USUARIO_ANULO IS NULL
                     AND ROUND (NVL (c.impuesto, 0), 2) = 0;
         ELSE
            v_resultado := 0; -- SE DEJA EN CERO POR QUE EL PL WMS_P_REDONDEO_TOTALES_JORNADA LO ACTUALIZA Y SE HACE PARA REDUCIR OVERHEAD
         END IF;

         -- TOTAL LINEAS EXCENTAS  ( EL SKU NO PAGA IMPUESTO )
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 558, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 552



         -- FACTURACION BRUTA
         IF V_IMP = 1
         THEN                             --- SI LOS PRECIOS INCLUYEN IMPUESTO
            SELECT                                           /*+ FIRST_ROWS */
                  DECODE (
                        v_mojo,
                        'MB',
                        NVL (
                           SUM(ROUND (
                                    NVL (a.cantidad, 0)
                                  * NVL (a.precio_unitario, 0)
                                  * (1 + NVL (c.impuesto / 100, v_piva)),
                                  2
                               )),
                           0
                        ),
                        NVL (
                           SUM(ROUND (
                                  (  NVL (a.cantidad, 0)
                                   * NVL (a.precio_unitario, 0)
                                   * (1 + NVL (c.impuesto / 100, v_piva)))
                                  / NVL (b.tasa_cambio_ma, 1),
                                  2
                               )),
                           0
                        )
                     )
              INTO   v_resultado
              FROM   WMS_SKUS_X_DOCUMENTO a, WMS_DOCUMENTOS b, WMS_SKUS c
             WHERE       a.documento = b.documento
                     AND a.sku = c.sku
                     AND b.tipo_documento = 'F'
                     AND b.jornada = p_jornada;
         ELSE
            SELECT                                           /*+ FIRST_ROWS */
                  DECODE (
                        v_mojo,
                        'MB',
                        NVL (
                           SUM(ROUND (
                                  NVL (a.cantidad, 0)
                                  * (NVL (a.precio_unitario, 0)
                                     + NVL (a.impuesto, 0)),
                                  2
                               )),
                           0
                        ),
                        NVL (
                           SUM(ROUND (
                                  (NVL (a.cantidad, 0)
                                   * (NVL (a.precio_unitario, 0)
                                      + (NVL (a.impuesto, 0))))
                                  / NVL (b.tasa_cambio_ma, 1),
                                  2
                               )),
                           0
                        )
                     )
              INTO   v_resultado
              FROM   WMS_SKUS_X_DOCUMENTO a, WMS_DOCUMENTOS b, WMS_SKUS c
             WHERE       a.documento = b.documento
                     AND a.sku = c.sku
                     AND b.tipo_documento = 'F'
                     AND b.jornada = p_jornada;
         END IF;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 160, v_resultado);

         v_total := v_resultado;

         -- ANULACIONES
         SELECT                                              /*+ FIRST_ROWS */
               DECODE (
                     v_mojo,
                     'MB',
                     NVL (
                        SUM(ROUND (
                               NVL (a.cantidad, 0)
                               * (  NVL (a.precio_unitario, 0)
                                  + NVL (a.impuesto, 0)
                                  - NVL (a.descuento, 0)),
                               2
                            )),
                        0
                     ),
                     NVL (
                        SUM(ROUND (
                               (NVL (a.cantidad, 0)
                                * (  NVL (a.precio_unitario, 0)
                                   + NVL (a.impuesto, 0)
                                   - NVL (a.descuento, 0)))
                               / NVL (b.tasa_cambio_ma, 1),
                               2
                            )),
                        0
                     )
                  )
                     AS total
           INTO   v_resultado
           FROM   WMS_SKUS_X_DOCUMENTO a, WMS_DOCUMENTOS b, WMS_SKUS c
          WHERE       a.documento = b.documento
                  AND a.sku = c.sku
                  AND b.tipo_documento = 'F'
                  AND b.situacion = 11
                  AND b.jornada = p_jornada;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 161, v_resultado);

         v_total := v_total - v_resultado;

         -- FACTURACION BRUTA - ANULACIONES
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 273, v_total);

         -- DESCUENTOS DE ANULACIONES
         IF V_IMP = 1
         THEN                             --- SI LOS PRECIOS INCLUYEN IMPUESTO
            SELECT                                           /*+ FIRST_ROWS */
                  DECODE (
                        v_mojo,
                        'MB',
                        NVL (
                           SUM(ROUND (
                                    NVL (a.descuento, 0)
                                  * NVL (a.cantidad, 0)
                                  * (1 + NVL (c.impuesto / 100, v_piva)),
                                  2
                               )),
                           0
                        ),
                        NVL (
                           SUM(ROUND (
                                  (  NVL (a.descuento, 0)
                                   * NVL (a.cantidad, 0)
                                   * (1 + NVL (c.impuesto / 100, v_piva)))
                                  / NVL (b.tasa_cambio_ma, 1),
                                  2
                               )),
                           0
                        )
                     )
                        descuento
              INTO   v_resultado
              FROM   WMS_SKUS_X_DOCUMENTO a, WMS_DOCUMENTOS b, WMS_SKUS c
             WHERE       a.documento = b.documento
                     AND a.sku = c.sku
                     AND b.tipo_documento = 'F'
                     AND b.situacion = 11
                     AND b.jornada = p_jornada;
         ELSE
            SELECT                                           /*+ FIRST_ROWS */
                  DECODE (
                        v_mojo,
                        'MB',
                        NVL (
                           SUM(ROUND (
                                  NVL (a.descuento, 0)
                                  * (NVL (a.cantidad, 0)
                                     + (NVL (c.impuesto, 0))),
                                  2
                               )),
                           0
                        ),
                        NVL (
                           SUM(ROUND (
                                  (NVL (a.descuento, 0)
                                   * (NVL (a.cantidad, 0)
                                      + (NVL (c.impuesto, 0))))
                                  / NVL (b.tasa_cambio_ma, 1),
                                  2
                               )),
                           0
                        )
                     )
                        descuento
              INTO   v_resultado
              FROM   WMS_SKUS_X_DOCUMENTO a, WMS_DOCUMENTOS b, WMS_SKUS c
             WHERE       a.documento = b.documento
                     AND a.sku = c.sku
                     AND b.tipo_documento = 'F'
                     AND b.situacion = 11
                     AND b.jornada = p_jornada;
         END IF;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 193, v_resultado);

         v_total := v_total - v_resultado;


         -- DESCUENTOS CON IVA, DESCUENTOS SIN IVA, IVA TOTAL
         IF V_IMP = 1
         THEN                             --- SI LOS PRECIOS INCLUYEN IMPUESTO
            SELECT                                           /*+ FIRST_ROWS */
                  DECODE (
                        v_mojo,
                        'MB',
                        NVL (
                           SUM(ROUND (
                                    NVL (a.descuento, 0)
                                  * NVL (a.cantidad, 0)
                                  * (1 + NVL (c.impuesto / 100, v_piva)),
                                  2
                               )),
                           0
                        ),
                        NVL (
                           SUM(ROUND (
                                  (  NVL (a.descuento, 0)
                                   * NVL (a.cantidad, 0)
                                   * (1 + NVL (c.impuesto / 100, v_piva)))
                                  / NVL (b.tasa_cambio_ma, 1),
                                  2
                               )),
                           0
                        )
                     )
                        descuento,
                     DECODE (
                        v_mojo,
                        'MB',
                        NVL (
                           SUM(ROUND (
                                  NVL (a.descuento, 0) * NVL (a.cantidad, 0),
                                  2
                               )),
                           0
                        ),
                        NVL (
                           SUM(ROUND (
                                  (NVL (a.descuento, 0) * NVL (a.cantidad, 0))
                                  / NVL (b.tasa_cambio_ma, 1),
                                  2
                               )),
                           0
                        )
                     )
                        descuento_si,
                     DECODE (
                        v_mojo,
                        'MB',
                        NVL (
                           SUM(ROUND (
                                  NVL (a.impuesto, 0) * NVL (a.cantidad, 0),
                                  2
                               )),
                           0
                        ),
                        NVL (
                           SUM(ROUND (
                                  (NVL (a.impuesto, 0) * NVL (a.cantidad, 0))
                                  / NVL (b.tasa_cambio_ma, 1),
                                  2
                               )),
                           0
                        )
                     )
                        impuesto
              INTO   v_resultado, v_resultado2, v_resultado3
              FROM   WMS_SKUS_X_DOCUMENTO a, WMS_DOCUMENTOS b, WMS_SKUS c
             WHERE       a.documento = b.documento
                     AND a.sku = c.sku
                     AND b.tipo_documento = 'F'
                     AND NVL (b.situacion, 1) <> 11
                     AND b.jornada = p_jornada;
         ELSE
            SELECT                                           /*+ FIRST_ROWS */
                  DECODE (
                        v_mojo,
                        'MB',
                        NVL (
                           SUM(ROUND (
                                  NVL (a.descuento, 0)
                                  * (NVL (a.cantidad, 0)
                                     + (NVL (c.impuesto, 0))),
                                  2
                               )),
                           0
                        ),
                        NVL (
                           SUM(ROUND (
                                  (NVL (a.descuento, 0)
                                   * (NVL (a.cantidad, 0)
                                      * (NVL (c.impuesto, 0))))
                                  / NVL (b.tasa_cambio_ma, 1),
                                  2
                               )),
                           0
                        )
                     )
                        descuento,
                     DECODE (
                        v_mojo,
                        'MB',
                        NVL (
                           SUM(ROUND (
                                  NVL (a.descuento, 0) * NVL (a.cantidad, 0),
                                  2
                               )),
                           0
                        ),
                        NVL (
                           SUM(ROUND (
                                  (NVL (a.descuento, 0) * NVL (a.cantidad, 0))
                                  / NVL (b.tasa_cambio_ma, 1),
                                  2
                               )),
                           0
                        )
                     )
                        descuento_si,
                     DECODE (
                        v_mojo,
                        'MB',
                        NVL (
                           SUM(ROUND (
                                  NVL (a.impuesto, 0) * NVL (a.cantidad, 0),
                                  2
                               )),
                           0
                        ),
                        NVL (
                           SUM(ROUND (
                                  (NVL (a.impuesto, 0) * NVL (a.cantidad, 0))
                                  / NVL (b.tasa_cambio_ma, 1),
                                  2
                               )),
                           0
                        )
                     )
                        impuesto
              INTO   v_resultado, v_resultado2, v_resultado3
              FROM   WMS_SKUS_X_DOCUMENTO a, WMS_DOCUMENTOS b, WMS_SKUS c
             WHERE       a.documento = b.documento
                     AND a.sku = c.sku
                     AND b.tipo_documento = 'F'
                     AND NVL (b.situacion, 1) <> 11
                     AND b.jornada = p_jornada;
         END IF;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 162, v_resultado);

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 274, v_resultado2);

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 275, v_resultado3);

         v_total := v_total - v_resultado;

         -- PROPINA FACTURADA
         SELECT                                              /*+ FIRST ROWS */
               DECODE (
                     v_mojo,
                     'MB',
                     NVL (SUM (NVL (propina, 0)), 0),
                     NVL (SUM (NVL (propina, 0) / NVL (tasa_cambio_ma, 1)),
                          0)
                  )
           INTO   v_resultado
           FROM   WMS_DOCUMENTOS
          WHERE       jornada = p_jornada
                  AND imprimir_propina = 'S'
                  AND NVL (situacion, 1) <> 11
                  AND tipo_documento = 'F';

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 163, v_resultado);

         --164
         -- FACTURACION NETA
         v_total := v_total + v_resultado;

         SELECT                                              /*+ first_rows */
               ROUND (
                     DECODE (
                        Cg_F_Parameter_Value ('MOJO'),
                        'MB',
                        (NVL (
                            SUM( (  NVL (a.precio_unitario, 0)
                                  + NVL (a.impuesto, 0)
                                  - NVL (a.descuento, 0))
                                * NVL (a.cantidad, 0)),
                            0
                         ))
                        + DECODE (NVL (MAX (b.imprimir_propina), 'N'),
                                  'S', NVL (MAX (b.propina), 0),
                                  0),
                        ( (NVL (
                              SUM( (  NVL (a.precio_unitario, 0)
                                    + NVL (a.impuesto, 0)
                                    - NVL (a.descuento, 0))
                                  * NVL (a.cantidad, 0)),
                              0
                           ))
                         + DECODE (NVL (MAX (b.imprimir_propina), 'N'),
                                   'S', NVL (MAX (b.propina), 0),
                                   0))
                        / MAX (NVL (b.tasa_cambio_ma, 1))
                     ),
                     2
                  )
                     total
           INTO   v_resultado
           FROM   WMS_SKUS_X_DOCUMENTO a, WMS_DOCUMENTOS b
          WHERE       a.documento = b.documento
                  AND b.tipo_documento = 'F'
                  AND b.jornada IN (p_jornada)
                  AND NVL (b.situacion, 1) <> 11
                  AND a.sku <> cg_f_parameter_value ('SPIC')
                  AND WMS_F_FACTANUL (b.documento) = 0;

         v_total := v_total - v_resultado;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 164, v_total);

         -- FACTURAS CREDITO
         SELECT                                              /*+ FIRST_ROWS */
               DECODE (v_mojo,
                       'MB', NVL (SUM (TOTAL), 0),
                       NVL (SUM (TOTAL / NVL (tasa_cambio_ma, 1)), 0))
           INTO   v_resultado
           FROM   WMS_DOCUMENTOS
          WHERE       jornada = p_jornada
                  AND tipo_documento = 'F'
                  AND NVL (situacion, 1) <> 11
                  AND (NVL (saldo, 0) > 0
                       OR NVL (fecha_vencimiento, fecha_emision) >
                            fecha_emision);

         v_total := v_total - v_resultado;

         -- PAGOS A FACTURAS DE CREDITO CON RECIBOS DE LA MISMA JORNADA
         SELECT                                              /*+ FIRST_ROWS */
               DECODE (v_mojo,
                       'MB', NVL (SUM (a.valor), 0),
                       NVL (SUM (a.valor / NVL (b.tasa_cambio_ma, 1)), 0))
           INTO   v_recibos
           FROM   doc_Abono_documentos a, wms_documentos b, wms_documentos c
          WHERE       a.documento = b.documento
                  AND b.jornada = p_jornada
                  AND c.jornada = p_jornada
                  AND a.recibo = c.documento
                  AND b.tipo_documento = 'F'
                  AND NVL (b.situacion, 1) <> 11
                  AND NVL (c.situacion, 1) <> 11
                  AND (NVL (b.saldo, 0) > 0
                       OR NVL (b.fecha_vencimiento, b.fecha_emision) >
                            b.fecha_emision);


         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 165, v_resultado - v_recibos);



         -- PAGOS A FACTURAS DE CREDITO CON RECIBOS DE LA MISMA JORNADA sin apartados

         SELECT   SUM(NVL (
                         wms_f_pago_asociacion (a.documento, p_jornada),
                         DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', NVL (total, 0),
                                 NVL (total, 0) / NVL (tasa_cambio_ma, 1))
                      ))
           INTO   v_resultado
           FROM   WMS_DOCUMENTOS A
          WHERE       jornada = p_jornada
                  AND a.tipo_documento = 'F'
                  AND NVL (situacion, 1) <> 11
                  AND NVL (fecha_vencimiento, fecha_emision) > fecha_emision
                  AND NVL (a.apartado, 'N') = 'N'
                  AND WMS_F_FACTANUL (A.DOCUMENTO) <> 0;



         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 589, v_resultado);

         -- NOTAS CREDITO, NC SIN IVA E IVA NC
         SELECT                                              /*+ FIRST_ROWS */
               DECODE (v_mojo,
                       'MB', NVL (SUM (total), 0),
                       NVL (SUM (total / NVL (tasa_cambio_ma, 1)), 0))
           INTO   v_resultado
           FROM   WMS_DOCUMENTOS
          WHERE       jornada = p_jornada
                  AND tipo_documento = 'N'
                  AND NVL (situacion, 1) <> 11;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 166, v_resultado);

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 271, v_resultado / (1 + v_piva));

         INSERT INTO WMS_HISTORICO_JORNADAS (
                                                jornada,
                                                rubro,
                                                monto
                    )
           VALUES   (
                        p_jornada,
                        272,
                        v_resultado - (v_resultado / (1 + v_piva))
                    );

         -- FACTURACION TOTAL REAL
         v_total := v_total - v_resultado;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 286, v_total);

         -- RECIBOS DE PAGO DE OTRAS JORNADAS
         SELECT                                              /*+ FIRST_ROWS */
               DECODE (
                     v_mojo,
                     'MB',
                     NVL (SUM (a.valor), 0),
                     NVL (SUM (a.valor) / NVL (MAX (b.tasa_cambio_ma), 1), 0)
                  )
           INTO   v_resultado
           FROM   DOC_ABONO_DOCUMENTOS a, WMS_DOCUMENTOS b, WMS_DOCUMENTOS c
          WHERE       a.recibo = b.documento
                  AND a.documento = c.documento
                  AND b.jornada <> c.jornada
                  AND c.jornada = p_jornada
                  AND NVL (b.situacion, 1) <> 11;

         v_total := v_total - v_resultado;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 167, v_resultado);

         -- NOTAS DE DEBITO PAGADAS
         SELECT                                              /*+ FIRST_ROWS */
               DECODE (v_mojo,
                       'MB', NVL (SUM (b.valor), 0),
                       NVL (SUM (b.valor / NVL (c.tasa_cambio_ma, 1)), 0))
           INTO   v_resultado
           FROM   WMS_DOCUMENTOS a, DOC_ABONO_DOCUMENTOS b, WMS_DOCUMENTOS c
          WHERE       a.tipo_documento = 'R'
                  AND NVL (a.situacion, 1) <> 11
                  AND a.jornada = p_jornada
                  AND a.documento = b.recibo
                  AND b.documento = c.documento
                  AND c.tipo_documento = 'B'
                  AND NVL (c.situacion, 1) <> 11;

         v_total := v_total + v_resultado;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 168, v_resultado);

         -- COBROS DE FACTURAS AL CREDITO
         SELECT                                              /*+ FIRST_ROWS */
               DECODE (v_mojo,
                       'MB', NVL (SUM (b.valor), 0),
                       NVL (SUM (b.valor / NVL (a.tasa_cambio_ma, 1)), 0))
           INTO   v_resultado
           FROM   WMS_DOCUMENTOS a, DOC_ABONO_DOCUMENTOS b, WMS_DOCUMENTOS c
          WHERE       a.Tipo_documento = 'R'
                  AND NVL (a.situacion, 1) <> 11
                  AND a.jornada = p_jornada
                  AND a.documento = b.recibo
                  AND b.documento = c.documento
                  AND c.tipo_documento = 'F'
                  AND c.jornada <> p_jornada;

         v_total := v_total + v_resultado;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 169, v_resultado);

         -- NOTAS DE CREDITO POR TRANSFERENCIA
         SELECT   SUM (TOTAL)
           INTO   v_resultado
           FROM   WMS_DOCUMENTOS
          WHERE       tipo_documento = 'D'
                  AND jornada = p_jornada
                  AND NVL (situacion, 1) <> 11
                  AND SUBTIPO_DOCUMENTO = 'R';

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 627, NVL (v_resultado, 0));

         -- DEVOLUCIONES EN EFECTIVO
         SELECT   SUM (TOTAL)
           INTO   v_resultado
           FROM   WMS_DOCUMENTOS
          WHERE       tipo_documento = 'D'
                  AND jornada = p_jornada
                  AND NVL (situacion, 1) <> 11
                  AND SUBTIPO_DOCUMENTO = 'D';

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 174, NVL (v_resultado, 0));

         --APARTADOS ANULADOS
         SELECT   SUM (A.TOTAL)
           INTO   v_resultado
           FROM      WMS_DOCUMENTOS A
                  INNER JOIN
                     WMS_DOCUMENTOS B
                  ON A.DOCUMENTO_PADRE = B.DOCUMENTO
          WHERE       A.tipo_documento = 'D'
                  AND A.jornada = p_jornada
                  AND NVL (A.situacion, 1) <> 11
                  AND A.SUBTIPO_DOCUMENTO = 'A'
                  AND NVL (B.APARTADO, 'N') = 'S';

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 598, NVL (v_resultado, 0));

         --FACTURAS ANULADAS
         SELECT   SUM (A.TOTAL)
           INTO   v_resultado
           FROM      WMS_DOCUMENTOS A
                  INNER JOIN
                     WMS_DOCUMENTOS B
                  ON A.DOCUMENTO_PADRE = B.DOCUMENTO
          WHERE       A.tipo_documento = 'D'
                  AND A.jornada = p_jornada
                  AND NVL (A.situacion, 1) <> 11
                  AND A.SUBTIPO_DOCUMENTO = 'A'
                  AND NVL (B.APARTADO, 'N') <> 'S';

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 599, NVL (v_resultado, 0));

         -- DEVOLUCIONES VALES
         SELECT   SUM (TOTAL)
           INTO   v_resultado
           FROM   WMS_DOCUMENTOS
          WHERE       tipo_documento = 'D'
                  AND jornada = p_jornada
                  AND NVL (situacion, 1) <> 11
                  AND SUBTIPO_DOCUMENTO = 'V';

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 566, NVL (v_resultado, 0));

         --GIFT CARD PAGO
         SELECT   SUM(DECODE (CG_F_PARAMETER_VALUE ('MOJO'),
                              'MB', C.VALOR,
                              C.VALOR / NVL (A.TASA_CAMBIO_MA, 1)))
                     TOTAL
           INTO   v_resultado
           FROM   WMS_DOCUMENTOS A,
                  WMS_SOCIOS B,
                  WMS_PAGO_DOCUMENTOS C,
                  DOC_ABONO_DOCUMENTOS D,
                  WMS_DOCUMENTOS E
          WHERE       A.TIPO_DOCUMENTO = 'R'
                  AND A.DOCUMENTO = C.DOCUMENTO
                  AND C.TIPO_PAGO = '14'
                  AND A.SOCIO = B.SOCIO(+)
                  AND A.JORNADA IN (p_jornada)
                  AND NVL (A.SITUACION, 1) <> 11
                  AND D.RECIBO = A.DOCUMENTO
                  AND D.DOCUMENTO = E.DOCUMENTO
                  AND NVL (E.FECHA_VENCIMIENTO, E.FECHA_EMISION) =
                        NVL (E.FECHA_EMISION, SYSDATE)
                  AND WMS_F_FACTANUL (E.DOCUMENTO) <> 0;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 596, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 596

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 597, NVL (v_resultado, 0)); -- SE CREA EL ENCABEZADO DE LA VARIABLE 592

         --CREDIX
         SELECT   SUM (NVL (MONTO, 0)) TOTAL
           INTO   v_resultado
           FROM   WMS_V_CREDIX
          WHERE   JORNADA = p_jornada;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 610, NVL (v_resultado, 0));

         --FLEXI
         SELECT   SUM (NVL (MONTO, 0)) TOTAL
           INTO   v_resultado
           FROM   WMS_V_FLEXI
          WHERE   JORNADA = p_jornada;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 615, NVL (v_resultado, 0));

         --CREDICUOTAS
         SELECT   SUM (NVL (MONTO, 0)) TOTAL
           INTO   v_resultado
           FROM   WMS_V_CREDITOEK
          WHERE   JORNADA = p_jornada
                  AND POS_F_ES_RECIBO_MARCHAMO (DOCUMENTO) = 0;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 611, NVL (v_resultado, 0));

         -- ABONOS CON CREDI-E
         SELECT   NVL (SUM (A.VALORCOMPRA), 0) TOTAL
           INTO   V_RESULTADO
           FROM   WMS_CREDITOEK_RPAGS A, WMS_DOCUMENTOS B
          WHERE       A.DOCUMENTO = B.DOCUMENTO
                  AND A.ESTADO = 'C'
                  AND A.JORNADA = p_jornada
                  AND B.TIPO_DOCUMENTO = 'R'
                  AND NVL (B.SITUACION, 3) <> 11;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 613, NVL (v_resultado, 0));

         -- EFECTIVO ECOMMERCE
         SELECT   SUM (MONTO)
           INTO   V_RESULTADO
           FROM   POS_V_ABONOSECOMCC
          WHERE   JORNADA = p_jornada;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 920, NVL (v_resultado, 0));

         -- DEVOLUCIONES POR TIPO
         SELECT   SUM (TOTAL)
           INTO   v_resultado
           FROM   WMS_DOCUMENTOS
          WHERE       tipo_documento = 'D'
                  AND jornada = p_jornada
                  AND NVL (situacion, 1) <> 11;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 518, v_resultado);

         -- PAGOS ANTICIPADOS
         SELECT                                              /*+ FIRST_ROWS */
               DECODE (
                     v_mojo,
                     'MB',
                     NVL (SUM (NVL (a.total, 0) - abonos (a.documento)), 0),
                     NVL (
                        SUM( (NVL (a.total, 0)
                              - abonos (a.documento)
                                / NVL (a.tasa_cambio_ma, 1))),
                        0
                     )
                  )
           INTO   v_resultado
           FROM   WMS_DOCUMENTOS a
          WHERE       a.tipo_documento = 'R'
                  AND abonos (a.documento) < a.total
                  AND a.jornada = p_jornada
                  AND NVL (a.situacion, 1) <> 11;

         v_total := v_total + v_resultado;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 170, v_resultado);

         -- OTROS INGRESOS ( PEDIDOS ASOCIADOS A RECIBOS DE PAGO, UTILIZADOS EN CISA )
         SELECT                                              /*+ FIRST_ROWS */
               DECODE (v_mojo,
                       'MB', NVL (SUM (a.valor), 0),
                       NVL (SUM (a.valor / NVL (b.tasa_cambio_ma, 1)), 0))
           INTO   v_resultado
           FROM   DOC_ABONO_DOCUMENTOS a, WMS_DOCUMENTOS b
          WHERE       a.recibo = b.documento
                  AND b.jornada = p_jornada
                  AND a.tipo_documento = 'P'
                  AND NVL (b.situacion, 1) <> 11;

         v_total := v_total + v_resultado;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 171, v_resultado);

         -- COBROS DE PROPINAS NO FACTURADAS
         SELECT                                              /*+ FIRST_ROWS */
               DECODE (v_mojo,
                       'MB', NVL (SUM (propina), 0),
                       NVL (SUM (propina / NVL (tasa_cambio_ma, 1)), 0))
           INTO   v_resultado
           FROM   WMS_DOCUMENTOS
          WHERE       jornada = p_jornada
                  AND NVL (imprimir_propina, 'N') = 'N'
                  AND tipo_documento = 'F'
                  AND NVL (situacion, 1) <> 11;

         v_total := v_total + v_resultado;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 172, v_resultado);
           
           
         --EKONO PLUS VENTA Y RENOVACION
           
      SELECT   SUM (total)
              INTO   v_resultado
              FROM   ( --membresia venta y renovacion 18112020 ACC i
                      SELECT   ROUND (
                                  NVL (
                                     SUM (
                                        NVL (precio_unitario, 0) * cantidad
                                     ),
                                     0
                                  ),
                                  2
                               )            
                                  total
                        FROM   wms_skus_x_documento a, sr3_v_ventas_contado b
                       WHERE       a.documento = b.documento
                               AND a.usuario_anulo IS NULL
                               AND NVL (a.impuesto, 0) = 0
                               AND a.sku in(  cg_f_parameter_value ('MPLS'),cg_f_parameter_value ('RPLS') ) --membresia venta y renovacion 18112020 ACC f
                               AND  b.jornada = p_jornada
                      );  


         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 921, v_resultado);
          
           
          
         --EKONO PLUS CAMBIO TARJETA
             SELECT   SUM (total)
              INTO   v_resultado
              FROM   ( --membresia reemplazo de tarjeta 18112020 ACC i
                      SELECT   ROUND (
                                  NVL (
                                     SUM (
                                        NVL (precio_unitario, 0) * cantidad
                                     ),
                                     0
                                  ),
                                  2
                               )            
                                  total
                        FROM   wms_skus_x_documento a, sr3_v_ventas_contado b
                       WHERE       a.documento = b.documento
                               AND a.usuario_anulo IS NULL
                               AND NVL (a.impuesto, 0) = 0
                               AND a.sku in(cg_f_parameter_value('TPLS') )
                               AND  b.jornada = p_jornada);
         
         
                INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 922, v_resultado);
         
         ----------EKONO_PLUS ---------------------------------------------
         
              SELECT   SUM (total)
              INTO   v_resultado
              FROM   ( --membresia reemplazo de tarjeta 18112020 ACC i
                      SELECT   ROUND (
                                  NVL (
                                     SUM (
                                        NVL (precio_unitario, 0) * cantidad
                                     ),
                                     0
                                  ),
                                  2
                               )            
                                  total
                        FROM   wms_skus_x_documento a, sr3_v_ventas_contado b
                       WHERE       a.documento = b.documento
                               AND a.usuario_anulo IS NULL
                               AND NVL (a.impuesto, 0) = 0
                               AND a.sku in(cg_f_parameter_value('TPLS'),cg_f_parameter_value ('MPLS'),cg_f_parameter_value ('RPLS'))
                               AND  b.jornada = p_jornada);
         
         
                INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 923, v_resultado);
         
        -----------------SINPE MOVIL--------------------------------------------------
        SELECT   SUM (total)
              INTO   v_resultado
              FROM   ( --SINPE MOVIL  22062021 RVM
                      SELECT   ROUND ( MONTO,2) total
                        FROM   WMS_V_PAGO_SINPEMOVIL 
                       WHERE       JORNADA = p_jornada AND CODIGO_RESP = 0 AND ESTADO = 'A');
        
                  INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 924, v_resultado);
        ------------------------------------------------------------------------------
         
         -- TOTAL E IMPUESTOS DE TIPOS DE PAGO EN MONEDA BASE
         v_total :=
            pagos ('MB',
                   p_jornada,
                   3,
                   175);                                           -- EFECTIVO
         v_total :=
            v_total
            + pagos ('MB',
                     p_jornada,
                     1,
                     176);                              -- TARJETAS DE CREDITO
         v_total :=
            v_total
            + pagos ('MB',
                     p_jornada,
                     2,
                     177);                                -- TARJETA DE DEBITO
         v_total :=
            v_total
            + pagos ('MB',
                     p_jornada,
                     4,
                     178);                                           -- CHEQUE
         v_total := v_total + vales (p_jornada, 'D', 179); -- VALES POR DEVOLUCION
         v_total := v_total + vales (p_jornada, 'A', 180); -- VALES POR ANTICIPO ( CERTIFICADOS REGALO )
         v_total := v_total + vales (p_jornada, 'D', 330); -- VALES POR DEVOLUCION v.6.X
         v_total := v_total + vales (p_jornada, 'A', 331); -- VALES POR ANTICIPO ( CERTIFICADOS REGALO ) v.6.X
         v_total :=
            v_total
            + pagos ('MB',
                     p_jornada,
                     11,
                     181);                                    -- OTRAS MONEDAS
         v_total :=
            v_total
            + pagos ('MB',
                     p_jornada,
                     10,
                     182);                                        -- DEPOSITOS
         v_total :=
            v_total
            + pagos ('MB',
                     p_jornada,
                     12,
                     183);                          -- EXONERACION DE IMPUESTO
         v_total := v_total + vales (p_jornada, 'D', 361); -- VALES POR DEVOLUCION EMITIDOS
         v_total := v_total + vales (p_jornada, 'A', 362); -- VALES POR ANTICIPO ( CERTIFICADOS REGALO ) EMITIDAS

         -- TOTAL MONEDA BASE
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 188, v_total);

         -- TOTAL SUPERVISOR
         SELECT   NVL (SUM (monto_supervisor), 0)
           INTO   v_resultado
           FROM   WMS_DETALLE_JORNADAS
          WHERE   jornada = p_jornada;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 284, v_resultado);

         -- DIFERENCIA SISTEMA-SUPERVISOR
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 285, v_total - v_resultado);

         -- IMPUESTO DE TIPOS DE PAGO EN MONEDA BASE
         v_total :=
            impuesto_pagos ('MB',
                            p_jornada,
                            3,
                            287);                                  -- EFECTIVO
         v_total :=
            v_total
            + impuesto_pagos ('MB',
                              p_jornada,
                              1,
                              288);                     -- TARJETAS DE CREDITO
         v_total :=
            v_total
            + impuesto_pagos ('MB',
                              p_jornada,
                              2,
                              289);                      -- TARJETAS DE DEBITO
         v_total :=
            v_total
            + impuesto_pagos ('MB',
                              p_jornada,
                              4,
                              290);                                  -- CHEQUE
         v_total :=
            v_total
            + impuesto_pagos ('MB',
                              p_jornada,
                              6,
                              291);                    -- VALES POR DEVOLUCION
         v_total :=
            v_total
            + impuesto_pagos ('MB',
                              p_jornada,
                              6,
                              292); -- VALES POR ANTICIPO ( CERTIFICADOS REGALO )
         v_total :=
            v_total
            + impuesto_pagos ('MB',
                              p_jornada,
                              11,
                              293);                           -- OTRAS MONEDAS
         v_total :=
            v_total
            + impuesto_pagos ('MB',
                              p_jornada,
                              10,
                              294);                               -- DEPOSITOS

         -- TOTAL IMPUESTO DE TIPOS DE PAGO EN MONEDA BASE
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 295, v_total);

         -- TIPOS DE PAGO EN MONEDA ALTERNA
         v_total :=
            pagos ('MA',
                   p_jornada,
                   17,
                   184);                                           -- EFECTIVO
         v_total :=
            v_total
            + pagos ('MA',
                     p_jornada,
                     19,
                     185);                                 -- TARJETAS CREDITO
         v_total :=
            v_total
            + pagos ('MA',
                     p_jornada,
                     18,
                     186);                                           -- CHEQUE
         v_total :=
            v_total
            + pagos ('MA',
                     p_jornada,
                     20,
                     187);                                        -- DEPOSITOS

         -- TOTAL MONEDA ALTERNA
         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 189, v_total);

         -- TARJETAS DE CREDITO AGRUPADAS POR EMISOR (1,2,3,4,5)
         -- v_total := pagos('MB',p_jornada,1,261,'N',1);
         -- v_total := pagos('MB',p_jornada,1,262,'N',2);
         -- v_total := pagos('MB',p_jornada,1,263,'N',3);
         -- v_total := pagos('MB',p_jornada,1,264,'N',4);
         -- v_total := pagos('MB',p_jornada,1,265,'N',5);

         actualizar_jornada (p_jornada);

         -- TOTAL CONTADO
         SELECT   SUM (monto)
           INTO   v_resultado
           FROM   WMS_HISTORICO_JORNADAS
          WHERE   jornada = p_jornada AND rubro IN (175, 178, 179, 180, 183);

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 296, v_resultado);

         -- TOTAL CREDITO + TARJETAS DE CREDITO
         SELECT   SUM (monto)
           INTO   v_resultado
           FROM   WMS_HISTORICO_JORNADAS
          WHERE   jornada = p_jornada AND rubro IN (165, 176);

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 297, v_resultado);

         -- VENTA BRUTA + DESCUENTOS SIN IVA
         SELECT   SUM (monto)
           INTO   v_resultado
           FROM   WMS_HISTORICO_JORNADAS
          WHERE   jornada = p_jornada AND rubro IN (273, 274);

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 276, v_resultado);

         -- VENTA BRUTA + DESCUENTOS SIN IVA + IVA TOTAL
         SELECT   SUM (monto)
           INTO   v_resultado
           FROM   WMS_HISTORICO_JORNADAS
          WHERE   jornada = p_jornada AND rubro IN (273, 274, 275);

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 277, v_resultado);

         -- DONACIONES
         SELECT                                              /*+ FIRST_ROWS */
               SUM (NVL (a.donado, 0))
           INTO   v_resultado
           FROM   WMS_PAGO_DOCUMENTOS a, WMS_DOCUMENTOS b
          WHERE       a.documento = b.documento
                  AND b.tipo_documento = 'R'
                  AND NVL (b.situacion, 1) <> 11
                  AND b.jornada = p_jornada;

         INSERT INTO WMS_HISTORICO_JORNADAS (jornada, rubro, monto)
           VALUES   (p_jornada, 278, v_resultado);
           
           
         -- ZUNIFY-------------------------------------------------------------------------------
            SELECT   SUM(DECODE (Cg_F_Parameter_Value ('MOJO'),
                                 'MB', c.valor,
                                 c.valor / NVL (a.tasa_cambio_ma, 1)))
              INTO   v_resultado
              FROM   WMS_DOCUMENTOS a, wms_pago_documentos c
             WHERE       a.tipo_documento = 'R'
                     AND A.DOCUMENTO = C.DOCUMENTO
                     AND C.TIPO_PAGO = '40'
                     AND a.jornada IN (p_jornada)
                     AND NVL (a.situacion, 1) <> 11;
        
         UPDATE WMS_HISTORICO_JORNADAS SET monto = v_resultado where jornada = p_jornada AND rubro = 148;
        -----------------------------------------------------------------------------------------------
           
         -- Grabamos los cambios
         COMMIT;
         WMS_P_REDONDEO_TOTALES_JORNADA (p_jornada, NULL, TRUE);
      END IF;
   END cierre_caja;

   --------------------------------------------------------------------------
   -- Cerrar jornada
   --------------------------------------------------------------------------
   PROCEDURE cerrar_jornada (p_jornada    NUMBER,
                             p_usuario    VARCHAR2,
                             p_estado     VARCHAR2 DEFAULT 'S' )
   IS
      VRESULT     NUMBER;
      VJORNADAS   VARCHAR2 (10000);
      VFECHA_AP   DATE;                         --FECHA APERTURA DE LA JORNADA

      CURSOR CJORNADAS (
         pFECHA                   DATE,
         pJORNADA                 NUMBER
      )
      IS
         SELECT   JORNADA
           FROM   WMS_JORNADAS
          WHERE       FECHA_CIERRE IS NULL
                  AND TRUNC (FECHA_APERTURA) = pFECHA
                  AND JORNADA <> pJORNADA;                 --JORNADAS ABIERTAS
   BEGIN
      WMS_P_REGISTRO_CAJERO (p_jornada, p_usuario);

      COMMIT;

      WMS_P_DOCS_MAN (p_jornada);

      COMMIT;

      VRESULT := WMS_F_DIFER_CIERREC (NULL, p_JORNADA);

      IF VRESULT = 0
      THEN
         SELECT   NVL (SISTEMA, 0)
           INTO   VRESULT
           FROM   RET_V_JORNADAS
          WHERE   JORNADA = p_jornada;

         SELECT   TRUNC (FECHA_APERTURA)
           INTO   VFECHA_AP
           FROM   WMS_JORNADAS
          WHERE   JORNADA = p_JORNADA;          --OBTIENE LA FECHA DE APERTURA

         VJORNADAS := NULL;

         FOR VJORN IN CJORNADAS (VFECHA_AP, p_JORNADA)
         LOOP                        --OBTIENE LAS JORNADAS QUE ESTAN ABIERTAS
            IF VJORNADAS IS NULL
            THEN
               VJORNADAS := '';
            END IF;

            VJORNADAS := VJORNADAS || ' ' || TO_CHAR (VJORN.JORNADA);
         END LOOP;

         IF VRESULT = 0
         THEN
            WMS_P_CERRAR_REGCAJ (p_JORNADA, p_USUARIO);

            UPDATE   WMS_JORNADAS
               SET   corte_cerrado = p_estado,
                     fecha_cierre = SYSDATE,
                     supervisor = p_usuario
             WHERE   jornada = p_jornada;

            UPDATE   WMS_JORNADAS_BAC
               SET   FECHA_CIERRE = SYSDATE
             WHERE   JORNADA = p_jornada;

            -- Grabamos los cambios
            COMMIT;
         ELSE
            SELECT   COUNT ( * )
              INTO   VRESULT
              FROM   WMS_REGISTRO_CAJEROS
             WHERE   JORNADA = p_jornada AND CERRADO_EL IS NULL;

            IF VRESULT = 0
            THEN
               UPDATE   WMS_JORNADAS
                  SET   corte_cerrado = p_estado,
                        fecha_cierre = SYSDATE,
                        supervisor = p_usuario
                WHERE   jornada = p_jornada;

               UPDATE   WMS_JORNADAS_BAC
                  SET   FECHA_CIERRE = SYSDATE
                WHERE   JORNADA = p_jornada;

               -- Grabamos los cambios
               COMMIT;
            ELSE
               IF VJORNADAS IS NULL
               THEN
                  RAISE_APPLICATION_ERROR (
                     -20000,
                     'NO SE HA REALIZADO O FINALIZADO EL CIERRE CONSOLIDADO DE ESTA JORNADA.'
                  );
               ELSE
                  RAISE_APPLICATION_ERROR (
                     -20000,
                     'NO SE HA REALIZADO O FINALIZADO EL CIERRE CONSOLIDADO DE ESTA JORNADA. ESTAS JORNADAS DEL DIA, NO SE HAN CERRADO: '
                     || VJORNADAS
                  );
               END IF;                             --IF VJORNADAS IS NULL THEN
            END IF;                                      --IF VRESULT = 0 THEN
         END IF;                                         --IF VRESULT = 0 THEN
      ELSE
         RAISE_APPLICATION_ERROR (
            -20000,
            'ESTA JORNADA TIENE UN SOBRANTE/FALTANTE. REVISE EL CIERRE CONSOLIDADO'
         );
      END IF;                            -- IF VRESULT = 0 THEN    DIFERENCIAS
   END cerrar_jornada;

   --------------------------------------------------------------------------
   -- Pagos efectuados en la jornada
   --------------------------------------------------------------------------
   FUNCTION pagos_jornada (p_jornada         NUMBER,
                           p_tipo_pago       NUMBER,
                           p_pagado      OUT NUMBER,
                           p_pagado_om   OUT NUMBER,
                           p_moneda          NUMBER DEFAULT NULL ,
                           p_emisor          NUMBER DEFAULT NULL )
      RETURN NUMBER
   IS
      v_resultado    NUMBER;
      v_total        NUMBER;
      v_usuario      WMS_DETALLE_JORNADAS.monto%TYPE;
      v_supervisor   WMS_DETALLE_JORNADAS.monto_supervisor%TYPE;
      v_rubro        NUMBER (5);
      v_pagado       WMS_HISTORICO_JORNADAS.monto_usuario%TYPE;
      v_pagado_om    WMS_HISTORICO_JORNADAS.monto_supervisor%TYPE;
   BEGIN
      -- Vales
      IF p_tipo_pago IN (6)
      THEN
         SELECT                                              /*+ FIRST_ROWS */
               NVL (
                     DECODE (
                        Cg_F_Parameter_Value ('MOJO'),
                        'MB',
                        SUM (NVL (a.valor, 0) + NVL (a.propina, 0)),
                        SUM( (NVL (a.valor, 0) + NVL (a.propina, 0))
                            / NVL (b.tasa_cambio_ma, 1))
                     ),
                     0
                  )
           INTO   v_resultado
           FROM   WMS_PAGO_DOCUMENTOS a, WMS_DOCUMENTOS b, DOC_VALES c
          WHERE       a.documento = b.documento
                  AND b.tipo_documento = 'R'
                  AND NVL (b.situacion, 1) <> 11
                  AND a.vale = c.vale
                  AND c.tipo = 'D'      -- D Vales A Certificados de Regalo/NC
                  AND b.jornada = p_jornada
                  AND a.tipo_pago = p_tipo_pago;

         v_total := v_resultado;

         -- v.6.X
         SELECT   NVL (
                     DECODE (
                        Cg_F_Parameter_Value ('MOJO'),
                        'MB',
                        -SUM (b.cantidad * (b.precio_unitario + b.impuesto)),
                        -SUM(  b.cantidad
                             * (b.precio_unitario + b.impuesto)
                             / NVL (a.tasa_cambio_ma, 1))
                     ),
                     0
                  )
                     total
           INTO   v_resultado
           FROM   WMS_DOCUMENTOS a, WMS_SKUS_X_DOCUMENTO b, DOC_VALES c
          WHERE       a.tipo_documento = 'F'
                  AND a.jornada = p_jornada
                  AND NVL (a.situacion, 1) <> 11
                  AND a.documento = b.documento
                  AND b.cantidad < 0
                  AND b.vale = c.vale;

         v_resultado := v_total + v_resultado;
      -- Efectivo, Cheque, Tarje...
      ELSE
         IF p_emisor IS NULL
         THEN
            SELECT                                           /*+ FIRST_ROWS */
                  NVL (
                        DECODE (
                           Cg_F_Parameter_Value ('MOJO'),
                           'MB',
                           SUM (NVL (a.valor, 0) + NVL (a.propina, 0)),
                           SUM( (NVL (a.valor, 0) + NVL (a.propina, 0))
                               / NVL (b.tasa_cambio_ma, 1))
                        ),
                        0
                     )
                        total,
                     -- DECODE(p_tipo_pago,11,SUM(NVL(a.pagado,0)),NULL) pagado,
                     -- DECODE(p_tipo_pago,11,SUM(NVL(a.pagado,0)/NVL(a.tasa_cambio,1)),NULL) pagado_om,
                     DECODE (MIN (NVL (a.tasa_cambio, 1)),
                             1, NULL,
                             SUM (NVL (a.pagado, 0)))
                        pagado,
                     DECODE (
                        MIN (NVL (a.tasa_cambio, 1)),
                        1,
                        NULL,
                        SUM (NVL (a.pagado, 0) / NVL (a.tasa_cambio, 1))
                     )
                        pagado_om
              INTO   v_resultado, v_pagado, v_pagado_om
              FROM   WMS_PAGO_DOCUMENTOS a, WMS_DOCUMENTOS b
             WHERE       a.documento = b.documento
                     AND b.tipo_documento = 'R'
                     AND NVL (b.situacion, 1) <> 11
                     AND b.jornada = p_jornada
                     AND a.tipo_pago = p_tipo_pago
                     AND NVL (a.moneda, Wms_F_Moneda_Base) =
                           NVL (p_moneda, NVL (a.moneda, Wms_F_Moneda_Base));
         ELSE
            SELECT                                           /*+ FIRST_ROWS */
                  NVL (
                        DECODE (
                           Cg_F_Parameter_Value ('MOJO'),
                           'MB',
                           SUM (NVL (a.valor, 0) + NVL (a.propina, 0)),
                           SUM( (NVL (a.valor, 0) + NVL (a.propina, 0))
                               / NVL (b.tasa_cambio_ma, 1))
                        ),
                        0
                     )
              INTO   v_resultado
              FROM   WMS_PAGO_DOCUMENTOS a, WMS_DOCUMENTOS b
             WHERE       a.documento = b.documento
                     AND b.tipo_documento = 'R'
                     AND NVL (b.situacion, 1) <> 11
                     AND b.jornada = p_jornada
                     AND a.tipo_pago = p_tipo_pago
                     AND NVL (a.emisor, -1) = NVL (p_emisor, -1)
                     AND NVL (a.moneda, Wms_F_Moneda_Base) =
                           NVL (p_moneda, NVL (a.moneda, Wms_F_Moneda_Base));
         END IF;
      END IF;

      v_total := v_resultado;

      -- (-) Devolucion en efectivo/tarjeta
      IF p_tipo_pago = 3 AND p_moneda = Wms_F_Moneda_Base
      THEN
         SELECT                                             /* + FIRST_ROWS */
               DECODE (Cg_F_Parameter_Value ('MOJO'),
                       'MB', NVL (SUM (total), 0),
                       NVL (SUM (total / NVL (tasa_cambio_ma, 1)), 0))
           INTO   v_resultado
           FROM   WMS_DOCUMENTOS
          WHERE       tipo_documento = 'D'
                  AND subtipo_documento = 'D'
                  AND jornada = p_jornada;

         v_total := v_total - v_resultado;
      END IF;

      -- (-) Devolucion en tarjeta
      IF p_tipo_pago = 1
      THEN
         SELECT                                             /* + FIRST_ROWS */
               DECODE (Cg_F_Parameter_Value ('MOJO'),
                       'MB', NVL (SUM (total), 0),
                       NVL (SUM (total / NVL (tasa_cambio_ma, 1)), 0))
           INTO   v_resultado
           FROM   WMS_DOCUMENTOS
          WHERE       tipo_documento = 'D'
                  AND subtipo_documento = 'A'
                  AND jornada = p_jornada;

         v_total := v_total - v_resultado;
      END IF;

      p_pagado := v_pagado;
      p_pagado_om := v_pagado_om;
      RETURN v_total;
   END pagos_jornada;

   --------------------------------------------------------------------------
   -- Calculando diferencial cambiario en base a depositos
   --------------------------------------------------------------------------
   PROCEDURE diferencial_cambiario (p_jornada NUMBER)
   IS
      -- Cursor de depositos en otras monedas de la jornada
      CURSOR c_depositos
      IS
         SELECT   a.tipo_pago,
                  a.monto,
                  a.tasa_cambio,
                  a.monto_om,
                  b.rv_mpnc01 moneda
           FROM   WMS_DETALLE_JORNADAS a, CG_REF_CODES b
          WHERE       a.jornada = p_jornada
                  AND NVL (a.monto, 0) > 0
                  AND b.rv_domain = 'TIPO PAGO CIERRE'
                  AND a.tipo_pago = b.rv_low_value
                  AND b.rv_high_value IN ('3', '4', '10');

      -- VL
      v_monto         WMS_DETALLE_JORNADAS.monto%TYPE;
      v_monto_om      WMS_DETALLE_JORNADAS.monto_om%TYPE;
      v_diferencial   WMS_DETALLE_JORNADAS.monto%TYPE;
   BEGIN
      UPDATE   WMS_DETALLE_JORNADAS
         SET   monto = 0, monto_om = NULL
       WHERE   jornada = p_jornada AND tipo_pago = 64;

      FOR v_depositos IN c_depositos
      LOOP
         SELECT                                              /*+ FIRST_ROWS */
               SUM (NVL (a.pagado, 0)) pagado,
                  SUM (NVL (a.pagado, 0) / NVL (a.tasa_cambio, 1)) pagado_om
           INTO   v_monto, v_monto_om
           FROM   WMS_PAGO_DOCUMENTOS a, WMS_DOCUMENTOS b
          WHERE       a.documento = b.documento
                  AND b.tipo_documento = 'R'
                  AND NVL (b.situacion, 1) <> 11
                  AND b.jornada = p_jornada
                  AND a.tipo_pago = v_depositos.tipo_pago
                  AND NVL (a.moneda, Wms_F_Moneda_Base) = v_depositos.moneda;

         v_diferencial := 0;

         -- Verificando si coincide el monto recibido en OM con el monto a depositar
         IF v_depositos.monto_om = v_monto_om
         THEN
            -- Calculando el diferencial cambiario
            v_diferencial := v_depositos.monto - v_monto;
         ELSE
            NULL;
         END IF;

         IF v_diferencial <> 0
         THEN
            BEGIN
               INSERT INTO WMS_DETALLE_JORNADAS (jornada,
                                                 tipo_pago,
                                                 monto,
                                                 tasa_cambio,
                                                 monto_om)
                 VALUES   (p_jornada,
                           64,
                           -v_diferencial,
                           NULL,
                           NULL);
            EXCEPTION
               WHEN DUP_VAL_ON_INDEX
               THEN
                  UPDATE   WMS_DETALLE_JORNADAS
                     SET   monto = monto + -v_diferencial, monto_om = NULL
                   WHERE   jornada = p_jornada AND tipo_pago = 64;
            END;
         END IF;
      END LOOP;

      -- GC
      COMMIT;
   END diferencial_cambiario;

   --------------------------------------------------------------------------
   -- Calculo del monto en caja chica para la jornada
   --------------------------------------------------------------------------
   PROCEDURE caja_chica (p_jornada NUMBER)
   IS
      -- VL
      v_monto   WMS_DETALLE_JORNADAS.monto%TYPE;
   BEGIN
      SELECT   NVL (SUM (NVL (valor, 0)), 0)
        INTO   v_monto
        FROM   WMS_GASTOS_JORNADA
       WHERE   jornada = p_jornada;

      BEGIN
         INSERT INTO WMS_DETALLE_JORNADAS (jornada,
                                           tipo_pago,
                                           monto,
                                           tasa_cambio,
                                           monto_om)
           VALUES   (p_jornada,
                     63,
                     v_monto,
                     NULL,
                     NULL);
      EXCEPTION
         WHEN DUP_VAL_ON_INDEX
         THEN
            UPDATE   WMS_DETALLE_JORNADAS
               SET   monto = v_monto, monto_om = NULL
             WHERE   jornada = p_jornada AND tipo_pago = 63;
      END;

      -- GC
      COMMIT;
   END caja_chica;

   --------------------------------------------------------------------------
   -- Actualizar informacion del cierre de caja
   --------------------------------------------------------------------------
   PROCEDURE actualizar_jornada (p_jornada NUMBER)
   IS
      -- Cursor de tipos de pago para el cierre
      CURSOR c_tipo_pagos_cierre
      IS
           SELECT   a.rv_low_value tipo_cierre,
                    a.rv_high_value tipo,
                    a.rv_mpnc01 subtipo,
                    b.rv_low_value rubro
             FROM   CG_REF_CODES a, CG_REF_CODES b
            WHERE       a.rv_domain = 'TIPO PAGO CIERRE'
                    AND b.rv_domain = 'VARIABLE'
                    AND a.rv_low_value = b.rv_mpnc01
         ORDER BY   1;

      -- Cursor de tipos de pago
      CURSOR c_tipo_pagos
      IS
         SELECT   rv_low_value
           FROM   CG_REF_CODES
          WHERE   rv_domain = 'TIPO PAGO';

      -- Cursor de Diferencias
      CURSOR c_diferencias
      IS
           SELECT   c.rv_high_value tipo_pago,
                    c.rv_mpnc02 rubro,
                    SUM (NVL (a.monto, 0)) monto_sistema,
                    SUM (NVL (d.monto, 0)) monto_usuario,
                    SUM (NVL (d.monto, 0)) - SUM (NVL (a.monto, 0)) diferencia
             FROM   WMS_HISTORICO_JORNADAS a,
                    CG_REF_CODES b,
                    CG_REF_CODES c,
                    WMS_DETALLE_JORNADAS d
            WHERE       a.jornada = p_jornada
                    AND a.jornada = d.jornada
                    AND b.rv_domain = 'VARIABLE'
                    AND c.rv_domain = 'TIPO PAGO CIERRE'
                    AND a.rubro = b.rv_low_value
                    AND d.tipo_pago = b.rv_mpnc01
                    AND b.rv_mpnc01 = c.rv_low_value
                    AND INSTR (c.rv_mpcc01, 'E') > 0
                    AND c.rv_mpnc02 IS NOT NULL
         GROUP BY   c.rv_high_value, c.rv_mpnc02;

      -- Definimos VL
      v_sistema       WMS_DETALLE_JORNADAS.monto%TYPE;
      v_tasa_cambio   WMS_DETALLE_JORNADAS.tasa_cambio%TYPE;
      v_pagado        WMS_HISTORICO_JORNADAS.monto_usuario%TYPE;
      v_pagado_om     WMS_HISTORICO_JORNADAS.monto_supervisor%TYPE;
      v_monto         WMS_DETALLE_JORNADAS.monto%TYPE;
   BEGIN
      IF jornada_cerrada (p_jornada) = 'N'
      THEN
         --    -- Creando/Actualizando detalles de la jornada
         FOR v_tipo_pago IN c_tipo_pagos_cierre
         LOOP
            v_sistema := 0;
            v_tasa_cambio := NULL;

            -- Efectivo              [3]  51
            -- Cheque                [4]  52
            -- Vale                  [6]  60
            -- Excension de Impuesto [12] 62
            IF v_tipo_pago.tipo_cierre IN (51, 52, 60, 62, 87, 90, 91)
            THEN
               v_sistema :=
                  pagos_jornada (p_jornada,
                                 v_tipo_pago.tipo,
                                 v_pagado,
                                 v_pagado_om,
                                 Wms_F_Moneda_Base);

               --Le restamos el valor de la caja chica
               IF (v_tipo_pago.tipo = 3)
               THEN
                  v_sistema :=
                     v_sistema
                     - WMS_F_TOTAL_CAJA_CHICA (p_jornada, Wms_F_Moneda_Base);
               END IF;
            -- Otras Monedas         TIPO 3 Efectivo, 4 Cheque, 10 Depositos
            ELSIF v_tipo_pago.tipo IN (3, 4, 10, 92)
            THEN                        -- .tipo_cierre IN ( 53, 54, 65 ) THEN
               -- Tasa de cambio
               SELECT   ROUND (Wms_F_Equivalencia ('M',
                                                   v_tipo_pago.subtipo,
                                                   Wms_F_Moneda_Base,
                                                   1), 6)
                 INTO   v_tasa_cambio
                 FROM   DUAL;

               v_sistema :=
                  pagos_jornada (p_jornada,
                                 v_tipo_pago.tipo,
                                 v_pagado,
                                 v_pagado_om,
                                 v_tipo_pago.subtipo);
            --Le restamos el valor de la caja chica
            --IF (v_tipo_pago.rubro = 279) THEN
            --    v_sistema := v_sistema - WMS_F_TOTAL_CAJA_CHICA(p_jornada,v_tipo_pago.subtipo);
            --END IF;

            -- Tarjeta de Credito    TIPO 1 Tarjeta de Credito
            ELSIF v_tipo_pago.tipo IN (1)
            THEN -- .tipo_cierre IN ( 51, 52, 53, 54, 55, 56, 57, 58, 59 ) THEN
               v_sistema :=
                  pagos_jornada (p_jornada,
                                 v_tipo_pago.tipo,
                                 v_pagado,
                                 v_pagado_om,
                                 Wms_F_Moneda_Base,
                                 v_tipo_pago.subtipo);
            -- Vale Externo          [1]  61
            ELSIF v_tipo_pago.tipo_cierre = 61
            THEN
               NULL;
            -- Caja Chica                 63
            ELSIF v_tipo_pago.tipo_cierre = 63
            THEN
               NULL;
            -- Diferencial Cambiario      64
            ELSIF v_tipo_pago.tipo_cierre = 64
            THEN
               NULL;
            END IF;

            -- Agregando en detalle jornadas
            BEGIN
               INSERT INTO WMS_DETALLE_JORNADAS (jornada,
                                                 tipo_pago,
                                                 monto,
                                                 monto_supervisor,
                                                 tasa_cambio,
                                                 monto_om)
                 VALUES   (p_jornada,
                           v_tipo_pago.tipo_cierre,
                           0,
                           0,
                           v_tasa_cambio,
                           DECODE (v_tasa_cambio, NULL, NULL, 0));
            EXCEPTION
               WHEN DUP_VAL_ON_INDEX
               THEN
                  NULL;
            END;

            -- Agregando al historico de jornadas
            BEGIN
               IF (v_tipo_pago.rubro = 279)
               THEN
                  v_sistema :=
                     v_sistema - WMS_F_TOTAL_CAJA_CHICA (p_jornada, 1);
               END IF;

               INSERT INTO WMS_HISTORICO_JORNADAS (jornada,
                                                   rubro,
                                                   monto,
                                                   monto_usuario,
                                                   monto_supervisor)
                 VALUES   (p_jornada,
                           v_tipo_pago.rubro,
                           v_sistema,
                           v_pagado,
                           v_pagado_om);
            EXCEPTION
               WHEN DUP_VAL_ON_INDEX
               THEN
                  UPDATE   WMS_HISTORICO_JORNADAS
                     SET   monto = v_sistema,
                           monto_usuario = v_pagado,
                           monto_supervisor = v_pagado_om
                   WHERE   jornada = p_jornada AND rubro = v_tipo_pago.rubro;
            END;
         END LOOP;

         -- Actualizando informacion del Usuario
         FOR v_tipo_pagos IN c_tipo_pagos
         LOOP
            SELECT   NVL (SUM (monto), 0) monto
              INTO   v_monto
              FROM   WMS_DETALLE_JORNADAS a, CG_REF_CODES b, CG_REF_CODES c
             WHERE       a.jornada = p_jornada
                     AND b.rv_domain = 'TIPO PAGO CIERRE'
                     AND a.tipo_pago = b.rv_low_value
                     AND c.rv_domain = 'TIPO PAGO'
                     AND b.rv_high_value = c.rv_low_value
                     AND c.rv_low_value = v_tipo_pagos.rv_low_value;

            UPDATE   WMS_DETALLE_JORNADAS
               SET   monto = v_monto
             WHERE   jornada = p_jornada
                     AND tipo_pago = v_tipo_pagos.rv_low_value;
         END LOOP;
      END IF;

      -- Actualizando diferencias Sistema - Usuario
      FOR v_diferencias IN c_diferencias
      LOOP
         BEGIN
            --IF (v_diferencias.tipo_pago = 3) THEN
            --        v_diferencias.diferencia := v_diferencias.diferencia + WMS_F_TOTAL_CAJA_CHICA(p_jornada,Wms_F_Moneda_Base);
            --END IF;

            INSERT INTO WMS_HISTORICO_JORNADAS (
                                                   jornada,
                                                   rubro,
                                                   monto
                       )
              VALUES   (
                           p_jornada,
                           v_diferencias.rubro,
                           v_diferencias.diferencia
                       );
         EXCEPTION
            WHEN DUP_VAL_ON_INDEX
            THEN
               UPDATE   WMS_HISTORICO_JORNADAS
                  SET   monto = v_diferencias.diferencia
                WHERE   jornada = p_jornada AND rubro = v_diferencias.rubro;
         END;
      END LOOP;

      -- GC
      COMMIT;
      -- Actualizando
      diferencial_cambiario (p_jornada);
      caja_chica (p_jornada);
   END actualizar_jornada;
END Wms_P_Jornadas;
/
